@@ -1,10 +1,7 @@
 /* vim: set sw=8: */
 
 /*
- * applix-read.c : Routines to read applix version 4 spreadsheets.
- *
- * I have no docs or specs for this format that are useful.
- * This is a guess based on some sample sheets.
+ * applix-read.c : Routines to read applix version 4 & 5 spreadsheets.
  *
  * Copyright (C) 2000-2002 Jody Goldberg (jody@gnome.org)
  *
@@ -23,35 +20,44 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
  */
+
+/*
+ * I do not have much in the way of useful docs.
+ * This is a guess based on some sample sheets with a few pointers from
+ * 	http://www.vistasource.com/products/axware/fileformats/wptchc01.html
+ */
+
 #include <gnumeric-config.h>
 #include <gnumeric.h>
 #include "applix.h"
-#include "application.h"
-#include "expr.h"
-#include "value.h"
-#include "sheet.h"
-#include "number-match.h"
-#include "cell.h"
-#include "parse-util.h"
-#include "sheet-style.h"
-#include "style.h"
-#include "style-border.h"
-#include "style-color.h"
-#include "selection.h"
-#include "position.h"
-#include "ranges.h"
-#include "io-context.h"
-#include "workbook-view.h"
-#include "workbook.h"
-#include "error-info.h"
 
+#include <application.h>
+#include <expr.h>
+#include <value.h>
+#include <sheet.h>
+#include <number-match.h>
+#include <cell.h>
+#include <parse-util.h>
+#include <sheet-style.h>
+#include <style.h>
+#include <style-border.h>
+#include <style-color.h>
+#include <selection.h>
+#include <position.h>
+#include <ranges.h>
+#include <io-context.h>
+#include <workbook-view.h>
+#include <workbook.h>
+#include <error-info.h>
+
+#include <gsf/gsf-input-textline.h>
 #include <ctype.h>
 #include <string.h>
 #include <stdlib.h>
 #include <libgnome/gnome-i18n.h>
 
 typedef struct {
-	FILE          *file;
+	GsfInputTextline *input;
 	ErrorInfo     *parse_error;
 	WorkbookView  *wb_view;
 	Workbook      *wb;
@@ -60,9 +66,9 @@ typedef struct {
 	GPtrArray     *attrs;
 	GPtrArray     *font_names;
 
-	char *buffer;
-	int buffer_size;
-	int line_len;
+	unsigned char *buffer;
+	size_t buffer_size;
+	size_t line_len;
 	int zoom;
 } ApplixReadState;
 
@@ -74,6 +80,8 @@ static int debug_applix_read = 0;
 #define d(level, code)
 #endif
 
+#define a_strncmp(buf, str) strncmp ((buf), str, sizeof (str) - 1)
+
 /* The maximum numer of character potentially involved in a new line */
 #define MAX_END_OF_LINE_SLOP	16
 
@@ -133,61 +141,83 @@ applix_parse_value (char *buf, char **follow)
 	return buf;
 }
 
-gboolean
-applix_read_header (FILE *file)
+static unsigned char *
+applix_get_line (ApplixReadState *state)
 {
-	char encoding_buffer[32];
-	int v0, v1, matches;
+	unsigned char *ptr, *end, *buf;
+	size_t len, skip = 0, offset = 0;
 
-	matches  = fscanf (file, "*BEGIN SPREADSHEETS VERSION=%d/%d ENCODING=%31s\n",
-			   &v0, &v1, encoding_buffer);
+	while (NULL != (ptr = gsf_input_textline_ascii_gets (state->input))) {
+		len = strlen (ptr);
 
-	if (matches != 3)
-		return FALSE;
+		/* Clip at the state line length */
+		if (len > state->line_len)
+			len = state->line_len;
 
-	/* FIXME : Guess that version 400 is a minimum */
-	if (v0 < 400)
-		return FALSE;
+		if ((offset + len) > state->buffer_size) {
+			state->buffer_size += state->line_len;
+			state->buffer = g_realloc (state->buffer, state->buffer_size + 1);
+		}
 
-	/* We only have a sample of '7BIT' right now */
-	return strcmp (encoding_buffer, "7BIT") == 0;
+		end = ptr + len;
+		ptr += skip;
+		buf = state->buffer + offset;
+		while (ptr < end) {
+			if (*ptr == '^') {
+				if (ptr [1] != '^') {
+					if (ptr [1] == '\0' || ptr [2] == '\0') {
+						applix_parse_error (state, _("Missing characters for character encoding"));
+						*(buf++) = *(ptr++);
+					} else if (ptr [1] < 'a' || ptr [1] > 'p' ||
+						   ptr [2] < 'a' || ptr [2] > 'p') {
+						applix_parse_error (state, _("Invalid characters for in encoding '%c%c'"),
+								    ptr[1], ptr[2]);
+						*(buf++) = *(ptr++);
+					} else {
+						*(buf++) = ((ptr[1] - 'a') << 8) | (ptr[2] - 'a');
+						ptr += 3;
+					}
+				} else /* an encoded carat */
+					*(buf++) = '^', ptr += 2;
+			} else
+				*(buf++) = *(ptr++);
+		}
+
+		offset = buf - state->buffer;
+
+		if (len >= state->line_len)
+			skip = 1; /* skip the leading space for next line */
+		else
+			break;
+	}
+
+	if (state->buffer != NULL)
+		state->buffer [offset] = '\0';
+	return state->buffer;
 }
+
 static gboolean
 applix_read_colormap (ApplixReadState *state)
 {
-	char buffer[128];
+	unsigned char *buffer, *pos, *iter, *end;
+	int count;
+	long numbers[6];
 
-	if (NULL == fgets (buffer, sizeof(buffer), state->file))
-		return TRUE;
 
-	if (strncmp (buffer, "COLORMAP", 8))
-		return TRUE;
+	while (NULL != (buffer = applix_get_line (state))) {
 
-	while (1) {
-		int count;
-		char *pos, * iter;
-		long numbers[6];
-
-		if (NULL == fgets (buffer, sizeof(buffer), state->file))
-			return TRUE;
-
-		if (!strncmp (buffer, "END COLORMAP", 12))
+		if (!a_strncmp (buffer, "END COLORMAP"))
 			return FALSE;
 
-		pos = buffer + strlen(buffer) - 2;
-
-		g_return_val_if_fail (pos >= buffer, TRUE);
-
-		iter = pos;
+		iter = pos = buffer + strlen (buffer) - 1;
 		for (count = 6; --count >= 0; pos = iter) {
-			char *end;
 			while (--iter > buffer && isdigit ((unsigned char)*iter))
 				;
 
 			if (iter <= buffer || *iter != ' ')
 				return TRUE;
 
-			numbers[count] = strtol (iter+1, &end, 10);
+			numbers[count] = strtol (iter+1, (char **)&end, 10);
 			if (end != pos || numbers[count] < 0 || numbers[count] > 255)
 				return TRUE;
 		}
@@ -219,31 +249,18 @@ applix_read_colormap (ApplixReadState *state)
 		}
 	}
 
-	/* NOTREACHED */
 	return TRUE;
 }
 
 static gboolean
 applix_read_typefaces (ApplixReadState *state)
 {
-	char buffer[128];
+	unsigned char *ptr;
 
-	if (NULL == fgets (buffer, sizeof(buffer), state->file))
-		return TRUE;
-
-	if (strncmp (buffer, "TYPEFACE TABLE", 14))
-		return TRUE;
-
-looper :
-	if (NULL == fgets (buffer, sizeof(buffer), state->file))
-		return TRUE;
-	if (strncmp (buffer, "END TYPEFACE TABLE", 18)) {
-		char *ptr = buffer;
-		while (*ptr && *ptr != '\n' && *ptr != '\r')
-			++ptr;
-		*ptr = '\0';
-		g_ptr_array_add	(state->font_names, g_strdup (buffer));
-		goto looper;
+	while (NULL != (ptr = applix_get_line (state))) {
+		if (!a_strncmp (ptr, "END TYPEFACE TABLE"))
+			return FALSE;
+		g_ptr_array_add	(state->font_names, g_strdup (ptr));
 	}
 
 	return FALSE;
@@ -278,7 +295,7 @@ applix_get_precision (char const *val)
 }
 
 static MStyle *
-applix_parse_style (ApplixReadState *state, char **buffer)
+applix_parse_style (ApplixReadState *state, unsigned char **buffer)
 {
 	MStyle *style;
 	char *start = *buffer, *tmp = start;
@@ -295,7 +312,6 @@ applix_parse_style (ApplixReadState *state, char **buffer)
 		is_invisible = TRUE;
 		tmp = ++start;
 	}
-	/* TODO : Handle these flags */
 	if ((is_protected || is_invisible)) {
 		if (*tmp != ' ') {
 			(void) applix_parse_error (state, "Invalid format, protection problem");
@@ -327,6 +343,9 @@ applix_parse_style (ApplixReadState *state, char **buffer)
 		/* Allocate the new style */
 		style = mstyle_new_default ();
 
+		mstyle_set_content_hidden (style, is_protected);
+		mstyle_set_content_locked (style, is_invisible);
+
 		if (sep[1] == '\'')
 			sep += 2;
 		else
@@ -684,27 +703,20 @@ applix_parse_style (ApplixReadState *state, char **buffer)
 static int
 applix_read_attributes (ApplixReadState *state)
 {
-	char buffer[128];
 	int count = 0;
+	unsigned char *ptr, *tmp;
+	MStyle *style;
 
-	if (NULL == fgets (buffer, sizeof(buffer), state->file) ||
-	    strcmp (buffer, "Attr Table Start\n"))
-		return applix_parse_error (state, "Invalid attribute table");
+	while (NULL != (ptr = applix_get_line (state))) {
+		if (!a_strncmp (ptr, "Attr Table End"))
+			return FALSE;
 
-	while (1) {
-		char *tmp = buffer+1;
-		MStyle *style;
-		if (NULL == fgets (buffer, sizeof(buffer), state->file))
-			return applix_parse_error (state, "Invalid attribute");
-
-		if (!strncmp (buffer, "Attr Table End", 14))
-			return 0;
-
-		if (buffer[0] != '<')
+		if (ptr [0] != '<')
 			return applix_parse_error (state, "Invalid attribute");
 
 		/* TODO : The first style seems to be a different format */
 		if (count++) {
+			tmp = ptr + 1;
 			style = applix_parse_style (state, &tmp);
 			if (style == NULL || *tmp != '>')
 				return applix_parse_error (state, "Invalid attribute");
@@ -717,7 +729,7 @@ applix_read_attributes (ApplixReadState *state)
 }
 
 static Sheet *
-applix_get_sheet (ApplixReadState *state, char **buffer,
+applix_get_sheet (ApplixReadState *state, unsigned char **buffer,
 		  char const separator)
 {
 	Sheet *sheet;
@@ -736,6 +748,7 @@ applix_get_sheet (ApplixReadState *state, char **buffer,
 		sheet = sheet_new (state->wb, *buffer);
 		workbook_sheet_attach (state->wb, sheet, NULL);
 		sheet_set_zoom_factor (sheet, (double )(state->zoom) / 100., FALSE, FALSE);
+		sheet_flag_recompute_spans (sheet);
 	}
 
 	*buffer = tmp+1;
@@ -743,8 +756,8 @@ applix_get_sheet (ApplixReadState *state, char **buffer,
 }
 
 static char *
-applix_parse_cellref (ApplixReadState *state, char *buffer,
-		      Sheet **sheet, int *col, int *row,
+applix_parse_cellref (ApplixReadState *state, unsigned char *buffer,
+		      Sheet **sheet, CellPos *pos,
 		      char const separator)
 {
 	int len;
@@ -752,11 +765,11 @@ applix_parse_cellref (ApplixReadState *state, char *buffer,
 	*sheet = applix_get_sheet (state, &buffer, separator);
 
 	/* Get cell addr */
-	if (*sheet && parse_cell_name (buffer, col, row, FALSE, &len))
+	if (*sheet && parse_cell_name (buffer, pos, FALSE, &len))
 		return buffer + len;
 
 	*sheet = NULL;
-	*col = *row = -1;
+	pos->col = pos->row = -1;
 	return NULL;
 }
 
@@ -772,32 +785,62 @@ applix_width_to_pixels (int width)
 }
 
 static int
-applix_read_view (ApplixReadState *state, char *name)
+applix_read_current_view (ApplixReadState *state, unsigned char *buffer)
 {
-	char buffer[128];
-	Sheet *sheet;
+	/* What is this ? */
+	unsigned char *ptr;
+	while (NULL != (ptr = applix_get_line (state)))
+	       if (!a_strncmp (ptr, "End View, Name: ~Current~"))
+		       return 0;
+	return -1;
+}
 
-	do {
-		if (NULL == fgets (buffer, sizeof(buffer), state->file))
-			return TRUE;
+static int
+applix_read_view (ApplixReadState *state, unsigned char *buffer)
+{
+	Sheet *sheet = NULL;
+	unsigned char *name = buffer + 19;
+	gboolean ignore;
+	int len = strlen (name);
 
-		if (!strncmp ("View Top Left: ", buffer, 15)) {
-			int col, row;
-			if (applix_parse_cellref (state, buffer+15, &sheet, &col, &row, ':'))
-				sheet_set_initial_top_left (sheet, col, row);
-		} else if (!strncmp ("View Open Cell: ", buffer, 16)) {
-			int col, row;
-			if (applix_parse_cellref (state, buffer+16, &sheet, &col, &row, ':'))
-				sheet_selection_set (sheet, col, row, col, row, col, row);
-		} else if (!strncmp ("View Default Column Width ", buffer, 26)) {
+	g_return_val_if_fail (len > 1 && name [len-1] == '~', -1);
+
+	/* I wish there were some docs on this, names sometimes appear to be
+	 * SHEET_LETTER:name~ and sometimes
+	 * SHEET_LETTER:name:~ and sometimes
+	 */
+	if (name [len-2] == ':')
+		name [len-2] = '\0';
+	else
+		name [len-1] = '\0';
+
+	ignore = !strcmp (name, "Current"); /* ignore current */
+
+	while (NULL != (buffer = applix_get_line (state))) {
+		if (!a_strncmp (buffer, "View End, Name: ~"))
+			break;
+		if (ignore)
+			continue;
+
+		if (!a_strncmp (buffer, "View Top Left: ")) {
+			CellPos pos;
+			if (applix_parse_cellref (state, buffer+15, &sheet, &pos, ':'))
+				sv_set_initial_top_left (sheet_get_view (sheet, state->wb_view),
+							 pos.col, pos.row);
+		} else if (!a_strncmp (buffer, "View Open Cell: ")) {
+			CellPos pos;
+			if (applix_parse_cellref (state, buffer+16, &sheet, &pos, ':'))
+				sv_selection_set (sheet_get_view (sheet, state->wb_view),
+						  &pos, pos.col, pos.row, pos.col, pos.row);
+		} else if (!a_strncmp (buffer, "View Default Column Width ")) {
 			char *ptr, *tmp = buffer + 26;
 			int width = strtol (tmp, &ptr, 10);
 			if (tmp == ptr || width <= 0)
 				return applix_parse_error (state, "Invalid default column width");
 
 			sheet_col_set_default_size_pixels (sheet,
-							   applix_width_to_pixels (width));
-		} else if (!strncmp ("View Default Row Height: ", buffer, 25)) {
+				applix_width_to_pixels (width));
+		} else if (!a_strncmp (buffer, "View Default Row Height: ")) {
 			char *ptr, *tmp = buffer + 25;
 			int height = strtol (tmp, &ptr, 10);
 			if (tmp == ptr || height <= 0)
@@ -805,8 +848,8 @@ applix_read_view (ApplixReadState *state, char *name)
 
 			/* height + one for the grid line */
 			sheet_row_set_default_size_pixels (sheet,
-							   applix_height_to_pixels (height));
-		} else if (!strncmp (buffer, "View Row Heights: ", 18)) {
+				applix_height_to_pixels (height));
+		} else if (!a_strncmp (buffer, "View Row Heights: ")) {
 			char *ptr = buffer + 17;
 			do {
 				int row, height;
@@ -831,7 +874,7 @@ applix_read_view (ApplixReadState *state, char *name)
 							  applix_height_to_pixels (height),
 							  TRUE);
 			} while (ptr[0] == ' ' && isdigit ((unsigned char) ptr[1]));
-		} else if (!strncmp (buffer, "View Column Widths: ", 20)) {
+		} else if (!a_strncmp (buffer, "View Column Widths: ")) {
 			char *ptr = buffer + 19;
 			do {
 				int col, width;
@@ -852,99 +895,29 @@ applix_read_view (ApplixReadState *state, char *name)
 							   TRUE);
 			} while (ptr[0] == ' ' && isalpha ((unsigned char) ptr[1]));
 		}
-	} while (strncmp (buffer, "View End, Name: ~", 17));
+	}
 
 	return 0;
 }
 
-static int
-applix_read_views (ApplixReadState *state)
-{
-	char buffer[128];
-
-	/* Ignore current view */
-	do {
-		if (NULL == fgets (buffer, sizeof(buffer), state->file))
-			return -1;
-	} while (strncmp (buffer, "End View, Name: ~Current~", 25));
-
-loop :
-	if (NULL == fgets (buffer, sizeof(buffer), state->file))
-		return TRUE;
-
-	if (!strncmp (buffer, "View Start, Name: ~", 19)) {
-		char *name = buffer + 19;
-		int len = strlen (name);
-
-		g_return_val_if_fail (name[len-1] == '\n', -1);
-		g_return_val_if_fail (name[len-2] == '~', -1);
-
-		/* I wish there were some docs on this, names sometimes appear to be
-		 * SHEET_LETTER:name~\n and sometimes
-		 * SHEET_LETTER:name:~\n and sometimes
-		 */
-		if (name[len-3] == ':')
-			name[len-3] = '\0';
-		else
-			name[len-2] = '\0';
-
-		applix_read_view (state, name);
-		goto loop;
-	}
-	return 0;
-}
-
-static gboolean
-applix_get_line (ApplixReadState *state)
-{
-	char saved_char = '\0';
-	char *ptr = state->buffer;
-	int len = state->buffer_size;
-
-loop :
-	/* Read line length plus room for end of line characters */
-	if (NULL == fgets(ptr, len, state->file))
-		return FALSE;
-
-	if ((int)strlen (ptr) > state->line_len) {
-		/* Clip at the state line length */
-		len -= state->line_len;
-		if (len < 0) {
-			int offset = ptr - state->buffer;
-			len += state->line_len;
-			state->buffer = g_renew (gchar, state->buffer, len);
-			ptr = state->buffer + offset;
-		}
-		/* the extension lines have a leading space.
-		 * To avoid reading the moving the line we copy over the last
-		 * character of the preceding line and replace it later.
-		 */
-		if (saved_char)
-			*ptr = saved_char;
-		ptr += state->line_len-1;
-		saved_char = *ptr;
-		goto loop;
-	}
-	if (saved_char)
-		*ptr = saved_char;
-	return TRUE;
-}
-
 static int
 applix_read_cells (ApplixReadState *state)
 {
 	Sheet *sheet;
-	int col, row;
+	MStyle *style;
+	Cell *cell;
+	CellPos pos;
+	ParseError  perr;
+	unsigned char content_type, *tmp, *ptr;
 
-	while (applix_get_line (state) && strncmp (state->buffer, "*END SPREADSHEETS", 17)) {
-		Cell *cell;
-		char content_type, *tmp, *ptr = state->buffer;
-		gboolean const val_is_string = (state->buffer[1] == '\'');
+	while (NULL != (ptr = applix_get_line (state))) {
+		gboolean const val_is_string = (ptr[0] != '\0' && ptr[1] == '\'');
+
+	       if (!a_strncmp (ptr, "*END SPREADSHEETS"))
+		       break;
 
 		/* Parse formatting */
-		MStyle *style = applix_parse_style (state, &ptr);
-
-		/* Error reported above */
+		style = applix_parse_style (state, &ptr);
 		if (style == NULL)
 			return -1;
 		if (ptr == NULL) {
@@ -953,21 +926,21 @@ applix_read_cells (ApplixReadState *state)
 		}
 
 		/* Get cell */
-		ptr = applix_parse_cellref (state, ptr, &sheet, &col, &row, '!');
+		ptr = applix_parse_cellref (state, ptr, &sheet, &pos, '!');
 		if (ptr == NULL) {
 			mstyle_unref (style);
 			return applix_parse_error (state, "Expression did not specify target cell");
 		}
-		cell = sheet_cell_fetch (sheet, col, row);
+		cell = sheet_cell_fetch (sheet, pos.col, pos.row);
 
 		/* Apply the formating */
-		sheet_style_set_pos (sheet, col, row, style);
+		sheet_style_set_pos (sheet, pos.col, pos.row, style);
 		content_type = *ptr;
 		switch (content_type) {
 		case ';' : /* First of a shared formula */
 		case '.' : { /* instance of a shared formula */
 			ParsePos	 pos;
-			ExprTree	*expr;
+			GnmExpr	const	*expr;
 			Value		*val = NULL;
 			Range		 r;
 			char *expr_string;
@@ -986,8 +959,6 @@ applix_read_cells (ApplixReadState *state)
 				/* TODO : Could this happen ? */
 				val = value_new_string (ptr);
 
-			tmp = expr_string + strlen (expr_string) - 1;
-			*tmp = '\0';
 #if 0
 			printf ("\'%s\'\n\'%s\'\n", ptr, expr_string);
 #endif
@@ -998,14 +969,14 @@ applix_read_cells (ApplixReadState *state)
 				if (*expr_string == '~') {
 					Sheet *start_sheet, *end_sheet;
 					tmp = applix_parse_cellref (state, expr_string+1, &start_sheet,
-								    &r.start.col, &r.start.row, ':');
+								    &r.start, ':');
 					if (start_sheet == NULL || tmp == NULL || tmp[0] != '.' || tmp[1] != '.') {
 						(void) applix_parse_error (state, "Invalid array expression");
 						continue;
 					}
 
 					tmp = applix_parse_cellref (state, tmp+2, &end_sheet,
-								    &r.end.col, &r.end.row, ':');
+								    &r.end, ':');
 					if (end_sheet == NULL || tmp == NULL || tmp[0] != '~') {
 						(void) applix_parse_error (state, "Invalid array expression");
 						continue;
@@ -1020,23 +991,29 @@ applix_read_cells (ApplixReadState *state)
 					expr_string = tmp+3; /* ~addr~<space><space>=expr */
 				}
 
+				/* We need to continue at all costs so that the
+				 * rest of the sheet can be parsed. If we quit, then trailing
+				 * 'Formula ' lines confuse the parser
+				 */
 				if (*expr_string != '=' && *expr_string != '+') {
-					(void) applix_parse_error (state, "Expression did not start with '=' ?");
-					continue;
-				}
+					(void) applix_parse_error (state, _("Expression did not start with '=' ? '%s'"),
+								   expr_string);
+					expr = gnm_expr_new_constant (value_new_string (expr_string));
+				} else
+					expr = gnm_expr_parse_str (expr_string+1,
+						parse_pos_init_cell (&pos, cell),
+						GNM_EXPR_PARSE_USE_APPLIX_REFERENCE_CONVENTIONS |
+						GNM_EXPR_PARSE_CREATE_PLACEHOLDER_FOR_UNKNOWN_FUNC,
+						&perr);
 
-				expr = expr_parse_str (expr_string+1,
-					parse_pos_init_cell (&pos, cell),
-					GNM_PARSER_USE_APPLIX_REFERENCE_CONVENTIONS |
-					GNM_PARSER_CREATE_PLACEHOLDER_FOR_UNKNOWN_FUNC,
-					NULL);
 				if (expr == NULL) {
-					(void) applix_parse_error (state, "Invalid expression");
-					continue;
-				}
-
-				if (is_array) {
-					expr_tree_ref (expr);
+					(void) applix_parse_error (state, _("%s!%s : unable to parse '%s'\n     %s"),
+								   cell->base.sheet->name_quoted, cell_name (cell),
+								   expr_string, perr.message);
+					parse_error_free (&perr);
+					expr = gnm_expr_new_constant (value_new_string (expr_string));
+				} else if (is_array) {
+					gnm_expr_ref (expr);
 					cell_set_array_formula (sheet,
 								r.start.col, r.start.row,
 								r.end.col, r.end.row,
@@ -1046,22 +1023,24 @@ applix_read_cells (ApplixReadState *state)
 					cell_set_expr_and_value (cell, expr, val, TRUE);
 
 				if (!applix_get_line (state) ||
-				    strncmp (state->buffer, "Formula: ", 9)) {
-					(void) applix_parse_error (state, "Missing forumula ID");
+				    a_strncmp (state->buffer, "Formula: ")) {
+					(void) applix_parse_error (state, "Missing formula ID");
 					continue;
 				}
 
 				ptr = state->buffer + 9;
-				tmp = ptr + strlen (ptr) - 1;
-				*tmp = '\0';
 
 				/* Store the newly parsed expresion along with its descriptor */
-				g_hash_table_insert (state->exprs, g_strdup (ptr), expr);
+				g_hash_table_insert (state->exprs, g_strdup (ptr),
+						     (gpointer)expr);
 			} else {
+				const char *key = expr_string + strlen (expr_string);
+				while (key > expr_string && !isspace ((unsigned char)key[-1]))
+					key--;
 #if 0
-				printf ("shared '%s'\n", expr_string);
+				printf ("Shared '%s'\n", expr_string);
 #endif
-				expr = g_hash_table_lookup (state->exprs, expr_string);
+				expr = g_hash_table_lookup (state->exprs, key);
 				cell_set_expr_and_value (cell, expr, val, TRUE);
 			}
 			break;
@@ -1071,8 +1050,6 @@ applix_read_cells (ApplixReadState *state)
 			Value *val = NULL;
 
 			ptr += 2;
-			tmp = ptr + strlen (ptr) - 1;
-			*tmp = '\0';
 #if 0
 			printf ("\"%s\" %d\n", ptr, val_is_string);
 #endif
@@ -1097,190 +1074,227 @@ applix_read_cells (ApplixReadState *state)
 	return 0;
 }
 
+static int
+applix_read_row_list (ApplixReadState *state, unsigned char *ptr)
+{
+	unsigned char *tmp;
+	Range	r;
+	Sheet *sheet = applix_get_sheet (state, &ptr, ' ');
+
+	if (ptr == NULL)
+		return -1;
+	if (*ptr != '!')
+		return applix_parse_error (state, "Invalid row format");
+
+	r.start.row = r.end.row = strtol (++ptr, (char **)&tmp, 10) - 1;
+	if (tmp == ptr || r.start.row < 0 || tmp[0] != ':' || tmp[1] != ' ')
+		return applix_parse_error (state, "Invalid row format row number");
+
+	++tmp;
+	do {
+		unsigned attr_index;
+
+		r.start.col = strtol (ptr = tmp+1, (char **)&tmp, 10);
+		if (tmp == ptr || r.start.col < 0 || tmp[0] != '-')
+			return applix_parse_error (state, "Invalid row format start col");
+		r.end.col = strtol (ptr = tmp+1, (char **)&tmp, 10);
+		if (tmp == ptr || r.end.col < 0 || tmp[0] != ':')
+			return applix_parse_error (state, "Invalid row format end col");
+		attr_index = strtol (ptr = tmp+1, (char **)&tmp, 10);
+		if (tmp != ptr && attr_index >= 2 && attr_index < state->attrs->len+2) {
+			MStyle *style = g_ptr_array_index(state->attrs, attr_index-2);
+			mstyle_ref (style);
+			sheet_style_set_range (sheet, &r, style);
+		} else if (attr_index != 1) /* TODO : What the hell is attr 1 ?? */
+			return applix_parse_error (state, "Invalid row format attr index");
+
+	/* Just for kicks they added a trailing space */
+	} while (tmp[0] && isdigit ((unsigned char)tmp[1]));
+
+	return 0;
+}
+
+static gboolean
+applix_read_sheet_table (ApplixReadState *state)
+{
+	unsigned char *ptr;
+	while (NULL != (ptr = applix_get_line (state)))
+	       if (!a_strncmp (ptr, "END SHEETS TABLE"))
+		       return FALSE;
+#warning TODO
+	return TRUE;
+}
+
+static gboolean
+applix_read_header_footer (ApplixReadState *state)
+{
+	unsigned char *ptr;
+	while (NULL != (ptr = applix_get_line (state)))
+	       if (!a_strncmp (ptr, "Headers And Footers End"))
+		       return FALSE;
+	return TRUE;
+}
+
+static gboolean
+applix_read_relative_name (ApplixReadState *state, char *buffer)
+{
+	char *end;
+
+	/* .ABCDe. Coordinate: A:B2..A:C4 */
+	/* Spec guarantees that there are no dots in the name */
+	buffer = strchr (buffer, '.');
+	if (buffer == NULL)
+		return TRUE;
+	end = strchr (++buffer, '.');
+	if (end == NULL)
+		return TRUE;
+	*end = '\0';
+#if 0
+	GnmExpr *expr = gnm_expr_parse_str (expr_string+1,
+		parse_pos_init_cell (&pos, cell),
+		GNM_EXPR_PARSE_USE_APPLIX_REFERENCE_CONVENTIONS |
+		GNM_EXPR_PARSE_CREATE_PLACEHOLDER_FOR_UNKNOWN_FUNC,
+		&perr);
+#endif
+	puts (buffer);
+	return FALSE;
+}
+
+static gboolean
+applix_read_absolute_name (ApplixReadState *state, char *buffer)
+{
+	/* .abcdE. tCol:0 tRow:0 tSheet:0 bCol:1 bRow:2 bSheet: 0 tColAbs:0 tRowAbs:0 tSheetAbs:1 bColAbs:0 bRowAbs:0 bSheetAbs:1 */
+	/* Spec guarantees that there are no dots in the name */
+	puts (buffer);
+	return FALSE;
+}
+
+#define ABS_NAMED_RANGE	"Named Range, Name:"
+#define REL_NAMED_RANGE	"Relative Named Range, Name:"
+
 static int
 applix_read_impl (ApplixReadState *state)
 {
 	Sheet *sheet;
-	int col, row;
-	int ext_links;
-	int major_rev, minor_rev;
-	char real_name[128];
-	int dummy, res;
-	char dummy_c;
-	char top_cell_addr[30], cur_cell_addr[30];
-	char buffer[128];
-	char default_text_format[128];
-	char default_number_format[128];
-	int def_col_width, win_width, win_height;
-	gboolean valid_header = applix_read_header (state->file);
+	CellPos pos;
+	int ext_links = -1;
+	unsigned char *real_name = NULL;
+	char top_cell_addr[30] = "";
+	char cur_cell_addr[30] = "";
+	unsigned char *buffer;
+	char default_text_format[128] = "";
+	char default_number_format[128] = "";
+	int def_col_width = -1;
+	int win_width = -1;
+	int win_height = -1;
 
-	g_return_val_if_fail (valid_header, -1);
+	while (NULL != (buffer = applix_get_line (state))) {
+		if (!a_strncmp (buffer, "*BEGIN SPREADSHEETS VERSION=")) {
+			char encoding_buffer[32];
+			int v0, v1;
+			if (3 != sscanf (buffer, "*BEGIN SPREADSHEETS VERSION=%d/%d ENCODING=%31s",
+					 &v0, &v1, encoding_buffer))
+				return applix_parse_error (state, "Invalid header ");
 
-	if (1 != fscanf (state->file, "Num ExtLinks: %d\n", &ext_links))
-		return applix_parse_error (state, "Missing number of external links");
+			/* FIXME : Guess that version 400 is a minimum */
+			if (v0 < 400)
+				return applix_parse_error (state, "Versions < 4.0 are not supported");
 
-	if (3 != fscanf (state->file, "Spreadsheet Dump Rev %d.%d Line Length %d\n",
-			 &major_rev, &minor_rev, &state->line_len))
-		return applix_parse_error (state, "Missing dump revision");
-	else if (state->line_len < 0 || 65535 < state->line_len) /* magic sanity check */
-		return applix_parse_error (state, "Invalid line length");
+			/* We only have a sample of '7BIT' right now */
+			if (strcmp (encoding_buffer, "7BIT"))
+				return applix_parse_error (state, "We only have samples of '7BIT' encoding, please send us this sample.");
 
-	state->buffer_size = 2 * state->line_len + MAX_END_OF_LINE_SLOP;
-	state->buffer = g_new (gchar, state->buffer_size);
+		} else if (!a_strncmp (buffer, "Num ExtLinks:")) {
+			if (1 != sscanf (buffer, "Num ExtLinks: %d", &ext_links))
+				return applix_parse_error (state, "Missing number of external links");
 
-	/* It appears some docs do not have this */
-	if (1 != fscanf (state->file, "Current Doc Real Name: %127s\n", real_name)) {
-		strncpy (real_name, "Unspecified", sizeof (real_name)-1);
-		ungetc ((unsigned char)'C', state->file); /* restore the leading 'C' */
+		} else if (!a_strncmp (buffer, "Spreadsheet Dump Rev")) {
+			int major_rev, minor_rev, len;
+			if (3 != sscanf (buffer, "Spreadsheet Dump Rev %d.%d Line Length %d",
+					 &major_rev, &minor_rev, &len))
+				return applix_parse_error (state, "Missing dump revision");
+			if (len < 0 || 65535 < len) /* magic sanity check */
+				return applix_parse_error (state, "Invalid line length");
+			state->line_len = len;
+
+			d (0, printf ("Applix load : Saved with revision %d.%d",
+				      major_rev, minor_rev););
+		} else if (!a_strncmp (buffer, "Current Doc Real Name:")) {
+			real_name = g_strdup (buffer + 22);
+
+		} else if (!strcmp (buffer, "COLORMAP")) {
+			if (applix_read_colormap (state))
+				return applix_parse_error (state, "invalid colormap");
+
+		} else if (!strcmp (buffer, "TYPEFACE TABLE")) {
+			if (applix_read_typefaces (state))
+				return applix_parse_error (state, "invalid typefaces");
+
+		} else if (!strcmp (buffer, "Attr Table Start")) {
+			if (applix_read_attributes (state))
+				return applix_parse_error (state, "Invalid attribute table");
+
+		} else if (!a_strncmp (buffer, "View, Name: ~Current~")) {
+			if (0 != applix_read_current_view (state, buffer))
+				return applix_parse_error (state, "Invalid view");
+
+		} else if (!a_strncmp (buffer, "View Start, Name: ~")) {
+			if (0 != applix_read_view (state, buffer))
+				return applix_parse_error (state, "Invalid view");
+
+		} else if (!a_strncmp (buffer, "Default Label Style")) {
+			if (1 != sscanf (buffer, "Default Label Style %s", default_text_format))
+				return applix_parse_error (state, "invalid default label style");
+
+		} else if (!a_strncmp (buffer, "Default Number Style")) {
+			if (1 != sscanf (buffer, "Default Number Style %s", default_number_format))
+				return applix_parse_error (state, "invalid default number style");
+
+		} else if (!a_strncmp (buffer, "Document Column Width:")) {
+			if (1 != sscanf (buffer, "Document Column Width: %d", &def_col_width))
+				return applix_parse_error (state, "invalid col width");
+
+		} else if (!a_strncmp (buffer, "Percent Zoom Factor:")) {
+			if (1 != sscanf (buffer, "Percent Zoom Factor: %d", &state->zoom) ||
+			    state->zoom <= 10 || 500 <= state->zoom)
+				return applix_parse_error (state, "invalid zoom");
+		} else if (!a_strncmp (buffer, "Window Width:")) {
+			if (1 != sscanf (buffer, "Window Width: %d", &win_width))
+				return applix_parse_error (state, "invalid win width");
+		} else if (!a_strncmp (buffer, "Window Height:")) {
+			if (1 != sscanf (buffer, "Window Height: %d", &win_height))
+				return applix_parse_error (state, "invalid win height");
+		} else if (!a_strncmp (buffer, "Top Left:")) {
+			if (1 != sscanf (buffer, "Top Left: %25s", top_cell_addr))
+				return applix_parse_error (state, "invalid top left");
+		} else if (!a_strncmp (buffer, "Open Cell:")) {
+			if (1 != sscanf (buffer, "Open Cell: %25s", cur_cell_addr))
+				return applix_parse_error (state, "invalid cur cell");
+		} else if (!a_strncmp (buffer, "SHEETS TABLE")) {
+			if (applix_read_sheet_table (state))
+				return applix_parse_error (state, "sheet table");
+		} else if (!a_strncmp (buffer, ABS_NAMED_RANGE)) {
+			if (applix_read_absolute_name (state, buffer + sizeof (ABS_NAMED_RANGE)))
+				return applix_parse_error (state, "Absolute named range");
+		} else if (!a_strncmp (buffer, REL_NAMED_RANGE)) {
+			if (applix_read_relative_name (state, buffer + sizeof (REL_NAMED_RANGE)))
+				return applix_parse_error (state, "Absolute named range");
+		} else if (!a_strncmp (buffer, "Row List")) {
+			if (applix_read_row_list (state, buffer + sizeof ("Row List")))
+				return applix_parse_error (state, "row list");
+		} else if (!a_strncmp (buffer, "Headers And Footers")) {
+			if (applix_read_header_footer (state))
+				return applix_parse_error (state, "headers and footers");
+
+			break; /* BREAK OUT OF THE LOOP HERE */
+		}
 	}
 
-	d (0, printf ("Applix load '%s' : Saved with revision %d.%d\n",
-		      real_name, major_rev, minor_rev););
-
-	if (applix_read_colormap (state))
-		return applix_parse_error (state, "invalid colormap");
-	if (applix_read_typefaces (state))
-		return applix_parse_error (state, "invalid typefaces");
-	if (0 != (res = applix_read_attributes (state)))
-		return res;
-
-	if (1 != fscanf (state->file, "No Auto Start Rt: %d\n", &dummy))
-		return applix_parse_error (state, "invalid auto start");
-
-	if (1 != fscanf (state->file, "No Auto Link Update: %d\n", &dummy))
-		return applix_parse_error (state, "invalid auto link");
-
-	if (1 != fscanf (state->file, "No Auto Start OD: %d\n", &dummy))
-		return applix_parse_error (state, "invalid auto start OD");
-
-	if (1 != fscanf (state->file, "No Auto Start Rt Insert: %d\n", &dummy))
-		return applix_parse_error (state, "invalid auto start insert");
-
-	if (0 != fscanf (state->file, "Date Numbers Standard\n"))
-		return applix_parse_error (state, "invalid date num");
-
-	if (0 != fscanf (state->file, "Calculation Automatic\n"))
-		return applix_parse_error (state, "invalid auto calc");
-
-	if (1 != fscanf (state->file, "Minimal Recalc: %d\n", &dummy))
-		return applix_parse_error (state, "invalid minimal recalc");
-
-	if (1 != fscanf (state->file, "Optimal Calc: %d\n", &dummy))
-		return applix_parse_error (state, "invalid optimal calc");
-
-	if (1 != fscanf (state->file, "Calculation Style %c\n", &dummy_c))
-		return applix_parse_error (state, "invalid calc style");
-
-	if (1 != fscanf (state->file, "Calc Background Enabled: %d\n", &dummy))
-		return applix_parse_error (state, "invalid enabled background calc");
-
-	if (1 != fscanf (state->file, "Calc On Display: %d\n", &dummy))
-		return applix_parse_error (state, "invalid calc on display");
-
-	if (1 != fscanf (state->file, "Calc Visible Cells Only:%d\n", &dummy))
-		return applix_parse_error (state, "invalid calc visi");
-
-	if (1 != fscanf (state->file, "Calc RtInsert On Display: %d\n", &dummy))
-		return applix_parse_error (state, "invalid rtinsert on disp");
-
-	if (1 != fscanf (state->file, "Calc Type Conversion: %d\n", &dummy))
-		return applix_parse_error (state, "invalid type conv");
-
-	if (1 != fscanf (state->file, "Calc Before Save: %d\n", &dummy))
-		return applix_parse_error (state, "invalid calc before save");
-
-	if (1 != fscanf (state->file, "Bottom Right Corner %25s\n", buffer))
-		return applix_parse_error (state, "invalid bottom right");
-
-	if (1 != fscanf (state->file, "Default Label Style %s\n", default_text_format))
-		return applix_parse_error (state, "invalid default label style");
-
-	if (1 != fscanf (state->file, "Default Number Style %s\n", default_number_format))
-		return applix_parse_error (state, "invalid default number style");
-
-	if (NULL == fgets (buffer, sizeof(buffer), state->file) ||
-	    strncmp (buffer, "Symbols ", 8))
-		return applix_parse_error (state, "invalid symbols ??");
-
-	if (1 != fscanf (state->file, "Document Column Width: %d\n", &def_col_width))
-		return applix_parse_error (state, "invalid col width");
-
-	if (1 != fscanf (state->file, "Percent Zoom Factor: %d\n", &state->zoom) ||
-	    state->zoom <= 10 || 500 <= state->zoom)
-		return applix_parse_error (state, "invalid zoom");
-
-	if (1 != fscanf (state->file, "Window Width: %d\n", &win_width))
-		return applix_parse_error (state, "invalid win width");
-
-	if (1 != fscanf (state->file, "Window Height: %d\n", &win_height))
-		return applix_parse_error (state, "invalid win height");
-
-	if (1 != fscanf (state->file, "Window X Pos: %d\n", &dummy))
-		return applix_parse_error (state, "invalid win x");
-
-	if (1 != fscanf (state->file, "Window Y Pos: %d\n", &dummy))
-		return applix_parse_error (state, "invalid win y");
-
-	if (1 != fscanf (state->file, "Top Left: %25s\n", top_cell_addr))
-		return applix_parse_error (state, "invalid top left");
-
-	if (1 != fscanf (state->file, "Open Cell: %25s\n", cur_cell_addr))
-		return applix_parse_error (state, "invalid cur cell");
-	/* TODO : find the rest of the selection */
-
-	if (1 != fscanf (state->file, "Charting Preference: %s\n", buffer))
-		return applix_parse_error (state, "invalid chart pref");
-
-	if (0 != applix_read_views (state))
+	if (applix_read_cells (state))
 		return -1;
 
-	while (NULL != fgets (buffer, sizeof(buffer), state->file) &&
-	       strncmp (buffer, "Headers And Footers End", 23)) {
-
-		if (!strncmp (buffer, "Row List ", 9)) {
-			char *tmp, *ptr = buffer + 9;
-			Range	r;
-
-			Sheet *sheet = applix_get_sheet (state, &ptr, ' ');
-			if (ptr == NULL)
-				return -1;
-			if (*ptr != '!')
-				return applix_parse_error (state, "Invalid row format");
-
-			r.start.row = r.end.row = strtol (++ptr, &tmp, 10) - 1;
-			if (tmp == ptr || r.start.row < 0 || tmp[0] != ':' || tmp[1] != ' ')
-				return applix_parse_error (state, "Invalid row format row number");
-
-			++tmp;
-			do {
-				unsigned attr_index;
-
-				r.start.col = strtol (ptr = tmp+1, &tmp, 10);
-				if (tmp == ptr || r.start.col < 0 || tmp[0] != '-')
-					return applix_parse_error (state, "Invalid row format start col");
-				r.end.col = strtol (ptr = tmp+1, &tmp, 10);
-				if (tmp == ptr || r.end.col < 0 || tmp[0] != ':')
-					return applix_parse_error (state, "Invalid row format end col");
-				attr_index = strtol (ptr = tmp+1, &tmp, 10);
-				if (tmp != ptr && attr_index >= 2 && attr_index < state->attrs->len+2) {
-					MStyle *style = g_ptr_array_index(state->attrs, attr_index-2);
-					mstyle_ref (style);
-					sheet_style_set_range (sheet, &r, style);
-				} else if (attr_index != 1) /* TODO : What the hell is attr 1 ?? */
-					return applix_parse_error (state, "Invalid row format attr index");
-
-			/* Just for kicks they added a trailing space */
-			} while (tmp[0] && isdigit ((unsigned char)tmp[1]));
-		}
-
-		/* FIXME : Can we really just ignore all of this ? */
-	}
-
-	if (!applix_read_cells (state)) {
-	}
-
 	/* We only need the sheet, the visible cell, and edit pos are already set */
-	if (applix_parse_cellref (state, cur_cell_addr, &sheet, &col, &row, ':'))
+	if (applix_parse_cellref (state, cur_cell_addr, &sheet, &pos, ':'))
 		wb_view_sheet_focus (state->wb_view, sheet);
 
 	return 0;
@@ -1290,7 +1304,7 @@ static gboolean
 cb_remove_expr (gpointer key, gpointer value, gpointer user_data)
 {
 	g_free (key);
-	expr_tree_unref (value);
+	gnm_expr_unref (value);
 	return TRUE;
 }
 static gboolean
@@ -1302,27 +1316,30 @@ cb_remove_style (gpointer key, gpointer value, gpointer user_data)
 }
 
 void
-applix_read (IOContext *io_context, WorkbookView *wb_view, FILE *file)
+applix_read (IOContext *io_context, WorkbookView *wb_view, GsfInput *src)
 {
 	int i;
 	int res;
 	ApplixReadState	state;
 
 	/* Init the state variable */
-	state.file        = file;
+	state.input	  = gsf_input_textline_new (src);
 	state.parse_error = NULL;
 	state.wb_view     = wb_view;
 	state.wb          = wb_view_workbook (wb_view);
-	state.exprs       = g_hash_table_new (&g_int_hash, &g_int_equal);
+	state.exprs       = g_hash_table_new (&g_str_hash, &g_str_equal);
 	state.styles      = g_hash_table_new (&g_str_hash, &g_str_equal);
 	state.colours     = g_ptr_array_new ();
 	state.attrs       = g_ptr_array_new ();
 	state.font_names  = g_ptr_array_new ();
 	state.buffer      = NULL;
+	state.buffer_size = 0;
+	state.line_len    = 80;
 
-	/* Actualy read the workbook */
+	/* Actually read the workbook */
 	res = applix_read_impl (&state);
 
+	g_object_unref (G_OBJECT (state.input));
 	if (state.buffer)
 		g_free (state.buffer);
 
