@@ -84,14 +84,14 @@ static const char *help_complex = {
 	   "@SYNTAX=COMPLEX(real,im[,suffix])\n"
 
 	   "@DESCRIPTION="
-	   "COMPLEX returns a complex number of the form x + yi. "
+	   "COMPLEX returns a complex number of the form x + yi.\n\n"
 	   "@real is the real and @im is the imaginary coefficient of "
 	   "the complex number.  @suffix is the suffix for the imaginary "
-	   "coefficient.  If it is omitted, COMPLEX uses 'i' by default."
+	   "coefficient.  If it is omitted, COMPLEX uses 'i' by default.\n"
 	   "\n"
-	   "If @suffix is neither 'i' nor 'j', COMPLEX returns #VALUE! "
+	   "* If @suffix is neither 'i' nor 'j', COMPLEX returns #VALUE! "
 	   "error.\n"
-	   "This function is Excel compatible. "
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "COMPLEX(1,-1) equals 1-i.\n"
@@ -123,8 +123,10 @@ static const char *help_imaginary = {
 	   "@SYNTAX=IMAGINARY(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMAGINARY returns the imaginary coefficient of a complex "
-	   "number.\n"
-	   "This function is Excel compatible. "
+	   "number.\n\n"
+	   "* If @inumber is not a valid complex number, IMAGINARY returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMAGINARY(\"132-j\") equals -1.\n"
@@ -153,8 +155,10 @@ static const char *help_imabs = {
 	N_("@FUNCTION=IMABS\n"
 	   "@SYNTAX=IMABS(inumber)\n"
 	   "@DESCRIPTION="
-	   "IMABS returns the absolute value of a complex number.\n"
-	   "This function is Excel compatible. "
+	   "IMABS returns the absolute value of a complex number.\n\n"
+	   "* If @inumber is not a valid complex number, IMABS returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMABS(\"2-j\") equals 2.23606798.\n"
@@ -170,7 +174,7 @@ gnumeric_imabs (FunctionEvalInfo *ei, Value **argv)
 	char imunit;
 
 	if (value_get_as_complex (argv[0], &c, &imunit))
-	  return value_new_error (ei->pos, gnumeric_err_VALUE);
+		return value_new_error (ei->pos, gnumeric_err_VALUE);
 
 	if (argv[0]->type != VALUE_STRING)
 		return value_new_error (ei->pos, gnumeric_err_VALUE);
@@ -184,8 +188,10 @@ static const char *help_imreal = {
 	N_("@FUNCTION=IMREAL\n"
 	   "@SYNTAX=IMREAL(inumber)\n"
 	   "@DESCRIPTION="
-	   "IMREAL returns the real coefficient of a complex number.\n"
-	   "This function is Excel compatible. "
+	   "IMREAL returns the real coefficient of a complex number.\n\n"
+	   "* If @inumber is not a valid complex number, IMREAL returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "imreal(\"132-j\") equals 132.\n"
@@ -216,7 +222,10 @@ static const char *help_imconjugate = {
 	   "@SYNTAX=IMCONJUGATE(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMCONJUGATE returns the complex conjugate of a complex number.\n"
-	   "This function is Excel compatible. "
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMCONJUGATE returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMCONJUGATE(\"1-j\") equals 1+j.\n"
@@ -247,7 +256,10 @@ static const char *help_iminv = {
 	   "@SYNTAX=IMINV(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMINV returns the the inverse, or reciprocal, of the complex "
-	   "number z, 1/z = (x - i y)/(x^2 + y^2). " 
+	   "number z (@inumber), where\n\n\t1/z = (x - i y)/(x^2 + y^2).\n" 
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMINV returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMINV(\"1-j\") equals 0.5+0.5j.\n"
@@ -274,8 +286,11 @@ static const char *help_imneg = {
 	N_("@FUNCTION=IMNEG\n"
 	   "@SYNTAX=IMNEG(inumber)\n"
 	   "@DESCRIPTION="
-	   "IMNEG returns the negative of the complex number z, "
-	   "-z = (-x) + i(-y)."
+	   "IMNEG returns the negative of the complex number z (@inumber), "
+	   "where\n\n\t-z = (-x) + i(-y).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMNEG returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMNEG(\"1-j\") equals -1+j.\n"
@@ -303,7 +318,10 @@ static const char *help_imcos = {
 	   "@SYNTAX=IMCOS(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMCOS returns the cosine of a complex number.\n"
-	   "This function is Excel compatible."
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMCOS returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMCOS(\"1+j\") equals 0.833730-0.988898j.\n"
@@ -331,7 +349,10 @@ static const char *help_imtan = {
 	   "@SYNTAX=IMTAN(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMTAN returns the tangent of a complex number.\n"
-	   "This function is Excel compatible. "
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMTAN returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMTAN(\"2-j\") equals -0.2434582-1.1667363j.\n"
@@ -358,8 +379,12 @@ static const char *help_imsec = {
 	N_("@FUNCTION=IMSEC\n"
 	   "@SYNTAX=IMSEC(inumber)\n"
 	   "@DESCRIPTION="
-	   "IMSEC returns the complex secant of the complex number z, "
-	   "sec(z) = 1/cos(z). "
+	   "IMSEC returns the complex secant of the complex number z "
+	   "(@inumber), where\n\n\t"
+	   "sec(z) = 1/cos(z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMSEC returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMSEC(\"2-j\") equals -0.413149-0.687527j.\n"
@@ -387,8 +412,12 @@ static const char *help_imcsc = {
 	N_("@FUNCTION=IMCSC\n"
 	   "@SYNTAX=IMCSC(inumber)\n"
 	   "@DESCRIPTION="
-	   "IMCSC returns the complex cosecant of the complex number z, "
-	   "csc(z) = 1/sin(z). "
+	   "IMCSC returns the complex cosecant of the complex number z "
+	   "(@inumber), where\n\n\t"
+	   "csc(z) = 1/sin(z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMCSC returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMCSC(\"2-j\") equals 0.635494-0.221501j.\n"
@@ -416,8 +445,12 @@ static const char *help_imcot = {
 	N_("@FUNCTION=IMCOT\n"
 	   "@SYNTAX=IMCOT(inumber)\n"
 	   "@DESCRIPTION="
-	   "IMCOT returns the complex cotangent of the complex number z, "
-	   "cot(z) = 1/tan(z). "
+	   "IMCOT returns the complex cotangent of the complex number z "
+	   "(@inumber), where\n\n\t"
+	   "cot(z) = 1/tan(z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMCOT returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMCOT(\"2-j\") equals -0.171384+0.821330j.\n"
@@ -446,7 +479,10 @@ static const char *help_imexp = {
 	   "@SYNTAX=IMEXP(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMEXP returns the exponential of a complex number.\n"
-	   "This function is Excel compatible."
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMEXP returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMEXP(\"2-j\") equals 3.992324-6.217676j.\n"
@@ -474,7 +510,10 @@ static const char *help_imargument = {
 	   "@SYNTAX=IMARGUMENT(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARGUMENT returns the argument theta of a complex number.\n"
-	   "This function is Excel compatible. "
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMARGUMENT returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARGUMENT(\"2-j\") equals -0.463647609.\n"
@@ -505,7 +544,10 @@ static const char *help_imln = {
 	   "natural logarithm is not uniquely defined on complex numbers. "
 	   "You may need to add or subtract an even multiple of pi to the "
 	   "imaginary part.)\n"
-	   "This function is Excel compatible. "
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMLN returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMLN(\"3-j\") equals 1.15129-0.32175j.\n"
@@ -533,7 +575,10 @@ static const char *help_imlog2 = {
 	   "@SYNTAX=IMLOG2(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMLOG2 returns the logarithm of a complex number in base 2.\n"
-	   "This function is Excel compatible. "
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMLOG2 returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMLOG2(\"3-j\") equals 1.66096-0.46419j.\n"
@@ -562,7 +607,10 @@ static const char *help_imlog10 = {
 	   "@SYNTAX=IMLOG10(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMLOG10 returns the logarithm of a complex number in base 10.\n"
-	   "This function is Excel compatible. "
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMLOG10 returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMLOG10(\"3-j\") equals 0.5-0.13973j.\n"
@@ -588,12 +636,15 @@ gnumeric_imlog10 (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_impower = {
 	N_("@FUNCTION=IMPOWER\n"
-	   "@SYNTAX=IMPOWER(inumber,number)\n"
+	   "@SYNTAX=IMPOWER(inumber1,inumber2)\n"
 	   "@DESCRIPTION="
-	   "IMPOWER returns a complex number raised to a power.  @inumber is "
-	   "the complex number to be raised to a power and @number is the "
-	   "power to which you want to raise the complex number.\n"
-	   "This function is Excel compatible."
+	   "IMPOWER returns a complex number raised to a power.  @inumber1 is "
+	   "the complex number to be raised to a power and @inumber2 is the "
+	   "power to which you want to raise it.\n"
+	   "\n"
+	   "* If @inumber1 or @inumber2 are not valid complex numbers, "
+	   "IMPOWER returns #VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMPOWER(\"4-j\",2) equals 15-8j.\n"
@@ -624,10 +675,13 @@ gnumeric_impower (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imdiv = {
 	N_("@FUNCTION=IMDIV\n"
-	   "@SYNTAX=IMDIV(inumber,inumber)\n"
+	   "@SYNTAX=IMDIV(inumber1,inumber2)\n"
 	   "@DESCRIPTION="
 	   "IMDIV returns the quotient of two complex numbers.\n"
-	   "This function is Excel compatible."
+	   "\n"
+	   "* If @inumber1 or @inumber2 are not valid complex numbers, "
+	   "IMDIV returns #VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMDIV(\"2-j\",\"2+j\") equals 0.6-0.8j.\n"
@@ -660,8 +714,10 @@ static const char *help_imsin = {
 	N_("@FUNCTION=IMSIN\n"
 	   "@SYNTAX=IMSIN(inumber)\n"
 	   "@DESCRIPTION="
-	   "IMSIN returns the sine of a complex number.\n"
-	   "This function is Excel compatible."
+	   "IMSIN returns the sine of a complex number.\n\n"
+	   "* If @inumber is not a valid complex number, IMSIN returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMSIN(\"1+j\") equals 1.29846+0.63496j.\n"
@@ -686,10 +742,14 @@ gnumeric_imsin (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imsinh = {
 	N_("@FUNCTION=IMSINH\n"
-	   "@SYNTAX=IMSINH(z)\n"
+	   "@SYNTAX=IMSINH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMSINH returns the complex hyperbolic sine of the complex "
-	   "number z, sinh(z) = (exp(z) - exp(-z))/2.\n"
+	   "number z (@inumber), where\n\n"
+	   "\tsinh(z) = (exp(z) - exp(-z))/2.\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMSINH returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMSINH(\"1+j\") equals 0.63496+1.29846j.\n"
@@ -714,10 +774,13 @@ gnumeric_imsinh (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imcosh = {
 	N_("@FUNCTION=IMCOSH\n"
-	   "@SYNTAX=IMCOSH(z)\n"
+	   "@SYNTAX=IMCOSH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMCOSH returns the complex hyperbolic cosine of the complex "
-	   "number z, cosh(z) = (exp(z) + exp(-z))/2.\n"
+	   "number z (@inumber), where\n\n\tcosh(z) = (exp(z) + exp(-z))/2.\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMCOSH returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMCOSH(\"1+j\") equals 0.83373+0.988898j.\n"
@@ -742,10 +805,13 @@ gnumeric_imcosh (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imtanh = {
 	N_("@FUNCTION=IMTANH\n"
-	   "@SYNTAX=IMTANH(z)\n"
+	   "@SYNTAX=IMTANH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMTANH returns the complex hyperbolic tangent of the complex "
-	   "number z, tanh(z) = sinh(z)/cosh(z).\n"
+	   "number z (@inumber), where\n\n\ttanh(z) = sinh(z)/cosh(z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMTANH returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMTANH(\"1+j\") equals 1.083923+0.2717526j.\n"
@@ -770,10 +836,13 @@ gnumeric_imtanh (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imsech = {
 	N_("@FUNCTION=IMSECH\n"
-	   "@SYNTAX=IMSECH(z)\n"
+	   "@SYNTAX=IMSECH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMSECH returns the complex hyperbolic secant of the complex "
-	   "number z, sech(z) = 1/cosh(z).\n"
+	   "number z (@inumber), where\n\n\tsech(z) = 1/cosh(z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMSECH returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMSECH(\"1+j\") equals 0.498337-0.5910838j.\n"
@@ -798,10 +867,13 @@ gnumeric_imsech (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imcsch = {
 	N_("@FUNCTION=IMCSCH\n"
-	   "@SYNTAX=IMCSCH(z)\n"
+	   "@SYNTAX=IMCSCH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMCSCH returns the complex hyperbolic cosecant of the "
-	   "complex number z, csch(z) = 1/sinh(z).\n"
+	   "complex number z (@inumber), where\n\n\tcsch(z) = 1/sinh(z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMCSCH returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMCSCH(\"1+j\") equals 0.303931-0.621518j.\n"
@@ -826,10 +898,13 @@ gnumeric_imcsch (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imcoth = {
 	N_("@FUNCTION=IMCOTH\n"
-	   "@SYNTAX=IMCOTH(z)\n"
+	   "@SYNTAX=IMCOTH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMCOTH returns the complex hyperbolic cotangent of the complex "
-	   "number z, coth(z) = 1/tanh(z).\n"
+	   "number z (@inumber) where,\n\n\tcoth(z) = 1/tanh(z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMCOTH returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMCOTH(\"1+j\") equals 0.868014-0.217622j.\n"
@@ -854,12 +929,15 @@ gnumeric_imcoth (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarcsin = {
 	N_("@FUNCTION=IMARCSIN\n"
-	   "@SYNTAX=IMARCSIN(z)\n"
+	   "@SYNTAX=IMARCSIN(inumber)\n"
 	   "@DESCRIPTION="
-	   "IMARCSIN returns the complex arcsine of the complex number z, "
-	   "arcsin(z). The branch cuts are on the real axis, less than -1 "
+	   "IMARCSIN returns the complex arcsine of the complex number "
+	   "@inumber. The branch cuts are on the real axis, less than -1 "
 	   "and greater than 1.\n"
 	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCSIN returns "
+	   "#VALUE! error.\n"
+	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCSIN(\"1+j\") equals 0.6662394+1.061275j.\n"
 	   "\n"
@@ -883,12 +961,15 @@ gnumeric_imarcsin (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarccos = {
 	N_("@FUNCTION=IMARCCOS\n"
-	   "@SYNTAX=IMARCCOS(z)\n"
+	   "@SYNTAX=IMARCCOS(inumber)\n"
 	   "@DESCRIPTION="
-	   "IMARCCOS returns the complex arccosine of the complex number z, "
-	   "arccos(z). The branch cuts are on the real axis, less than -1 "
+	   "IMARCCOS returns the complex arccosine of the complex number "
+	   "@inumber. The branch cuts are on the real axis, less than -1 "
 	   "and greater than 1.\n"
 	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCCOS returns "
+	   "#VALUE! error.\n"
+	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCCOS(\"1+j\") equals 0.9045569-1.061275j.\n"
 	   "\n"
@@ -912,12 +993,15 @@ gnumeric_imarccos (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarctan = {
 	N_("@FUNCTION=IMARCTAN\n"
-	   "@SYNTAX=IMARCTAN(z)\n"
+	   "@SYNTAX=IMARCTAN(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCTAN returns the complex arctangent of the complex number "
-	   "z, arctan(z). The branch cuts are on the imaginary axis, "
+	   "inumber. The branch cuts are on the imaginary axis, "
 	   "below -i and above i.\n"
 	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCTAN returns "
+	   "#VALUE! error.\n"
+	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCTAN(\"1+j\") equals 1.0172220+0.4023595j.\n"
 	   "\n"
@@ -941,10 +1025,13 @@ gnumeric_imarctan (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarcsec = {
 	N_("@FUNCTION=IMARCSEC\n"
-	   "@SYNTAX=IMARCSEC(z)\n"
+	   "@SYNTAX=IMARCSEC(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCSEC returns the complex arcsecant of the complex number "
-	   "z, arcsec(z) = arccos(1/z).\n"
+	   "z (@inumber), where\n\n\tarcsec(z) = arccos(1/z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCSEC returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCSEC(\"1+j\") equals 1.1185179+0.5306375j.\n"
@@ -969,10 +1056,13 @@ gnumeric_imarcsec (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarccsc = {
 	N_("@FUNCTION=IMARCCSC\n"
-	   "@SYNTAX=IMARCCSC(z)\n"
+	   "@SYNTAX=IMARCCSC(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCCSC returns the complex arccosecant of the complex "
-	   "number z, arccsc(z) = arcsin(1/z).\n"
+	   "number z (@inumber), where\n\n\tarccsc(z) = arcsin(1/z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCCSC returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCCSC(\"1+j\") equals 0.45227845-0.5306375j.\n"
@@ -997,10 +1087,13 @@ gnumeric_imarccsc (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarccot = {
 	N_("@FUNCTION=IMARCCOT\n"
-	   "@SYNTAX=IMARCCOT(z)\n"
+	   "@SYNTAX=IMARCCOT(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCCOT returns the complex arccotangent of the complex "
-	   "number z, arccot(z) = arctan(1/z).\n"
+	   "number z (@inumber), where\n\n\tarccot(z) = arctan(1/z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCCOT returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCCOT(\"1+j\") equals 0.553574+0.4023595j.\n"
@@ -1025,12 +1118,15 @@ gnumeric_imarccot (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarcsinh = {
 	N_("@FUNCTION=IMARCSINH\n"
-	   "@SYNTAX=IMARCSINH(z)\n"
+	   "@SYNTAX=IMARCSINH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCSINH returns the complex hyperbolic arcsine of the "
-	   "complex number z, arcsinh(z). The branch cuts are on the "
+	   "complex number @inumber. The branch cuts are on the "
 	   "imaginary axis, below -i and above i.\n"
 	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCSINH returns "
+	   "#VALUE! error.\n"
+	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCSINH(\"1+j\") equals 1.061275+0.6662394j.\n"
 	   "\n"
@@ -1054,12 +1150,15 @@ gnumeric_imarcsinh (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarccosh = {
 	N_("@FUNCTION=IMARCCOSH\n"
-	   "@SYNTAX=IMARCCOSH(z)\n"
+	   "@SYNTAX=IMARCCOSH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCCOSH returns the complex hyperbolic arccosine of the "
-	   "complex number z, arccosh(z). The branch cut is on the real "
+	   "complex number @inumber. The branch cut is on the real "
 	   "axis, less than 1.\n"
 	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCCOSH returns "
+	   "#VALUE! error.\n"
+	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCCOSH(\"1+j\") equals 1.06127506+0.904557j.\n"
 	   "\n"
@@ -1083,12 +1182,15 @@ gnumeric_imarccosh (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarctanh = {
 	N_("@FUNCTION=IMARCTANH\n"
-	   "@SYNTAX=IMARCTANH(z)\n"
+	   "@SYNTAX=IMARCTANH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCTANH returns the complex hyperbolic arctangent of the "
-	   "complex number z, arctanh(z). The branch cuts are on the "
+	   "complex number @inumber. The branch cuts are on the "
 	   "real axis, less than -1 and greater than 1.\n"
 	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCTANH returns "
+	   "#VALUE! error.\n"
+	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCTANH(\"1+j\") equals 0.4023595+1.0172220j.\n"
 	   "\n"
@@ -1112,10 +1214,14 @@ gnumeric_imarctanh (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarcsech = {
 	N_("@FUNCTION=IMARCSECH\n"
-	   "@SYNTAX=IMARCSECH(z)\n"
+	   "@SYNTAX=IMARCSECH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCSECH returns the complex hyperbolic arcsecant of the "
-	   "complex number z, arcsech(z) = arccosh(1/z).\n"
+	   "complex number z (@inumber), where\n\n\t"
+	   "arcsech(z) = arccosh(1/z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCSECH returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCSECH(\"1+j\") equals 0.5306375-1.118518j.\n"
@@ -1140,10 +1246,13 @@ gnumeric_imarcsech (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarccsch = {
 	N_("@FUNCTION=IMARCCSCH\n"
-	   "@SYNTAX=IMARCCSCH(z)\n"
+	   "@SYNTAX=IMARCCSCH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCCSCH returns the complex hyperbolic arccosecant of the "
-	   "complex number z, arccsch(z) = arcsin(1/z).\n"
+	   "complex number z (@inumber), where\n\n\tarccsch(z) = arcsin(1/z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCCSCH returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCCSCH(\"1+j\") equals 0.5306375-0.452278j.\n"
@@ -1168,10 +1277,14 @@ gnumeric_imarccsch (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imarccoth = {
 	N_("@FUNCTION=IMARCCOTH\n"
-	   "@SYNTAX=IMARCCOTH(z)\n"
+	   "@SYNTAX=IMARCCOTH(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMARCCOTH returns the complex hyperbolic arccotangent of the "
-	   "complex number z, arccoth(z) = arctanh(1/z).\n"
+	   "complex number z (@inumber), where\n\n\t"
+	   "arccoth(z) = arctanh(1/z).\n"
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMARCCOTH returns "
+	   "#VALUE! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMARCCOTH(\"1+j\") equals 0.40235948-0.5535744j.\n"
@@ -1199,7 +1312,10 @@ static const char *help_imsqrt = {
 	   "@SYNTAX=IMSQRT(inumber)\n"
 	   "@DESCRIPTION="
 	   "IMSQRT returns the square root of a complex number.\n"
-	   "This function is Excel compatible."
+	   "\n"
+	   "* If @inumber is not a valid complex number, IMSQRT returns "
+	   "#VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMSQRT(\"1+j\") equals 1.09868+0.4550899j.\n"
@@ -1224,10 +1340,13 @@ gnumeric_imsqrt (FunctionEvalInfo *ei, Value **argv)
 
 static const char *help_imsub = {
 	N_("@FUNCTION=IMSUB\n"
-	   "@SYNTAX=IMSUB(inumber,inumber)\n"
+	   "@SYNTAX=IMSUB(inumber1,inumber2)\n"
 	   "@DESCRIPTION="
 	   "IMSUB returns the difference of two complex numbers.\n"
-	   "This function is Excel compatible."
+	   "\n"
+	   "* If @inumber1 or @inumber2 are not valid complex numbers, "
+	   "IMSUB returns #VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMSUB(\"3-j\",\"2+j\") equals 1-2j.\n"
@@ -1258,7 +1377,10 @@ static const char *help_improduct = {
 	   "@SYNTAX=IMPRODUCT(inumber1[,inumber2,...])\n"
 	   "@DESCRIPTION="
 	   "IMPRODUCT returns the product of given complex numbers.\n"
-	   "This function is Excel compatible."
+	   "\n"
+	   "* If any of the @inumbers are not valid complex numbers, "
+	   "IMPRODUCT returns #VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMPRODUCT(\"2-j\",\"4-2j\") equals 6-8j.\n"
@@ -1324,10 +1446,13 @@ gnumeric_improduct (FunctionEvalInfo *ei, GnmExprList *expr_node_list)
 
 static const char *help_imsum = {
 	N_("@FUNCTION=IMSUM\n"
-	   "@SYNTAX=IMSUM(inumber,inumber)\n"
+	   "@SYNTAX=IMSUM(inumber1,inumber2)\n"
 	   "@DESCRIPTION="
 	   "IMSUM returns the sum of two complex numbers.\n"
-	   "This function is Excel compatible."
+	   "\n"
+	   "* If @inumber1 or @inumber2 are not valid complex numbers, "
+	   "IMSUM returns #VALUE! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "IMSUM(\"2-4j\",\"9-j\") equals 11-5j.\n"
@@ -1442,28 +1567,3 @@ const ModulePluginFunctionInfo complex_functions[] = {
 	  gnumeric_imarccoth, NULL, NULL, NULL },
         {NULL}
 };
-
-/* FIXME: Should be merged into the above.  */
-static const struct {
-	const char *func;
-	AutoFormatTypes typ;
-} af_info[] = {
-	{ NULL, AF_UNKNOWN }
-};
-
-void
-plugin_init (void)
-{
-	int i;
-	for (i = 0; af_info[i].func; i++)
-		auto_format_function_result_by_name (af_info[i].func,
-						     af_info[i].typ);
-}
-
-void
-plugin_cleanup (void)
-{
-	int i;
-	for (i = 0; af_info[i].func; i++)
-		auto_format_function_result_remove (af_info[i].func);
-}
