@@ -7,6 +7,7 @@
  *   Jody Goldberg (jody@gnome.org)
  *   Morten Welinder (terra@diku.dk)
  *   Almer S. Tigelaar (almer@gnome.org)
+ *   Harlan Grove
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +22,12 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * Many thanks to Harlan Grove for his excellent characterization and writeup
+ * of the multitude of different potential arguments across the various
+ * different spreadsheets.  Although neither the code is not his, the set of
+ * attributes, and the comments on their behviour are.  Hence he holds partial
+ * copyright on the CELL implementation.
  */
 #include <gnumeric-config.h>
 #include <gnumeric.h>
@@ -109,19 +116,19 @@ static const char *help_cell = {
 
 	   "@DESCRIPTION="
 	   "CELL returns information about the formatting, location, or "
-	   "contents of a cell. "
+	   "contents of a cell.\n"
 	   "\n"
-	   "@type specifies the type of information you want to obtain:\n "
-	   "     address       Returns the given cell reference as text.\n"
-	   "     col           Returns the number of the column in @ref.\n"
-	   "     contents      Returns the contents of the cell in @ref.\n"
-	   "     format        Returns the code of the format of the cell.\n"
-	   "     parentheses   Returns 1 if @ref contains a negative value\n"
-	   "                   and it's format displays it with parentheses.\n"
-	   "     row           Returns the number of the row in @ref.\n"
-	   "     width         Returns the column width.\n"
+	   "@type specifies the type of information you want to obtain:\n\n"
+	   "  address    \tReturns the given cell reference as text.\n"
+	   "  col        \t\tReturns the number of the column in @ref.\n"
+	   "  contents   \tReturns the contents of the cell in @ref.\n"
+	   "  format     \t\tReturns the code of the format of the cell.\n"
+	   "  parentheses\tReturns 1 if @ref contains a negative value\n"
+	   "             \t\tand it's format displays it with parentheses.\n"
+	   "  row        \t\tReturns the number of the row in @ref.\n"
+	   "  width      \t\tReturns the column width.\n"
 	   "\n"
-           "This function is Excel compatible. "
+           "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "CEll(\"format\",A1) returns the code of the format of the cell A1.\n"
@@ -147,7 +154,7 @@ static const translate_t translate_table[] = {
 	{ "0.00%", "P2" },
 	{ "0.00e+00", "S2" },
 	{ "# ?/?", "G" },
-	{ "# ?" "?/?" "?", "G" },   /* Don't accidentally use trigraphs here.  */
+	{ "# ?" "?/?" "?", "G" },   /* Don't accidentally use trigraphs here. */
 	{ "m/d/yy", "D4" },
 	{ "m/d/yy h:mm", "D4" },
 	{ "mm/dd/yy", "D4" },
@@ -168,7 +175,8 @@ translate_cell_format (StyleFormat const *format)
 {
 	int i;
 	char *fmt;
-	const int translate_table_count = sizeof (translate_table) / sizeof(translate_t);
+	const int translate_table_count = sizeof (translate_table) /
+		sizeof(translate_t);
 
 	if (format == NULL)
 		return value_new_string ("G");
@@ -207,51 +215,99 @@ static Value *
 gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 {
 	const char *info_type = value_peek_string (argv[0]);
-	CellRef ref = argv [1]->v_range.cell.a;
+	CellRef const *ref = &argv [1]->v_range.cell.a;
 
+	/* from CELL - limited usefulness! */
 	if (!g_strcasecmp(info_type, "address")) {
-		/* Reference of the first cell in reference, as text. */
-		return value_new_string (cell_coord_name (ref.col, ref.row));
-	} else if (!g_strcasecmp (info_type, "col")) {
-		return value_new_int (ref.col + 1);
+		ParsePos pp;
+		char *ref_name = cellref_name (ref,
+			parse_pos_init_evalpos (&pp, ei->pos), TRUE);
+		return value_new_string_nocopy (ref_name);
+
+	/* from later 123 versions - USEFUL! */
+	} else if (!g_strcasecmp(info_type, "coord")) {
+		ParsePos pp;
+		CellRef tmp = *ref;
+		char *ref_name;
+
+		if (tmp.sheet == NULL)
+			tmp.sheet = ei->pos->sheet;
+		ref_name = cellref_name (&tmp,
+			parse_pos_init_evalpos (&pp, ei->pos), FALSE);
+		return value_new_string_nocopy (ref_name);
+
+	/* from CELL - pointless - use COLUMN instead! */
+	} else if (!g_strcasecmp (info_type, "col") ||
+		   !g_strcasecmp (info_type, "column")) {
+		return value_new_int (ref->col + 1);
+
+	/* from CELL - pointless - use ROW instead! */
+	} else if (!g_strcasecmp (info_type, "row")) {
+		return value_new_int (ref->row + 1);
+
+	/* from CELL - limited usefulness
+	 * NOTE: differences between Excel & 123 - Excel's returns 1 whenever
+	 * there's a color specified for EITHER positive OR negative values
+	 * in the number format, e.g., 1 for format "[Black]0;-0;0" but not
+	 * for format "0;-0;[Green]0"
+	 * Another place where Excel doesn't conform to it's documentation!
+	 */
 	} else if (!g_strcasecmp (info_type, "color")) {
-		FormatCharacteristics info = retrieve_format_info (ei->pos->sheet,
-								   ref.col,
-								   ref.row);
+		FormatCharacteristics info =
+			retrieve_format_info (ei->pos->sheet, ref->col, ref->row);
 
 		/* 0x01 = first bit (1) indicating negative colors */
 		return (info.negative_fmt & 0x01) ? value_new_int (1) :
 			value_new_int (0);
-	} else if (!g_strcasecmp (info_type, "contents")) {
-		Cell *cell = sheet_cell_get (ei->pos->sheet, ref.col, ref.row);
 
+	/* absolutely pointless - compatibility only */
+	} else if (!g_strcasecmp (info_type, "contents") ||
+		   !g_strcasecmp (info_type, "value")) {
+		Cell const *cell =
+			sheet_cell_get (ei->pos->sheet, ref->col, ref->row);
 		if (cell && cell->value)
 			return value_duplicate (cell->value);
 		return value_new_empty ();
-	} else if (!g_strcasecmp (info_type, "filename"))	{
-		char *name = ei->pos->sheet->workbook->filename;
+
+	/* from CELL - limited usefulness!
+	 * A testament to Microsoft's hypocracy! They could include this from
+	 * 123R2.2 (it wasn't in 123R2.0x), modify it in Excel 4.0 to include
+	 * the worksheet name, but they can't make any other changes to CELL?!
+	 */
+	} else if (!g_strcasecmp (info_type, "filename")) {
+		char const *name = ei->pos->sheet->workbook->filename;
 
 		if (name == NULL)
 			return value_new_string ("");
 		else
 			return value_new_string (name);
+
+	/* from CELL */
+	/* Backwards compatibility w/123 - unnecessary */
 	} else if (!g_strcasecmp (info_type, "format")) {
-		MStyle *mstyle = sheet_style_get (ei->pos->sheet, ref.col,
-						  ref.row);
+		MStyle const *mstyle =
+			sheet_style_get (ei->pos->sheet, ref->col, ref->row);
 
 		return translate_cell_format (mstyle_get_format (mstyle));
+
+	/* from CELL */
+	/* Backwards compatibility w/123 - unnecessary */
 	} else if (!g_strcasecmp (info_type, "parentheses")) {
-		FormatCharacteristics info = retrieve_format_info (ei->pos->sheet,
-								   ref.col,
-								   ref.row);
+		FormatCharacteristics info =
+			retrieve_format_info (ei->pos->sheet, ref->col, ref->row);
 
 		/* 0x02 = second bit (2) indicating parentheses */
 		return (info.negative_fmt & 0x02) ? value_new_int (1) :
 			value_new_int (0);
-	} else if (!g_strcasecmp (info_type, "prefix")) {
-		MStyle *mstyle = sheet_style_get (ei->pos->sheet, ref.col,
-						  ref.row);
-		Cell *cell = sheet_cell_get (ei->pos->sheet, ref.col, ref.row);
+
+	/* from CELL */
+	/* Backwards compatibility w/123 - unnecessary */
+	} else if (!g_strcasecmp (info_type, "prefix") ||
+		   !g_strcasecmp (info_type, "prefixcharacter")) {
+		MStyle const *mstyle =
+			sheet_style_get (ei->pos->sheet, ref->col, ref->row);
+		Cell const *cell =
+			sheet_cell_get (ei->pos->sheet, ref->col, ref->row);
 
 		if (cell && cell->value && cell->value->type == VALUE_STRING) {
 			switch (mstyle_get_align_h (mstyle)) {
@@ -264,16 +320,43 @@ gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 			}
 		}
 		return value_new_string ("");
-	} else if (!g_strcasecmp (info_type, "protect")) {
-		MStyle const *mstyle = sheet_style_get (ei->pos->sheet, ref.col,
-							ref.row);
-		return value_new_int (mstyle_get_content_locked (mstyle) ? 1 : 0);
-	} else if (!g_strcasecmp (info_type, "row")) {
-		return value_new_int (ref.row + 1);
-	} else if (!g_strcasecmp (info_type, "type")) {
-		Cell *cell;
 
-		cell = sheet_cell_get (ei->pos->sheet, ref.col, ref.row);
+	/* from CELL */
+	} else if (!g_strcasecmp (info_type, "locked") ||
+		   !g_strcasecmp (info_type, "protect")) {
+		MStyle const *mstyle =
+			sheet_style_get (ei->pos->sheet, ref->col, ref->row);
+		return value_new_int (mstyle_get_content_locked (mstyle) ? 1 : 0);
+
+    /* different characteristics grouped for efficiency
+     * TYPE needed for backward compatibility w/123 but otherwise useless
+     * DATATYPE and FORMULATYPE are options in later 123 versions' @CELL
+     * no need for them but included to make 123 conversion easier
+    Case "datatype", "formulatype", "type"
+        t = Left(prop, 1)
+        
+            rv = IIf( t = "f" And rng.HasFormula, "f", "" )
+
+            If rng.formula = "" Then
+                rv = rv & "b"
+            ElseIf IsNumeric("0" & CStr(rng.Value)) _
+              Or (t = "t" And IsError(rng.Value)) Then
+                rv = rv & "v"
+            ElseIf rng.Value = CVErr(xlErrNA) Then
+                rv = rv & "n"
+            ElseIf IsError(rng.Value) Then
+                rv = rv & "e"
+            Else
+                rv = rv & "l"
+            End If
+        End If
+	*/
+
+	} else if (!g_strcasecmp (info_type, "type") ||
+		   !g_strcasecmp (info_type, "datatype") ||
+		   !g_strcasecmp (info_type, "formulatype")) {
+		Cell const *cell =
+			sheet_cell_get (ei->pos->sheet, ref->col, ref->row);
 		if (cell && cell->value) {
 			if (cell->value->type == VALUE_STRING)
 				return value_new_string ("l");
@@ -281,8 +364,12 @@ gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 				return value_new_string ("v");
 		}
 		return value_new_string ("b");
-	} else if (!g_strcasecmp (info_type, "width")) {
-		ColRowInfo const *info = sheet_col_get_info (ei->pos->sheet, ref.col);
+
+	/* from CELL */
+	} else if (!g_strcasecmp (info_type, "width") ||
+		   !g_strcasecmp (info_type, "columnwidth")) {
+		ColRowInfo const *info =
+			sheet_col_get_info (ei->pos->sheet, ref->col);
 		double charwidth;
 		int    cellwidth;
 
@@ -292,7 +379,7 @@ gnumeric_cell (FunctionEvalInfo *ei, Value **argv)
 		return value_new_int (rint (cellwidth / charwidth));
 	}
 
-	return value_new_error (ei->pos, _("Unknown info_type"));
+	return value_new_error (ei->pos, gnumeric_err_VALUE);
 }
 
 #warning implement this
@@ -311,12 +398,6 @@ Function ExtCell( _
   Optional rng As Variant, _
   Optional rar As Boolean = False _
 ) As Variant
-   /*Copyright (C) 2002, Harlan Grove
-    *This is free software. It s use in derivative works is covered
-    *under the terms of the Free Software Foundation s GPL. See
-    *http://www.gnu.org/copyleft/gpl.html
-    */
-
     Dim ws As Worksheet, wb As Workbook, rv As Variant
     Dim i As Long, j As Long, m As Long, n As Long, t As String
 
@@ -363,17 +444,6 @@ Function ExtCell( _
             )
         End If
     
-    Case "address"  /* from CELL - limited usefulness! */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = rng.Cells(i, j).Address
-                Next j
-            Next i
-        Else
-            rv = rng.Address
-        End If
-    
     Case "backgroundcolor"  /* from later 123 versions - USEFUL! */
         If rar Then
             For i = 1 To m
@@ -423,41 +493,6 @@ Function ExtCell( _
             rv = rng.Borders(xlEdgeBottom).ColorIndex
         End If
 
-    Case "col", "column"  /* from CELL - pointless - use COLUMN instead! */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = rng.Cells(i, j).Column
-                Next j
-            Next i
-        Else
-            rv = rng.Column
-        End If
-
-    Case "color"  /* from CELL - limited usefulness */
-    /* NOTE: differences between Excel & 123 - Excel's returns 1 whenever */
-    /* there's a color specified for EITHER positive OR negative values */
-    /* in the number format, e.g., 1 for format "[Black]0;-0;0" but not */
-    /* for format "0;-0;[Green]0" */
-    /* Another place where Excel doesn't conform to it's documentation! */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = Evaluate( _
-                      "=CELL(""Color""," & _
-                      rng.Cells(i, j).Address(True, True, xlA1, True) & _
-                      ")" _
-                    )
-                Next j
-            Next i
-        Else
-            rv = Evaluate( _
-              "=CELL(""Color""," & _
-              rng.CellsAddress(True, True, xlA1, True) & _
-              ")" _
-            )
-        End If
-
     Case "columnhidden"
         If rar Then
             For i = 1 To m
@@ -488,21 +523,6 @@ Function ExtCell( _
             End If
         End If
 
-    Case "contents", "value"  /* absolutely pointless - compatibility only */
-        /* DOME - nothing more to do! */
-
-    Case "coord"  /* from later 123 versions - USEFUL! */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = "'" & ws.Name & "'!" & _
-                      rng.Cells(i, j).Address
-                Next j
-            Next i
-        Else
-            rv = "'" & ws.Name & "'!" & rng.Address
-        End If
-
     Case "currentarray"  /* NOTE: returns Range addresses! */
         If rar Then
             For i = 1 To m
@@ -525,57 +545,6 @@ Function ExtCell( _
             rv = rng.CurrentRegion.Address
         End If
 
-     /* different characteristics grouped for efficiency */
-    /* TYPE needed for backward compatibility w/123 but otherwise useless */
-    /* DATATYPE and FORMULATYPE are options in later 123 versions' @CELL */
-    /* no need for them but included to make 123 conversion easier */
-    Case "datatype", "formulatype", "type"
-        t = Left(prop, 1)
-        
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = IIf( _
-                      t = "f" And rng.Cells(i, j).HasFormula, _
-                      "f", _
-                      "" _
-                    )
-                    
-                    If rng.Cells(i, j).formula = "" Then
-                        rv(i, j) = rv(i, j) & "b"
-                    ElseIf IsNumeric("0" & CStr(rng.Cells(i, j).Value)) _
-                      Or (t = "t" And IsError(rng.Cells(i, j).Value)) Then
-                        rv(i, j) = rv(i, j) & "v"
-                    ElseIf rng.Cells(i, j).Value = CVErr(xlErrNA) Then
-                        rv(i, j) = rv(i, j) & "n"
-                    ElseIf IsError(rng.Cells(i, j).Value) Then
-                        rv(i, j) = rv(i, j) & "e"
-                    Else
-                        rv(i, j) = rv(i, j) & "l"
-                    End If
-                Next j
-            Next i
-        Else
-            rv = IIf( _
-              t = "f" And rng.HasFormula, _
-              "f", _
-              "" _
-            )
-
-            If rng.formula = "" Then
-                rv = rv & "b"
-            ElseIf IsNumeric("0" & CStr(rng.Value)) _
-              Or (t = "t" And IsError(rng.Value)) Then
-                rv = rv & "v"
-            ElseIf rng.Value = CVErr(xlErrNA) Then
-                rv = rv & "n"
-            ElseIf IsError(rng.Value) Then
-                rv = rv & "e"
-            Else
-                rv = rv & "l"
-            End If
-        End If
-
     Case "filedate"  /* from later 123 versions - limited usefulness! */
         t = wb.BuiltinDocumentProperties("Last Save Time")  /* invariant! */
 
@@ -589,27 +558,6 @@ Function ExtCell( _
             rv = t
         End If
 
-    Case "filename"  /* from CELL - limited usefulness! */
-    /* A testament to Microsoft's hypocracy! They could include this from
-     * 123R2.2 (it wasn't in 123R2.0x), modify it in Excel 4.0 to include
-     * the worksheet name, but they can't make any other changes to CELL?!
-     */
-        t = Evaluate( _
-          "=CELL(""Filename""," & _
-          rng.Address(True, True, xlA1, True) & _
-          ")" _
-        )  /* invariant! */
-
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = t
-                Next j
-            Next i
-        Else
-            rv = t
-        End If
-
     Case "fontface", "fontname", "typeface"  /* from later 123 versions */
         If rar Then
             For i = 1 To m
@@ -632,26 +580,6 @@ Function ExtCell( _
             rv = rng.Font.Size
         End If
 
-    Case "format"  /* from CELL */
-    /* Backwards compatibility w/123 - unnecessary */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = Evaluate( _
-                      "=CELL(""Format""," & _
-                      rng.Cells(i, j).Address(True, True, xlA1, True) & _
-                      ")" _
-                    )
-                Next j
-            Next i
-        Else
-            rv(i, j) = Evaluate( _
-              "=CELL(""Format""," & _
-              rng.Address(True, True, xlA1, True) & _
-              ")" _
-            )
-        End If
-
     Case "formula"
         If rar Then
             For i = 1 To m
@@ -857,17 +785,6 @@ Function ExtCell( _
             rv = rng.Borders(xlEdgeLeft).ColorIndex
         End If
 
-    Case "locked", "protect"  /* from CELL */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = CLng(rng.Cells(i, j).Locked)
-                Next j
-            Next i
-        Else
-            rv = CLng(rng.Locked)
-        End If
-
     Case "mergearea"  /* NOTE: returns Range addresses! */
         If rar Then
             For i = 1 To m
@@ -934,26 +851,6 @@ Function ExtCell( _
             rv = rng.Orientation
         End If
 
-    Case "parentheses"  /* from CELL */
-    /* Backwards compatibility w/123 - unnecessary */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = Evaluate( _
-                      "=CELL(""Parentheses""," & _
-                      rng.Cells(i, j).Address(True, True, xlA1, True) & _
-                      ")" _
-                    )
-                Next j
-            Next i
-        Else
-            rv = Evaluate( _
-              "=CELL(""Parentheses""," & _
-              rng.Address(True, True, xlA1, True) & _
-              ")" _
-            )
-        End If
-
     Case "pattern"  /* from later 123 versions */
         If rar Then
             For i = 1 To m
@@ -979,26 +876,6 @@ Function ExtCell( _
             rv = rng.Interior.PatternColorIndex
         End If
 
-    Case "prefix", "prefixcharacter"  /* from CELL */
-    /* Backwards compatibility w/123 - unnecessary */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = Evaluate( _
-                      "=CELL(""Prefix""," & _
-                      rng.Cells(i, j).Address(True, True, xlA1, True) & _
-                      ")" _
-                    )
-                Next j
-            Next i
-        Else
-            rv = Evaluate( _
-              "=CELL(""Prefix""," & _
-              rng.Address(True, True, xlA1, True) & _
-              ")" _
-            )
-        End If
-
     Case "rightborder"  /* from later 123 versions */
     /* Note: many possible return values! wrap inside SIGN to test T/F */
         If rar Then
@@ -1025,17 +902,6 @@ Function ExtCell( _
             rv = rng.Borders(xlEdgeRight).ColorIndex
         End If
 
-    Case "row"  /* from CELL - pointless - use ROW instead! */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = rng.Cells(i, j).Row
-                Next j
-            Next i
-        Else
-            rv = rng.Row
-        End If
-
     Case "rowhidden"
         If rar Then
             For i = 1 To m
@@ -1257,17 +1123,6 @@ Function ExtCell( _
             rv = t
         End If
 
-    Case "width", "columnwidth"  /* from CELL */
-        If rar Then
-            For i = 1 To m
-                For j = 1 To n
-                    rv(i, j) = rng.Cells(i, j).Width
-                Next j
-            Next i
-        Else
-            rv = rng.Width
-        End If
-
     Case "workbookfullname"  /* same as FileName in later 123 versions */
         t = wb.FullName  /* invariant */
 
@@ -1389,8 +1244,8 @@ static const char *help_countblank = {
            "@SYNTAX=COUNTBLANK(range)\n"
 
            "@DESCRIPTION="
-           "COUNTBLANK returns the number of blank cells in a @range.\n"
-	   "This function is Excel compatible. "
+           "COUNTBLANK returns the number of blank cells in a @range.\n\n"
+	   "* This function is Excel compatible.\n"
            "\n"
 	   "@EXAMPLES=\n"
 	   "COUNTBLANK(A1:A20) returns the number of blank cell in A1:A20.\n"
@@ -1415,7 +1270,8 @@ gnumeric_countblank (FunctionEvalInfo *ei, Value **args)
 		value_area_get_height (ei->pos, args[0]) *
 		value_area_get_width (ei->pos, args[0]);
 
-	workbook_foreach_cell_in_range (ei->pos, args[0], CELL_ITER_IGNORE_BLANK,
+	workbook_foreach_cell_in_range (ei->pos, args[0],
+					CELL_ITER_IGNORE_BLANK,
 					&cb_countblank, &count);
 
 	return value_new_int (count);
@@ -1429,19 +1285,19 @@ static const char *help_info = {
 
 	   "@DESCRIPTION="
 	   "INFO returns information about the current operating environment. "
+	   "\n\n"
+	   "@type is the type of information you want to obtain:\n\n"
+	   "  memavail \tReturns the amount of memory available, bytes.\n"
+	   "  memused  \tReturns the amount of memory used (bytes).\n"
+	   "  numfile  \t\tReturns the number of active worksheets.\n"
+	   "  osversion\t\tReturns the operating system version.\n"
+	   "  recalc   \t\tReturns the recalculation mode (automatic).\n"
+	   "  release  \t\tReturns the version of Gnumeric as text.\n"
+	   "  system   \t\tReturns the name of the environment.\n"
+	   "  totmem   \t\tReturns the amount of total memory available.\n"
 	   "\n"
-	   "@type is the type of information you want to obtain:\n"
-	   "    memavail        Returns the amount of memory available (bytes).\n"
-	   "    memused         Returns the amount of memory used (bytes).\n"
-	   "    numfile         Returns the number of active worksheets.\n"
-	   "    osversion       Returns the operating system version.\n"
-	   "    recalc          Returns the recalculation mode (automatic).\n"
-	   "    release         Returns the version of Gnumeric as text.\n"
-	   "    system          Returns the name of the environment.\n"
-	   "    totmem          Returns the amount of total memory available.\n"
-	   "\n"
-	   "This function is Excel compatible, except that types directory "
-	   "and origin are not implemented. "
+	   "* This function is Excel compatible, except that types directory "
+	   "and origin are not implemented.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "INFO(\"system\") returns \"Linux\" on a Linux system.\n"
@@ -1519,8 +1375,8 @@ static const char *help_iserror = {
 	   "@SYNTAX=ISERROR(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISERROR returns a TRUE value if the expression has an error.\n"
-	   "This function is Excel compatible. "
+	   "ISERROR returns a TRUE value if the expression has an error.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISERROR(NA()) equals TRUE.\n"
@@ -1542,7 +1398,8 @@ gnumeric_check_for_err (FunctionEvalInfo *ei, GnmExprList *expr_node_list,
 				       _("Argument mismatch"));
 		return NULL;
 	}
-	tmp = gnm_expr_eval (expr_node_list->data, ei->pos, GNM_EXPR_EVAL_STRICT);
+	tmp = gnm_expr_eval (expr_node_list->data, ei->pos,
+			     GNM_EXPR_EVAL_STRICT);
 
 	if (tmp != NULL) {
 		if (tmp->type == VALUE_ERROR)
@@ -1574,8 +1431,8 @@ static const char *help_isna = {
 	   "@SYNTAX=ISNA(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISNA returns TRUE if the value is the #N/A error value.\n"
-	   "This function is Excel compatible. "
+	   "ISNA returns TRUE if the value is the #N/A error value.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISNA(NA()) equals TRUE.\n"
@@ -1609,8 +1466,8 @@ static const char *help_iserr = {
 	   "@SYNTAX=ISERR(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISERR returns TRUE if the value is any error value except #N/A.\n"
-	   "This function is Excel compatible. "
+	   "ISERR returns TRUE if the value is any error value except #N/A.\n\n"
+	   "* This function is Excel compatible. "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISERR(NA()) return FALSE.\n"
@@ -1641,14 +1498,14 @@ static const char *help_error_type = {
 
 	   "@DESCRIPTION="
 	   "ERROR.TYPE returns an error number corresponding to the given "
-	   "error value.  The error numbers for error values are\n"
-	   "#DIV/0!    2\n"
-	   "#VALUE!    3\n"
-	   "#REF!      4\n"
-	   "#NAME?     5\n"
-	   "#NUM!      6\n"
-	   "#N/A       7\n"
-	   "This function is Excel compatible. "
+	   "error value.  The error numbers for error values are:\n\n"
+	   "\t#DIV/0!  \t\t2\n"
+	   "\t#VALUE!  \t\t3\n"
+	   "\t#REF!    \t\t4\n"
+	   "\t#NAME?   \t5\n"
+	   "\t#NUM!    \t\t6\n"
+	   "\t#N/A     \t\t7\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ERROR.TYPE(NA()) equals 7.\n"
@@ -1699,8 +1556,8 @@ static const char *help_na = {
 	   "@SYNTAX=NA()\n"
 
 	   "@DESCRIPTION="
-	   "NA returns the error value #N/A.\n"
-	   "This function is Excel compatible. "
+	   "NA returns the error value #N/A.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "NA() equals #N/A error.\n"
@@ -1742,8 +1599,8 @@ static const char *help_isblank = {
 	   "@SYNTAX=ISBLANK(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISBLANK returns TRUE if the value is blank.\n"
-	   "This function is Excel compatible. "
+	   "ISBLANK returns TRUE if the value is blank.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISBLANK(A1).\n"
@@ -1779,7 +1636,8 @@ gnumeric_isblank (FunctionEvalInfo *ei, GnmExprList *expr_node_list)
 		CellPos pos;
 
 		cellref_get_abs_pos (ref, &ei->pos->eval, &pos);
-		result = cell_is_blank (sheet_cell_get (sheet, pos.col, pos.row));
+		result = cell_is_blank (sheet_cell_get (sheet, pos.col,
+							pos.row));
 	}
 	return value_new_bool (result);
 }
@@ -1791,8 +1649,8 @@ static const char *help_iseven = {
 	   "@SYNTAX=ISEVEN(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISEVEN returns TRUE if the number is even.\n"
-	   "This function is Excel compatible. "
+	   "ISEVEN returns TRUE if the number is even.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISEVEN(4) equals TRUE.\n"
@@ -1813,8 +1671,8 @@ static const char *help_islogical = {
 	   "@SYNTAX=ISLOGICAL(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISLOGICAL returns TRUE if the value is a logical value.\n"
-	   "This function is Excel compatible. "
+	   "ISLOGICAL returns TRUE if the value is a logical value.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISLOGICAL(A1).\n"
@@ -1843,8 +1701,8 @@ static const char *help_isnontext = {
 	   "@SYNTAX=ISNONTEXT(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISNONTEXT Returns TRUE if the value is not text.\n"
-	   "This function is Excel compatible. "
+	   "ISNONTEXT Returns TRUE if the value is not text.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISNONTEXT(\"text\") equals FALSE.\n"
@@ -1870,8 +1728,8 @@ static const char *help_isnumber = {
 	   "@SYNTAX=ISNUMBER(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISNUMBER returns TRUE if the value is a number.\n"
-	   "This function is Excel compatible. "
+	   "ISNUMBER returns TRUE if the value is a number.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISNUMBER(\"text\") equals FALSE.\n"
@@ -1897,8 +1755,8 @@ static const char *help_isodd = {
 	   "@SYNTAX=ISODD(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISODD returns TRUE if the number is odd.\n"
-	   "This function is Excel compatible. "
+	   "ISODD returns TRUE if the number is odd.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISODD(3) equals TRUE.\n"
@@ -1919,8 +1777,8 @@ static const char *help_isref = {
 	   "@SYNTAX=ISREF(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISREF returns TRUE if the value is a reference.\n"
-	   "This function is Excel compatible. "
+	   "ISREF returns TRUE if the value is a reference.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISREF(A1) equals TRUE.\n"
@@ -1951,8 +1809,8 @@ static const char *help_istext = {
 	   "@SYNTAX=ISTEXT(value)\n"
 
 	   "@DESCRIPTION="
-	   "ISTEXT returns TRUE if the value is text.\n"
-	   "This function is Excel compatible. "
+	   "ISTEXT returns TRUE if the value is text.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ISTEXT(\"text\") equals TRUE.\n"
@@ -1979,8 +1837,8 @@ static const char *help_n = {
 
 	   "@DESCRIPTION="
 	   "N returns a value converted to a number.  Strings containing "
-	   "text are converted to the zero value.\n"
-	   "This function is Excel compatible. "
+	   "text are converted to the zero value.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "N(\"42\") equals 42.\n"
@@ -2017,8 +1875,8 @@ static const char *help_type = {
 	   "@SYNTAX=TYPE(value)\n"
 
 	   "@DESCRIPTION="
-	   "TYPE returns a number indicating the data type of a value.\n"
-	   "This function is Excel compatible. "
+	   "TYPE returns a number indicating the data type of a value.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "TYPE(3) equals 1.\n"
@@ -2046,7 +1904,7 @@ static const char *help_getenv = {
 	   "@DESCRIPTION="
 	   "GETENV retrieves a value from the execution environment.\n"
 	   "\n"
-	   "If the variable specified by @STRING does not exist, #N/A! will "
+	   "* If the variable specified by @STRING does not exist, #N/A! will "
 	   "be returned.  Note, that variable names are case sensitive.\n"
 	   "@EXAMPLES=\n"
 	   "\n"
@@ -2068,26 +1926,47 @@ gnumeric_getenv (FunctionEvalInfo *ei, Value **argv)
 /***************************************************************************/
 
 const ModulePluginFunctionInfo info_functions[] = {
-	{ "cell", "sr", N_("info_type, cell"), &help_cell, gnumeric_cell, NULL, NULL, NULL },
-        { "countblank", "r",  N_("range"), &help_countblank, gnumeric_countblank, NULL, NULL, NULL },
-	{ "error",   "s",  N_("text"), &help_error,   gnumeric_error, NULL, NULL, NULL },
-	{ "error.type", NULL, N_("value"), &help_error_type, NULL, gnumeric_error_type, NULL, NULL },
-	{ "expression", "r",   N_("cell"), &help_expression, gnumeric_expression, NULL, NULL, NULL },
-	{ "info", "s", N_("info_type"), &help_info, gnumeric_info, NULL, NULL, NULL },
-	{ "isblank", NULL, N_("value"), &help_isblank, NULL, gnumeric_isblank, NULL, NULL },
-	{ "iserr", NULL,   N_("value"), &help_iserr,   NULL, gnumeric_iserr, NULL, NULL },
-	{ "iserror", NULL,   N_("value"), &help_iserror, NULL, gnumeric_iserror, NULL, NULL },
-	{ "iseven", "?", N_("value"), &help_iseven, gnumeric_iseven, NULL, NULL, NULL },
-	{ "islogical", NULL, N_("value"), &help_islogical, NULL, gnumeric_islogical, NULL, NULL },
-	{ "isna", NULL,   N_("value"), &help_isna,    NULL, gnumeric_isna, NULL, NULL },
-	{ "isnontext", NULL, N_("value"), &help_isnontext, NULL, gnumeric_isnontext, NULL, NULL },
-	{ "isnumber", NULL, N_("value"), &help_isnumber, NULL, gnumeric_isnumber, NULL, NULL },
-	{ "isodd", "?", N_("value"), &help_isodd, gnumeric_isodd, NULL, NULL, NULL },
-	{ "isref", NULL, N_("value"), &help_isref, NULL, gnumeric_isref, NULL, NULL },
-	{ "istext", NULL, N_("value"), &help_istext, NULL, gnumeric_istext, NULL, NULL },
-	{ "n", "?", N_("value"), &help_n, gnumeric_n, NULL, NULL, NULL },
-	{ "na",      "",  "", &help_na,      gnumeric_na, NULL, NULL, NULL },
-	{ "type",   NULL, N_("value"), &help_type, NULL, gnumeric_type, NULL, NULL },
-	{ "getenv", "s", N_("string"), &help_getenv, gnumeric_getenv, NULL, NULL, NULL },
+	{ "cell", "sr", N_("info_type, cell"), &help_cell,
+	  gnumeric_cell, NULL, NULL, NULL },
+        { "countblank", "r",  N_("range"), &help_countblank,
+	  gnumeric_countblank, NULL, NULL, NULL },
+	{ "error",   "s",  N_("text"), &help_error,
+	  gnumeric_error, NULL, NULL, NULL },
+	{ "error.type", NULL, N_("value"), &help_error_type,
+	  NULL, gnumeric_error_type, NULL, NULL },
+	{ "expression", "r",   N_("cell"), &help_expression,
+	  gnumeric_expression, NULL, NULL, NULL },
+	{ "info", "s", N_("info_type"), &help_info,
+	  gnumeric_info, NULL, NULL, NULL },
+	{ "isblank", NULL, N_("value"), &help_isblank,
+	  NULL, gnumeric_isblank, NULL, NULL },
+	{ "iserr", NULL,   N_("value"), &help_iserr,
+	  NULL, gnumeric_iserr, NULL, NULL },
+	{ "iserror", NULL,   N_("value"), &help_iserror,
+	  NULL, gnumeric_iserror, NULL, NULL },
+	{ "iseven", "?", N_("value"), &help_iseven,
+	  gnumeric_iseven, NULL, NULL, NULL },
+	{ "islogical", NULL, N_("value"), &help_islogical,
+	  NULL, gnumeric_islogical, NULL, NULL },
+	{ "isna", NULL,   N_("value"), &help_isna,
+	  NULL, gnumeric_isna, NULL, NULL },
+	{ "isnontext", NULL, N_("value"), &help_isnontext,
+	  NULL, gnumeric_isnontext, NULL, NULL },
+	{ "isnumber", NULL, N_("value"), &help_isnumber,
+	  NULL, gnumeric_isnumber, NULL, NULL },
+	{ "isodd", "?", N_("value"), &help_isodd,
+	  gnumeric_isodd, NULL, NULL, NULL },
+	{ "isref", NULL, N_("value"), &help_isref,
+	  NULL, gnumeric_isref, NULL, NULL },
+	{ "istext", NULL, N_("value"), &help_istext,
+	  NULL, gnumeric_istext, NULL, NULL },
+	{ "n", "?", N_("value"), &help_n,
+	  gnumeric_n, NULL, NULL, NULL },
+	{ "na",      "",  "", &help_na,
+	  gnumeric_na, NULL, NULL, NULL },
+	{ "type",   NULL, N_("value"), &help_type,
+	  NULL, gnumeric_type, NULL, NULL },
+	{ "getenv", "s", N_("string"), &help_getenv,
+	  gnumeric_getenv, NULL, NULL, NULL },
         {NULL}
 };
