@@ -141,12 +141,12 @@ static const char *help_gcd = {
 	   "@SYNTAX=GCD(number1,number2,...)\n"
 
 	   "@DESCRIPTION="
-	   "GCD returns the greatest common divisor of given numbers. "
+	   "GCD returns the greatest common divisor of given numbers.\n"
 	   "\n"
-	   "If any of the arguments is less than zero, GCD returns #NUM! "
-	   "error. "
-	   "If any of the arguments is non-integer, it is truncated.\n"
-	   "This function is Excel compatible. "
+	   "* If any of the arguments is less than zero, GCD returns #NUM! "
+	   "error.\n"
+	   "* If any of the arguments is non-integer, it is truncated.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "GCD(470,770) equals to 10.\n"
@@ -195,11 +195,11 @@ static const char *help_lcm = {
 	   "@DESCRIPTION="
 	   "LCM returns the least common multiple of integers.  The least "
 	   "common multiple is the smallest positive number that is a "
-	   "multiple of all integer arguments given. "
+	   "multiple of all integer arguments given.\n"
 	   "\n"
-	   "If any of the arguments is less than one, LCM returns #NUM! "
+	   "* If any of the arguments is less than one, LCM returns #NUM! "
 	   "error.\n"
-	   "This function is Excel compatible. "
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "LCM(2,13) equals to 26.\n"
@@ -252,8 +252,8 @@ static const char *help_abs = {
 	   "@DESCRIPTION="
 	   "ABS implements the Absolute Value function:  the result is "
 	   "to drop the negative sign (if present).  This can be done for "
-	   "integers and floating point numbers.\n"
-	   "This function is Excel compatible."
+	   "integers and floating point numbers.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ABS(7) equals 7.\n"
@@ -276,10 +276,12 @@ static const char *help_acos = {
 
 	   "@DESCRIPTION="
 	   "ACOS function calculates the arc cosine of @x; that "
-	   "is the value whose cosine is @x.  If @x  falls  outside  the "
-	   "range -1 to 1, ACOS fails and returns the #NUM! error. "
-	   "The value it returns is in radians.\n"
-	   "This function is Excel compatible."
+	   "is the value whose cosine is @x.\n"
+	   "\n"
+	   "* The value it returns is in radians.\n"
+	   "* If @x falls outside the range -1 to 1, ACOS returns "
+	   "the #NUM! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ACOS(0.1) equals 1.470629.\n"
@@ -309,8 +311,10 @@ static const char *help_acosh = {
 	   "@DESCRIPTION="
 	   "ACOSH  function  calculates  the inverse hyperbolic "
 	   "cosine of @x; that is the value whose hyperbolic cosine is "
-	   "@x. If @x is less than 1.0, ACOSH() returns the #NUM! error.\n"
-	   "This function is Excel compatible. "
+	   "@x.\n"
+	   "\n"
+	   "* If @x is less than 1.0, ACOSH() returns the #NUM! error.\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ACOSH(2) equals 1.31696.\n"
@@ -339,9 +343,11 @@ static const char *help_asin = {
 
 	   "@DESCRIPTION="
 	   "ASIN function calculates the arc sine of @x; that is "
-	   "the value whose sine is @x. If @x falls outside  the  range "
-	   "-1 to 1, ASIN fails and returns the #NUM! error.\n"
-	   "This function is Excel compatible. "
+	   "the value whose sine is @x.\n"
+	   "\n"
+	   "* If @x falls outside the range -1 to 1, ASIN returns "
+	   "the #NUM! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ASIN(0.5) equals 0.523599.\n"
@@ -370,8 +376,8 @@ static const char *help_asinh = {
 
 	   "@DESCRIPTION="
 	   "ASINH function calculates the inverse hyperbolic sine of @x; "
-	   "that is the value whose hyperbolic sine is @x.\n"
-	   "This function is Excel compatible. "
+	   "that is the value whose hyperbolic sine is @x.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ASINH(0.5) equals 0.481212.\n"
@@ -394,9 +400,9 @@ static const char *help_atan = {
 
 	   "@DESCRIPTION="
 	   "ATAN function calculates the arc tangent of @x; that "
-	   "is the value whose tangent is @x. "
-	   "Return value is in radians.\n"
-	   "This function is Excel compatible. "
+	   "is the value whose tangent is @x.\n\n"
+	   "* Return value is in radians.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ATAN(0.5) equals 0,463648.\n"
@@ -419,10 +425,11 @@ static const char *help_atanh = {
 
 	   "@DESCRIPTION="
 	   "ATANH function calculates the inverse hyperbolic tangent "
-	   "of @x; that is the value whose hyperbolic tangent is @x. "
-	   "If the absolute value of @x is greater than 1.0, ATANH "
+	   "of @x; that is the value whose hyperbolic tangent is @x.\n"
+	   "\n"
+	   "* If the absolute value of @x is greater than 1.0, ATANH "
 	   "returns #NUM! error.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ATANH(0.5) equals 0.549306.\n "
@@ -453,9 +460,9 @@ static const char *help_atan2 = {
 	   "ATAN2 function calculates the arc tangent of the two "
 	   "variables @b1 and @b2.  It is similar to calculating the arc "
 	   "tangent of @b2 / @b1, except that the signs of both arguments "
-	   "are used to determine the quadrant of the result. "
-	   "The result is in radians.\n"
-	   "This function is Excel compatible. "
+	   "are used to determine the quadrant of the result.\n\n"
+	   "* The result is in radians.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ATAN2(0.5,1.0) equals 1.107149.\n"
@@ -478,8 +485,8 @@ static const char *help_ceil = {
 	   "@SYNTAX=CEIL(x)\n"
 
 	   "@DESCRIPTION="
-	   "CEIL function rounds @x up to the next nearest integer.\n"
-	   "This function is Excel compatible. "
+	   "CEIL function rounds @x up to the next nearest integer.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "CEIL(0.4) equals 1.\n"
@@ -492,7 +499,8 @@ static const char *help_ceil = {
 static Value *
 gnumeric_ceil (FunctionEvalInfo *ei, Value **args)
 {
-	return value_new_float (gnumeric_fake_ceil (value_get_as_float (args [0])));
+	return value_new_float (gnumeric_fake_ceil
+				(value_get_as_float (args [0])));
 }
 
 /***************************************************************************/
@@ -503,8 +511,8 @@ static const char *help_countif = {
 
 	   "@DESCRIPTION="
 	   "COUNTIF function counts the number of cells in the given @range "
-	   "that meet the given @criteria.\n"
-	   "This function is Excel compatible."
+	   "that meet the given @criteria.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
@@ -583,8 +591,8 @@ static const char *help_sumif = {
 	   "SUMIF function sums the values in the given @range that meet "
 	   "the given @criteria.  If @actual_range is given, SUMIF sums "
 	   "the values in the @actual_range whose corresponding components "
-	   "in @range meet the given @criteria.\n"
-	   "This function is Excel compatible. "
+	   "in @range meet the given @criteria.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
@@ -618,7 +626,8 @@ callback_function_sumif (Sheet *sheet, int col, int row,
 
 	if (cell != NULL && cell->value != NULL)
 		switch (cell->value->type) {
-		case VALUE_BOOLEAN:	v = cell->value->v_bool.val ? 1 : 0; break;
+		case VALUE_BOOLEAN:	v = cell->value->v_bool.val ? 1 : 0;
+			break;
 		case VALUE_INTEGER:	v = cell->value->v_int.val; break;
 		case VALUE_FLOAT:	v = cell->value->v_float.val; break;
 
@@ -707,7 +716,8 @@ gnumeric_sumif (FunctionEvalInfo *ei, Value **argv)
 	      items.current = items.list;
 	      items.sum = items.total_num = 0;
  	      ret = sheet_foreach_cell_in_range (
-			eval_sheet (actual_range->v_range.cell.a.sheet, ei->pos->sheet),
+			eval_sheet (actual_range->v_range.cell.a.sheet,
+				    ei->pos->sheet),
 			/* Empty cells too.  Criteria and results must align */
 			CELL_ITER_ALL,
 
@@ -733,13 +743,13 @@ static const char *help_ceiling = {
 
 	   "@DESCRIPTION="
 	   "CEILING function rounds @x up to the nearest multiple of "
-	   "@significance. "
+	   "@significance.\n"
 	   "\n"
-	   "If @x or @significance is non-numeric CEILING returns "
-	   "#VALUE! error. "
-	   "If @x and @significance have different signs CEILING returns "
+	   "* If @x or @significance is non-numeric CEILING returns "
+	   "#VALUE! error.\n"
+	   "* If @x and @significance have different signs CEILING returns "
 	   "#NUM! error.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "CEILING(2.43,1) equals 3.\n"
@@ -774,8 +784,8 @@ static const char *help_cos = {
 
 	   "@DESCRIPTION="
 	   "COS function returns the cosine of @x, where @x is given "
-           "in radians.\n"
-	   "This function is Excel compatible."
+           "in radians.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "COS(0.5) equals 0.877583.\n"
@@ -798,9 +808,9 @@ static const char *help_cosh = {
 
 	   "@DESCRIPTION="
 	   "COSH function returns the hyperbolic cosine of @x, which "
-	   "is defined mathematically as (exp(@x) + exp(-@x)) / 2.   "
-	   "@x is in radians.\n"
-	   "This function is Excel compatible. "
+	   "is defined mathematically as\n\n\t(exp(@x) + exp(-@x)) / 2.\n\n"
+	   "* @x is in radians.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "COSH(0.5) equals 1.127626.\n"
@@ -823,7 +833,8 @@ static const char *help_degrees = {
 
 	   "@DESCRIPTION="
 	   "DEGREES computes the number of degrees equivalent to @x radians.\n"
-	   "This function is Excel compatible. "
+	   "\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "DEGREES(2.5) equals 143.2394.\n"
@@ -834,7 +845,8 @@ static const char *help_degrees = {
 static Value *
 gnumeric_degrees (FunctionEvalInfo *ei, Value **argv)
 {
-	return value_new_float ((value_get_as_float (argv [0]) * 180.0) / M_PIgnum);
+	return value_new_float ((value_get_as_float (argv [0]) * 180.0) /
+				M_PIgnum);
 }
 
 /***************************************************************************/
@@ -845,8 +857,8 @@ static const char *help_exp = {
 
 	   "@DESCRIPTION="
 	   "EXP computes the value of e (the base of natural logarithmns) "
-	   "raised to the power of @x.\n"
-	   "This function is Excel compatible. "
+	   "raised to the power of @x.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "EXP(2) equals 7.389056.\n"
@@ -867,8 +879,8 @@ static const char *help_fact = {
 	   "@SYNTAX=FACT(x)\n"
 
 	   "@DESCRIPTION="
-	   "FACT computes the factorial of @x. ie, @x!\n"
-	   "This function is Excel compatible. "
+	   "FACT computes the factorial of @x. ie, @x!\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "FACT(3) equals 6.\n"
@@ -895,7 +907,7 @@ gnumeric_fact (FunctionEvalInfo *ei, Value **argv)
 	if (x > 12 || !x_is_integer) {
 		gnum_float res = expgnum (lgamma (x + 1));
 		if (x_is_integer)
-			res = floorgnum (res + 0.5);  /* Round, just in case.  */
+			res = floorgnum (res + 0.5);  /* Round, just in case. */
 		return value_new_float (res);
 	} else
 		return value_new_int (fact (x));
@@ -908,11 +920,12 @@ static const char *help_combin = {
 	   "@SYNTAX=COMBIN(n,k)\n"
 
 	   "@DESCRIPTION="
-	   "COMBIN computes the number of combinations. "
+	   "COMBIN computes the number of combinations.\n"
 	   "\n"
-	   "Performing this function on a non-integer or a negative number "
-           "returns an error.  Also if @n is less than @k returns an error.\n"
-	   "This function is Excel compatible."
+	   "* Performing this function on a non-integer or a negative number "
+           "returns #NUM! error.\n"
+	   "* If @n is less than @k COMBIN returns #NUM! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "COMBIN(8,6) equals 28.\n"
@@ -943,8 +956,9 @@ static const char *help_floor = {
 
 	   "@DESCRIPTION="
 	   "FLOOR function rounds @x down to the next nearest multiple "
-	   "of @significance.  @significance defaults to 1.\n"
-	   "This function is Excel compatible."
+	   "of @significance.\n\n"
+	   "* @significance defaults to 1.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "FLOOR(0.5) equals 0.\n"
@@ -980,8 +994,8 @@ static const char *help_int = {
 
 	   "@DESCRIPTION="
 	   "INT function returns the largest integer that is not "
-	   "bigger than its argument.\n"
-	   "This function is Excel compatible."
+	   "bigger than its argument.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "INT(7.2) equals 7.\n"
@@ -993,7 +1007,8 @@ static const char *help_int = {
 static Value *
 gnumeric_int (FunctionEvalInfo *ei, Value **argv)
 {
-	return value_new_float (gnumeric_fake_floor (value_get_as_float (argv [0])));
+	return value_new_float (gnumeric_fake_floor
+				(value_get_as_float (argv [0])));
 }
 
 /***************************************************************************/
@@ -1005,8 +1020,8 @@ static const char *help_log = {
 	   "@DESCRIPTION="
 	   "LOG computes the logarithm of @x in the given base @base.  "
 	   "If no @base is given LOG returns the logarithm in base 10. "
-	   "@base must be > 0. and can not equal 1.\n"
-	   "This function is Excel compatible."
+	   "@base must be > 0. and can not equal 1.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "LOG(2) equals 0.30103.\n"
@@ -1043,9 +1058,10 @@ static const char *help_ln = {
 	   "@SYNTAX=LN(x)\n"
 
 	   "@DESCRIPTION="
-	   "LN returns the natural logarithm of @x. "
-	   "If @x <= 0, LN returns #NUM! error.\n"
-	   "This function is Excel compatible."
+	   "LN returns the natural logarithm of @x.\n"
+	   "\n"
+	   "* If @x <= 0, LN returns #NUM! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "LN(7) equals 1.94591.\n"
@@ -1073,8 +1089,8 @@ static const char *help_power = {
 	   "@SYNTAX=POWER(x,y)\n"
 
 	   "@DESCRIPTION="
-	   "POWER returns the value of @x raised to the power @y. "
-	   "This function is Excel compatible.\n"
+	   "POWER returns the value of @x raised to the power @y.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "POWER(2,7) equals 128.\n"
@@ -1107,8 +1123,8 @@ static const char *help_log2 = {
 	   "@SYNTAX=LOG2(x)\n"
 
 	   "@DESCRIPTION="
-	   "LOG2 computes the base-2 logarithm of @x. "
-	   "If @x <= 0, LOG2 returns #NUM! error. "
+	   "LOG2 computes the base-2 logarithm of @x.\n\n"
+	   "* If @x <= 0, LOG2 returns #NUM! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "LOG2(1024) equals 10.\n"
@@ -1135,9 +1151,9 @@ static const char *help_log10 = {
 	   "@SYNTAX=LOG10(x)\n"
 
 	   "@DESCRIPTION="
-	   "LOG10 computes the base-10 logarithm of @x. "
-	   "If @x <= 0, LOG10 returns #NUM! error.\n"
-	   "This function is Excel compatible. "
+	   "LOG10 computes the base-10 logarithm of @x.\n\n"
+	   "* If @x <= 0, LOG10 returns #NUM! error.\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "LOG10(7) equals 0.845098.\n"
@@ -1166,9 +1182,9 @@ static const char *help_mod = {
 	   "@DESCRIPTION="
 	   "MOD function returns the remainder when @divisor is divided "
 	   "into @number.\n"
-	   "This function is Excel compatible. "
 	   "\n"
-	   "MOD returns #DIV/0! if divisor is zero.\n"
+	   "* MOD returns #DIV/0! if divisor is zero.\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "MOD(23,7) equals 2.\n"
@@ -1213,7 +1229,8 @@ static const char *help_radians = {
 
 	   "@DESCRIPTION="
 	   "RADIANS computes the number of radians equivalent to @x degrees.\n"
-	   "This function is Excel compatible. "
+	   "\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "RADIANS(180) equals 3.14159.\n"
@@ -1224,7 +1241,8 @@ static const char *help_radians = {
 static Value *
 gnumeric_radians (FunctionEvalInfo *ei, Value **argv)
 {
-	return value_new_float ((value_get_as_float (argv [0]) * M_PIgnum) / 180);
+	return value_new_float ((value_get_as_float (argv [0]) * M_PIgnum) /
+				180);
 }
 
 /***************************************************************************/
@@ -1235,8 +1253,8 @@ static const char *help_sin = {
 
 	   "@DESCRIPTION="
 	   "SIN function returns the sine of @x, where @x is given "
-           "in radians.\n"
-	   "This function is Excel compatible."
+           "in radians.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "SIN(0.5) equals 0.479426.\n"
@@ -1258,8 +1276,9 @@ static const char *help_sinh = {
 
 	   "@DESCRIPTION="
 	   "SINH function returns the hyperbolic sine of @x, "
-	   "which is defined mathematically as (exp(@x) - exp(-@x)) / 2.\n"
-	   "This function is Excel compatible. "
+	   "which is defined mathematically as\n\n\t"
+	   "(exp(@x) - exp(-@x)) / 2.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "SINH(0.5) equals 0.521095.\n"
@@ -1280,9 +1299,10 @@ static const char *help_sqrt = {
 	   "@SYNTAX=SQRT(x)\n"
 
 	   "@DESCRIPTION="
-	   "SQRT function returns the square root of @x.  "
-	   "If @x is negative, SQRT returns #NUM! error.\n"
-	   "This function is Excel compatible."
+	   "SQRT function returns the square root of @x.\n"
+	   "\n"
+	   "* If @x is negative, SQRT returns #NUM! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "SQRT(2) equals 1.4142136.\n"
@@ -1311,7 +1331,7 @@ static const char *help_suma = {
 	   "in the argument list.  Numbers, text and logical values are "
 	   "included in the calculation too.  If the cell contains text or "
 	   "the argument evaluates to FALSE, it is counted as value zero (0). "
-	   "If the argument evaluates to TRUE, it is counted as one (1). "
+	   "If the argument evaluates to TRUE, it is counted as one (1).\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
@@ -1340,8 +1360,8 @@ static const char *help_sumsq = {
 
 	   "@DESCRIPTION="
 	   "SUMSQ returns the sum of the squares of all the values and "
-	   "cells referenced in the argument list.\n"
-	   "This function is Excel compatible. "
+	   "cells referenced in the argument list.\n\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
@@ -1371,8 +1391,8 @@ static const char *help_multinomial = {
 
 	   "@DESCRIPTION="
 	   "MULTINOMIAL returns the ratio of the factorial of a sum of "
-	   "values to the product of factorials.\n"
-	   "This function is Excel compatible. "
+	   "values to the product of factorials.\n\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "MULTINOMIAL(2,3,4) equals 1260.\n"
@@ -1399,9 +1419,9 @@ static const char *help_g_product = {
 	   "@SYNTAX=G_PRODUCT(value1, value2, ...)\n"
 
 	   "@DESCRIPTION="
-	   "PRODUCT returns the product of all the values and cells "
-	   "referenced in the argument list.  Empty cells are ignored "
-	   "and the empty product is 1."
+	   "G_PRODUCT returns the product of all the values and cells "
+	   "referenced in the argument list.\n\n"
+	   "* Empty cells are ignored and the empty product is 1.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "G_PRODUCT(2,5,9) equals 90.\n"
@@ -1428,8 +1448,8 @@ static const char *help_tan = {
 
 	   "@DESCRIPTION="
 	   "TAN function returns the tangent of @x, where @x is "
-	   "given in radians.\n"
-	   "This function is Excel compatible."
+	   "given in radians.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "TAN(3) equals -0.1425465.\n"
@@ -1451,8 +1471,8 @@ static const char *help_tanh = {
 
 	   "@DESCRIPTION="
 	   "TANH function returns the hyperbolic tangent of @x, "
-	   "which is defined mathematically as sinh(@x) / cosh(@x).\n"
-	   "This function is Excel compatible. "
+	   "which is defined mathematically as \n\n\tsinh(@x) / cosh(@x).\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "TANH(2) equals 0.96402758.\n"
@@ -1473,11 +1493,11 @@ static const char *help_pi = {
 	   "@SYNTAX=PI()\n"
 
 	   "@DESCRIPTION="
-	   "PI functions returns the value of pi. "
+	   "PI functions returns the value of pi.\n"
 	   "\n"
-	   "This function is called with no arguments.\n"
-	   "This function is Excel compatible, except that "
-           "it returns pi with a better precision. "
+	   "* This function is called with no arguments.\n"
+	   "* This function is Excel compatible, except that "
+           "it returns pi with a better precision.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "PI() equals about 3.141593.\n"
@@ -1499,9 +1519,9 @@ static const char *help_trunc = {
 
 	   "@DESCRIPTION="
 	   "TRUNC function returns the value of @number "
-	   "truncated to the number of digits specified. "
-	   "If @digits is omitted then @digits defaults to zero.\n"
-	   "This function is Excel compatible. "
+	   "truncated to the number of digits specified.\n\n"
+	   "* If @digits is omitted then @digits defaults to zero.\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "TRUNC(3.12) equals 3.\n"
@@ -1534,8 +1554,8 @@ static const char *help_even = {
 
 	   "@DESCRIPTION="
 	   "EVEN function returns the number rounded up to the "
-	   "nearest even integer.\n"
-	   "This function is Excel compatible. "
+	   "nearest even integer.\n\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "EVEN(5.4) equals 6.\n"
@@ -1572,8 +1592,8 @@ static const char *help_odd = {
 
 	   "@DESCRIPTION="
 	   "ODD function returns the @number rounded up to the "
-	   "nearest odd integer.\n"
-	   "This function is Excel compatible. "
+	   "nearest odd integer.\n\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ODD(4.4) equals 5.\n"
@@ -1610,11 +1630,11 @@ static const char *help_factdouble = {
 
 	   "@DESCRIPTION="
 	   "FACTDOUBLE function returns the double factorial "
-	   "of a @number, i.e., x!!."
+	   "of a @number, i.e., x!!.\n"
 	   "\n"
-	   "If @number is not an integer, it is truncated.  "
-	   "If @number is negative FACTDOUBLE returns #NUM! error.\n"
-	   "This function is Excel compatible. "
+	   "* If @number is not an integer, it is truncated.\n"
+	   "* If @number is negative FACTDOUBLE returns #NUM! error.\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "FACTDOUBLE(5) equals 15.\n"
@@ -1648,9 +1668,9 @@ static const char *help_quotient = {
 
 	   "@DESCRIPTION="
 	   "QUOTIENT function returns the integer portion "
-	   "of a division.  @numerator is the divided number and \n"
-	   "@denumerator is the divisor.\n"
-	   "This function is Excel compatible. "
+	   "of a division.  @numerator is the divided number and "
+	   "@denumerator is the divisor.\n\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "QUOTIENT(23,5) equals 4.\n"
@@ -1680,8 +1700,8 @@ static const char *help_sign = {
 
 	   "@DESCRIPTION="
 	   "SIGN function returns 1 if the @number is positive, "
-	   "zero if the @number is 0, and -1 if the @number is negative.\n"
-	   "This function is Excel compatible. "
+	   "zero if the @number is 0, and -1 if the @number is negative.\n\n"
+	   "* This function is Excel compatible.\n "
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "SIGN(3) equals 1.\n"
@@ -1714,8 +1734,8 @@ static const char *help_sqrtpi = {
 
 	   "@DESCRIPTION="
 	   "SQRTPI function returns the square root of a @number "
-	   "multiplied by pi.\n"
-	   "This function is Excel compatible."
+	   "multiplied by pi.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "SQRTPI(2) equals 2.506628275.\n"
@@ -1744,15 +1764,15 @@ static const char *help_rounddown = {
 	   "@DESCRIPTION="
 	   "ROUNDDOWN function rounds a given @number down. "
 	   "@number is the number you want rounded down and @digits is the "
-	   "number of digits to which you want to round that number. "
+	   "number of digits to which you want to round that number.\n"
 	   "\n"
-	   "If @digits is greater than zero, @number is rounded down to the "
-	   "given number of digits. "
-	   "If @digits is zero or omitted, @number is rounded down to the "
-	   "nearest integer. "
-	   "If @digits is less than zero, @number is rounded down to the left "
-	   "of the decimal point.\n"
-	   "This function is Excel compatible. "
+	   "* If @digits is greater than zero, @number is rounded down to the "
+	   "given number of digits.\n"
+	   "* If @digits is zero or omitted, @number is rounded down to the "
+	   "nearest integer.\n"
+	   "* If @digits is less than zero, @number is rounded down to the "
+	   "left of the decimal point.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ROUNDDOWN(5.5) equals 5.\n"
@@ -1786,17 +1806,17 @@ static const char *help_round = {
 	   "@SYNTAX=ROUND(number[,digits])\n"
 
 	   "@DESCRIPTION="
-	   "ROUND function rounds a given number. "
+	   "ROUND function rounds a given number.\n\n"
 	   "@number is the number you want rounded and @digits is the "
-	   "number of digits to which you want to round that number. "
+	   "number of digits to which you want to round that number.\n"
 	   "\n"
-	   "If @digits is greater than zero, @number is rounded to the "
-	   "given number of digits. "
-	   "If @digits is zero or omitted, @number is rounded to the "
-	   "nearest integer. "
-	   "If @digits is less than zero, @number is rounded to the left "
+	   "* If @digits is greater than zero, @number is rounded to the "
+	   "given number of digits.\n"
+	   "* If @digits is zero or omitted, @number is rounded to the "
+	   "nearest integer.\n"
+	   "* If @digits is less than zero, @number is rounded to the left "
 	   "of the decimal point.\n"
-	   "This function is Excel compatible. "
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ROUND(5.5) equals 6.\n"
@@ -1827,17 +1847,17 @@ static const char *help_roundup = {
 	   "@SYNTAX=ROUNDUP(number[,digits])\n"
 
 	   "@DESCRIPTION="
-	   "ROUNDUP function rounds a given number up. "
+	   "ROUNDUP function rounds a given number up.\n\n"
 	   "@number is the number you want rounded up and @digits is the "
-	   "number of digits to which you want to round that number. "
+	   "number of digits to which you want to round that number.\n"
 	   "\n"
-	   "If @digits is greater than zero, @number is rounded up to the "
-	   "given number of digits. "
-	   "If @digits is zero or omitted, @number is rounded up to the "
-	   "nearest integer. "
-	   "If @digits is less than zero, @number is rounded up to the left "
+	   "* If @digits is greater than zero, @number is rounded up to the "
+	   "given number of digits.\n"
+	   "* If @digits is zero or omitted, @number is rounded up to the "
+	   "nearest integer.\n"
+	   "* If @digits is less than zero, @number is rounded up to the left "
 	   "of the decimal point.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ROUNDUP(5.5) equals 6.\n"
@@ -1871,13 +1891,13 @@ static const char *help_mround = {
 	   "@SYNTAX=MROUND(number,multiple)\n"
 
 	   "@DESCRIPTION="
-	   "MROUND function rounds a given number to the desired multiple. "
+	   "MROUND function rounds a given number to the desired multiple.\n\n"
 	   "@number is the number you want rounded and @multiple is the "
-	   "the multiple to which you want to round the number. "
+	   "the multiple to which you want to round the number.\n"
 	   "\n"
-	   "If @number and @multiple have different sign, MROUND "
+	   "* If @number and @multiple have different sign, MROUND "
 	   "returns #NUM! error.\n"
-	   "This function is Excel compatible.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "MROUND(1.7,0.2) equals 1.8.\n"
@@ -1923,17 +1943,17 @@ static const char *help_roman = {
 	   "@DESCRIPTION="
 	   "ROMAN function returns an arabic number in the roman numeral "
 	   "style, as text. @number is the number you want to convert and "
-	   "@type is the type of roman numeral you want. "
+	   "@type is the type of roman numeral you want.\n"
 	   "\n"
-	   "If @type is 0 or it is omitted, ROMAN returns classic roman "
-	   "numbers. "
-	   "Type 1 is more concise than classic type, type 2 is more concise "
+	   "* If @type is 0 or it is omitted, ROMAN returns classic roman "
+	   "numbers.\n"
+	   "* Type 1 is more concise than classic type, type 2 is more concise "
 	   "than type 1, and type 3 is more concise than type 2.  Type 4 "
-	   "is simplified type. "
+	   "is simplified type."
 	   "\n"
-	   "If @number is negative or greater than 3999, ROMAN returns "
+	   "* If @number is negative or greater than 3999, ROMAN returns "
 	   "#VALUE! error.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "ROMAN(999) equals CMXCIX.\n"
@@ -2191,13 +2211,12 @@ static const char *help_sumx2my2 = {
 	   "of corresponding values in two arrays. @array1 is the first "
 	   "array or range of data points and @array2 is the second array "
 	   "or range of data points. The equation of SUMX2MY2 is "
-	   "SUM (x^2-y^2). "
+	   "SUM (x^2-y^2).\n"
 	   "\n"
-           "Strings and empty cells are simply ignored."
-           "\n"
-	   "If @array1 and @array2 have different number of data points, "
+           "* Strings and empty cells are simply ignored.\n"
+	   "* If @array1 and @array2 have different number of data points, "
 	   "SUMX2MY2 returns #N/A error.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
@@ -2306,13 +2325,12 @@ static const char *help_sumx2py2 = {
 	   "of corresponding values in two arrays. @array1 is the first "
 	   "array or range of data points and @array2 is the second array "
 	   "or range of data points. The equation of SUMX2PY2 is "
-	   "SUM (x^2+y^2). "
+	   "SUM (x^2+y^2).\n"
 	   "\n"
-           "Strings and empty cells are simply ignored."
-           "\n"
-	   "If @array1 and @array2 have different number of data points, "
+           "* Strings and empty cells are simply ignored.\n"
+	   "* If @array1 and @array2 have different number of data points, "
 	   "SUMX2PY2 returns #N/A error.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
@@ -2418,13 +2436,12 @@ static const char *help_sumxmy2 = {
 	   "of corresponding values in two arrays. @array1 is the first "
 	   "array or range of data points and @array2 is the second array "
 	   "or range of data points. The equation of SUMXMY2 is "
-	   "SUM (x-y)^2. "
+	   "SUM (x-y)^2.\n"
 	   "\n"
-           "Strings and empty cells are simply ignored."
-           "\n"
-	   "If @array1 and @array2 have different number of data points, "
+           "* Strings and empty cells are simply ignored.\n"
+	   "* If @array1 and @array2 have different number of data points, "
 	   "SUMXMY2 returns #N/A error.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
@@ -2532,8 +2549,8 @@ static const char *help_seriessum = {
 	   "the base of the power series, @n is the initial power to raise @x, "
 	   "@m is the increment to the power for each term in the series, and "
 	   "@coefficients is the coefficents by which each successive power "
-	   "of @x is multiplied.\n"
-	   "This function is Excel compatible."
+	   "of @x is multiplied.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
@@ -2650,12 +2667,13 @@ static const char *help_minverse = {
 	   "@SYNTAX=MINVERSE(matrix)\n"
 
 	   "@DESCRIPTION="
-	   "MINVERSE function returns the inverse matrix of a given matrix. "
+	   "MINVERSE function returns the inverse matrix of a given matrix.\n"
 	   "\n"
-	   "If the @matrix cannot be inverted, MINVERSE returns #NUM! error. "
-	   "If the @matrix does not contain equal number of columns and "
+	   "* If the @matrix cannot be inverted, MINVERSE returns #NUM! "
+	   "error.\n"
+	   "* If the @matrix does not contain equal number of columns and "
 	   "rows, MINVERSE returns #VALUE! error.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
@@ -2780,8 +2798,8 @@ static const char *help_mmult = {
 	   "@DESCRIPTION="
 	   "MMULT function returns the matrix product of two arrays. The "
 	   "result is an array with the same number of rows as @array1 and "
-	   "the same number of columns as @array2.\n"
-	   "This function is Excel compatible."
+	   "the same number of columns as @array2.\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "\n"
@@ -2854,11 +2872,11 @@ static const char *help_mdeterm = {
 	   "@SYNTAX=MDETERM(matrix)\n"
 
 	   "@DESCRIPTION="
-	   "MDETERM function returns the determinant of a given matrix. "
+	   "MDETERM function returns the determinant of a given matrix.\n"
 	   "\n"
-	   "If the @matrix does not contain equal number of columns and "
+	   "* If the @matrix does not contain equal number of columns and "
 	   "rows, MDETERM returns #VALUE! error.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that A1, ..., A4 contain numbers 2, 3, 7, and 3, "
@@ -2914,11 +2932,11 @@ static const char *help_sumproduct = {
 	   "SUMPRODUCT function multiplies corresponding data entries in the "
 	   "given arrays or ranges, and then returns the sum of those "
 	   "products.  If an array entry is not numeric, the value zero is "
-	   "used instead. "
+	   "used instead.\n"
 	   "\n"
-	   "If arrays or range arguments do not have the same dimensions, "
+	   "* If arrays or range arguments do not have the same dimensions, "
 	   "SUMPRODUCT returns #VALUE! error.\n"
-	   "This function is Excel compatible."
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
