@@ -28,10 +28,15 @@
 
 #include <func.h>
 #include <mathfunc.h>
+#include <rangefunc.h>
 #include <value.h>
 #include <auto-format.h>
 
 #include <libgnome/gnome-i18n.h>
+#include <expr.h>
+#include <sheet.h>
+#include <cell.h>
+#include <collect.h>
 
 #include "plugin.h"
 #include "plugin-util.h"
@@ -46,8 +51,8 @@ static const char *help_rand = {
 	   "@SYNTAX=RAND()\n"
 
 	   "@DESCRIPTION="
-	   "RAND returns a random number between zero and one ([0..1]).\n"
-	   "This function is Excel compatible. "
+	   "RAND returns a random number between zero and one ([0..1]).\n\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "RAND() returns a random number greater than zero but less "
@@ -70,11 +75,10 @@ static const char *help_randuniform = {
 
 	   "@DESCRIPTION="
 	   "RANDUNIFORM returns a random variate from the uniform (flat) "
-	   "distribution from a to b. The distribution is, p(x) dx = "
-	   "{1 over (b-a)} dx.  If a <= x < b and 0 otherwise. a random "
-	   "number between zero and one ([0..1]).\n"
-	   "\n"
-           "If @a > @b RANDUNIFORM returns #NUM! error. "
+	   "distribution from a to b. The distribution is,\n\n\t"
+	   "p(x) dx = {1 over (b-a)} dx.\n\n"
+	   "* If a <= x < b and 0 otherwise.\n"
+           "* If @a > @b RANDUNIFORM returns #NUM! error.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "RANDUNIFORM(1.4,4.2) returns a random number greater than or "
@@ -97,12 +101,142 @@ gnumeric_randuniform (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
+static const char *help_randdiscrete = {
+	N_("@FUNCTION=RANDDISCRETE\n"
+	   "@SYNTAX=RANDDISCRETE(val_range[,prob_range])\n"
+
+	   "@DESCRIPTION="
+	   "RANDDISCRETE returns one of the values in the @val_range. The "
+	   "probablilites for each value are given in the @prob_range.\n"
+	   "\n"
+	   "* If @prob_range is omitted, the uniform discrete distribution "
+	   "is assumed.\n"
+           "* If the sum of all values in @prob_range is other than one, "
+	   "RANDDISCRETE returns #NUM! error.\n"
+           "* If @val_range and @prob_range are not the same size, "
+	   "RANDDISCRETE returns #NUM! error.\n"
+	   "* If @val_range or @prob_range is not a range, RANDDISCRETE "
+	   "returns #VALUE! error.\n"
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "RANDDISCRETE(A1:A6) returns one of the values in the range A1:A6.\n"
+	   "\n"
+	   "@SEEALSO=RANDBETWEEN,RAND")
+};
+
+typedef struct {
+	gnum_float *prob;
+	int        ind;
+	gnum_float x;
+	gnum_float cum;
+	int        x_ind;
+	Value      *res;
+} randdiscrete_t;
+
+static Value *
+cb_randdiscrete (Sheet *sheet, int col, int row, Cell *cell, void *user_data)
+{
+	randdiscrete_t *p = (randdiscrete_t *) user_data;
+
+	if (p->res != NULL)
+		return NULL;
+
+	if (p->prob) {
+		if (p->x <= p->prob [p->ind] + p->cum)
+			if (cell != NULL)
+				p->res = value_duplicate (cell->value);
+			else
+				p->res = value_new_empty ();
+		else
+			p->cum += p->prob [p->ind];
+	} else if (p->ind == p->x_ind) {
+		if (cell != NULL)
+			p->res = value_duplicate (cell->value);
+		else
+			p->res = value_new_empty ();
+	}
+	(p->ind)++;
+		    
+	return NULL;
+}
+
+static Value *
+gnumeric_randdiscrete (FunctionEvalInfo *ei, Value **argv)
+{
+        Value          *value_range = argv[0];
+	Value          *prob_range  = argv[1];
+	Value          *ret;
+	int            cols, rows;
+	randdiscrete_t rd;
+
+	rd.prob  = NULL;
+	rd.ind   = 0;
+	rd.cum   = 0;
+	rd.res   = NULL;
+	rd.x_ind = 0;
+
+	if (value_range->type != VALUE_CELLRANGE ||
+	    (prob_range != NULL && prob_range->type != VALUE_CELLRANGE))
+	        return value_new_error (ei->pos, gnumeric_err_VALUE);
+
+	cols = value_range->v_range.cell.b.col
+		- value_range->v_range.cell.a.col + 1;
+	rows = value_range->v_range.cell.b.row
+		- value_range->v_range.cell.a.row + 1;
+
+	rd.x = random_01 ();
+
+	if (prob_range) {
+		int        n;
+		gnum_float sum;
+
+		if (prob_range->v_range.cell.b.col
+		    - prob_range->v_range.cell.a.col + 1 != cols
+		    || prob_range->v_range.cell.b.row
+		    - prob_range->v_range.cell.a.row + 1 != rows)
+			return value_new_error (ei->pos, gnumeric_err_NUM);
+
+		rd.prob = collect_floats_value (prob_range, ei->pos, 0, &n,
+						&ret);
+
+		/* Check that the cumulative probability equals to one. */
+		range_sum (rd.prob, n, &sum);
+		if (sum != 1) {
+			g_free (rd.prob);
+			return value_new_error (ei->pos, gnumeric_err_NUM);
+		}
+	} else
+		rd.x_ind = rd.x * cols * rows;
+
+	ret = sheet_foreach_cell_in_range
+		(eval_sheet (value_range->v_range.cell.a.sheet, ei->pos->sheet),
+		 CELL_ITER_ALL,
+		 value_range->v_range.cell.a.col,
+		 value_range->v_range.cell.a.row,
+		 value_range->v_range.cell.b.col,
+		 value_range->v_range.cell.b.row,
+		 cb_randdiscrete,
+		 &rd);
+
+	g_free (rd.prob);
+
+	if (ret != NULL) {
+		g_free (rd.res);
+	        return value_new_error (ei->pos, gnumeric_err_VALUE);
+	}
+
+	return rd.res;
+	
+}
+
+/***************************************************************************/
+
 static const char *help_randexp = {
         N_("@FUNCTION=RANDEXP\n"
            "@SYNTAX=RANDEXP(b)\n"
 
            "@DESCRIPTION="
-           "RANDEXP returns a exponentially-distributed random number. "
+           "RANDEXP returns a exponentially-distributed random number.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDEXP(0.5).\n"
@@ -125,7 +259,9 @@ static const char *help_randpoisson = {
            "@SYNTAX=RANDPOISSON(lambda)\n"
 
            "@DESCRIPTION="
-           "RANDPOISSON returns a poisson-distributed random number. "
+           "RANDPOISSON returns a poisson-distributed random number.\n"
+           "\n"
+           "* If @lambda < 0 RANDPOISSON returns #NUM! error.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDPOISSON(3).\n"
@@ -151,10 +287,10 @@ static const char *help_randbinom = {
            "@SYNTAX=RANDBINOM(p,trials)\n"
 
            "@DESCRIPTION="
-           "RANDBINOM returns a binomially-distributed random number. "
+           "RANDBINOM returns a binomially-distributed random number.\n"
            "\n"
-           "If @p < 0 or @p > 1 RANDBINOM returns #NUM! error. "
-           "If @trials < 0 RANDBINOM returns #NUM! error. "
+           "* If @p < 0 or @p > 1 RANDBINOM returns #NUM! error.\n"
+           "* If @trials < 0 RANDBINOM returns #NUM! error. "
 	   "\n"
            "@EXAMPLES=\n"
            "RANDBINOM(0.5,2).\n"
@@ -165,8 +301,8 @@ static const char *help_randbinom = {
 static Value *
 gnumeric_randbinom (FunctionEvalInfo *ei, Value **argv)
 {
-	gnum_float p = value_get_as_float (argv[0]);
-	int     trials = value_get_as_int (argv[1]);
+	gnum_float p      = value_get_as_float (argv[0]);
+	int        trials = value_get_as_int (argv[1]);
 
 	if (p < 0 || p > 1 || trials < 0)
 		return value_new_error (ei->pos, gnumeric_err_NUM);
@@ -183,9 +319,10 @@ static const char *help_randbetween = {
 	   "@DESCRIPTION="
 	   "RANDBETWEEN function returns a random integer number "
 	   "between and including @bottom and @top.\n"
-	   "If @bottom or @top is non-integer, they are truncated. "
-	   "If @bottom > @top, RANDBETWEEN returns #NUM! error.\n"
-	   "This function is Excel compatible. "
+           "\n"
+	   "* If @bottom or @top is non-integer, they are truncated.\n"
+	   "* If @bottom > @top, RANDBETWEEN returns #NUM! error.\n"
+	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "RANDBETWEEN(3,7).\n"
@@ -216,10 +353,10 @@ static const char *help_randnegbinom = {
 
            "@DESCRIPTION="
            "RANDNEGBINOM returns a negative binomially-distributed random "
-           "number. "
+           "number.\n"
            "\n"
-           "If @p < 0 or @p > 1, RANDNEGBINOM returns #NUM! error. "
-           "If @failures RANDNEGBINOM returns #NUM! error. "
+           "* If @p < 0 or @p > 1, RANDNEGBINOM returns #NUM! error.\n"
+           "* If @failures RANDNEGBINOM returns #NUM! error.\n"
 	   "\n"
            "@EXAMPLES=\n"
            "RANDNEGBINOM(0.5,2).\n"
@@ -246,9 +383,9 @@ static const char *help_randbernoulli = {
            "@SYNTAX=RANDBERNOULLI(p)\n"
 
            "@DESCRIPTION="
-           "RANDBERNOULLI returns a Bernoulli-distributed random number. "
+           "RANDBERNOULLI returns a Bernoulli-distributed random number.\n"
            "\n"
-           "If @p < 0 or @p > 1 RANDBERNOULLI returns #NUM! error. "
+           "* If @p < 0 or @p > 1 RANDBERNOULLI returns #NUM! error.\n"
 	   "\n"
            "@EXAMPLES=\n"
            "RANDBERNOULLI(0.5).\n"
@@ -274,9 +411,9 @@ static const char *help_randgaussian = {
            "@SYNTAX=RANDGAUSSIAN(mean,stdev)\n"
 
            "@DESCRIPTION="
-           "RANDGAUSSIAN returns a gaussian-distributed random number. "
+           "RANDGAUSSIAN returns a gaussian-distributed random number.\n"
            "\n"
-           "If @stdev < 0 RANDGAUSSIAN returns #NUM! error. "
+           "* If @stdev < 0 RANDGAUSSIAN returns #NUM! error.\n"
 	   "\n"
            "@EXAMPLES=\n"
            "RANDGAUSSIAN(0,1).\n"
@@ -305,9 +442,9 @@ static const char *help_randcauchy = {
            "@DESCRIPTION="
            "RANDCAUCHY returns a cauchy-distributed random number with "
 	   "scale parameter a. The Cauchy distribution is also known as the "
-	   "Lorentz distribution. "
+	   "Lorentz distribution.\n"
            "\n"
-           "If @a < 0 RANDCAUCHY returns #NUM! error. "
+           "* If @a < 0 RANDCAUCHY returns #NUM! error.\n"
 	   "\n"
            "@EXAMPLES=\n"
            "RANDCAUCHY(1).\n"
@@ -333,7 +470,7 @@ static const char *help_randlognorm = {
            "@SYNTAX=RANDLOGNORM(zeta,sigma)\n"
 
            "@DESCRIPTION="
-           "RANDLOGNORM returns a lognormal-distributed random number. "
+           "RANDLOGNORM returns a lognormal-distributed random number.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDLOGNORM(1,2).\n"
@@ -357,7 +494,7 @@ static const char *help_randweibull = {
            "@SYNTAX=RANDWEIBULL(a,b)\n"
 
            "@DESCRIPTION="
-           "RANDWEIBULL returns a Weibull-distributed random number. "
+           "RANDWEIBULL returns a Weibull-distributed random number.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDWEIBULL(1,2).\n"
@@ -383,7 +520,7 @@ static const char *help_randlaplace = {
            "@DESCRIPTION="
            "RANDLAPLACE returns a Laplace-distributed random number. Laplace "
 	   "distribution is also known as two-sided exponential probability "
-	   "distribution. "
+	   "distribution.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDLAPLACE(1).\n"
@@ -406,7 +543,7 @@ static const char *help_randrayleigh = {
            "@SYNTAX=RANDRAYLEIGH(sigma)\n"
 
            "@DESCRIPTION="
-           "RANDRAYLEIGH returns a Rayleigh-distributed random number. "
+           "RANDRAYLEIGH returns a Rayleigh-distributed random number.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDRAYLEIGH(1).\n"
@@ -431,8 +568,9 @@ static const char *help_randrayleightail = {
            "@DESCRIPTION="
            "RANDRAYLEIGHTAIL returns  a random variate from the tail of the "
 	   "Rayleigh distribution with scale parameter sigma and a lower limit "
-	   "of a. The distribution is, p(x) dx = {x over sigma^2} exp "
-	   "((a^2 - x^2) /(2 sigma^2)) dx, for x > a. "
+	   "of a. The distribution is,\n\n\t"
+	   "p(x) dx = {x over sigma^2} exp ((a^2 - x^2) /(2 sigma^2)) dx,\n\n"
+	   "for x > a.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDRAYLEIGHTAIL(0.3,1).\n"
@@ -456,9 +594,9 @@ static const char *help_randgamma = {
            "@SYNTAX=RANDGAMMA(a,b)\n"
 
            "@DESCRIPTION="
-           "RANDGAMMA returns a Gamma-distributed random number. "
+           "RANDGAMMA returns a Gamma-distributed random number.\n"
            "\n"
-           "If @a <= 0 RANDGAMMA returns #NUM! error. "
+           "* If @a <= 0 RANDGAMMA returns #NUM! error.\n"
 	   "\n"
            "@EXAMPLES=\n"
            "RANDGAMMA(1,2).\n"
@@ -485,7 +623,7 @@ static const char *help_randpareto = {
            "@SYNTAX=RANDPARETO(a,b)\n"
 
            "@DESCRIPTION="
-           "RANDPARETO returns a Pareto-distributed random number. "
+           "RANDPARETO returns a Pareto-distributed random number.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDPARETO(1,2).\n"
@@ -509,7 +647,7 @@ static const char *help_randfdist = {
            "@SYNTAX=RANDFDIST(nu1,nu2)\n"
 
            "@DESCRIPTION="
-           "RANDFDIST returns a F-distributed random number. "
+           "RANDFDIST returns a F-distributed random number.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDFDIST(1,2).\n"
@@ -533,7 +671,7 @@ static const char *help_randbeta = {
            "@SYNTAX=RANDBETA(a,b)\n"
 
            "@DESCRIPTION="
-           "RANDBETA returns a Beta-distributed random number. "
+           "RANDBETA returns a Beta-distributed random number.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDBETA(1,2).\n"
@@ -558,8 +696,9 @@ static const char *help_randlogistic = {
 
            "@DESCRIPTION="
            "RANDLOGISTIC returns a logistic-distributed random number.  The "
-	   "distribution function is, p(x) dx = { exp(-x/a) over a "
-	   "(1 + exp(-x/a))^2 } dx for -infty < x < +infty."
+	   "distribution function is,\n\n\t"
+	   "p(x) dx = { exp(-x/a) over a (1 + exp(-x/a))^2 } dx for "
+	   "-infty < x < +infty.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDLOGISTIC(1).\n"
@@ -585,9 +724,9 @@ static const char *help_randgeom = {
            "RANDGEOM returns a geometric-distributed random number. The "
 	   "number of independent trials with probability @p until the "
 	   "first success. The probability distribution for geometric "
-	   "variates is, p(k) =  p (1-p)^(k-1), for k >= 1. "
+	   "variates is, \n\n\tp(k) =  p (1-p)^(k-1), for k >= 1.\n"
            "\n"
-           "If @p < 0 or @p > 1 RANDGEOM returns #NUM! error. "
+           "* If @p < 0 or @p > 1 RANDGEOM returns #NUM! error. "
 	   "\n"
            "@EXAMPLES=\n"
            "RANDGEOM(0.4).\n"
@@ -615,8 +754,10 @@ static const char *help_randhyperg = {
            "@DESCRIPTION="
            "RANDHYPERG returns a hypergeometric-distributed random number. "
 	   "The probability distribution for hypergeometric random variates "
-	   "is, p(k) =  C(n_1,k) C(n_2, t-k) / C(n_1 + n_2,k), where C(a,b) "
-	   "= a!/(b!(a-b)!). The domain of k is max(0,t-n_2), ..., max(t,n_1)."
+	   "is,\n\n\t"
+	   "p(k) =  C(n_1,k) C(n_2, t-k) / C(n_1 + n_2,k), \n\nwhere C(a,b) "
+	   "= a!/(b!(a-b)!). \n\n"
+	   "The domain of k is max(0,t-n_2), ..., max(t,n_1)."
            "\n"
            "@EXAMPLES=\n"
            "RANDHYPERG(21,1,9).\n"
@@ -641,9 +782,9 @@ static const char *help_randlog = {
            "@SYNTAX=RANDLOG(p)\n"
 
            "@DESCRIPTION="
-           "RANDLOG returns a logarithmic-distributed random number. "
+           "RANDLOG returns a logarithmic-distributed random number.\n"
            "\n"
-           "If @p < 0 or @p > 1 RANDLOG returns #NUM! error. "
+           "* If @p < 0 or @p > 1 RANDLOG returns #NUM! error.\n"
 	   "\n"
            "@EXAMPLES=\n"
            "RANDHYPERG(0.72).\n"
@@ -669,7 +810,7 @@ static const char *help_randchisq = {
            "@SYNTAX=RANDCHISQ(nu)\n"
 
            "@DESCRIPTION="
-           "RANDCHISQ returns a Chi-Square-distributed random number. "
+           "RANDCHISQ returns a Chi-Square-distributed random number.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDCHISQ(0.5).\n"
@@ -692,7 +833,7 @@ static const char *help_randtdist = {
            "@SYNTAX=RANDTDIST(nu)\n"
 
            "@DESCRIPTION="
-           "RANDTDIST returns a T-distributed random number. "
+           "RANDTDIST returns a T-distributed random number.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDTDIST(0.5).\n"
@@ -717,10 +858,10 @@ static const char *help_randgumbel = {
            "@DESCRIPTION="
            "RANDGUMBEL returns a Type I or Type II Gumbel-distributed "
 	   "random number. @type is either 1 or 2 and specifies the type of "
-	   "the distribution (Type I or Type II). "
+	   "the distribution (Type I or Type II).\n"
            "\n"
-	   "If @type is either 1 or 2, RANDGUMBEL returns #NUM! error. "
-	   "If @type is omitted, Type I is assumed. "
+	   "* If @type is either 1 or 2, RANDGUMBEL returns #NUM! error.\n"
+	   "* If @type is omitted, Type I is assumed.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDGUMBEL(0.5,1,2).\n"
@@ -753,11 +894,12 @@ static const char *help_randlevy = {
            "@DESCRIPTION="
            "RANDLEVY returns a Levy-distributed random number. If @beta is "
 	   "ommitted, it is assumed to be 0.\n"
-	   "For alpha = 1, beta=0, we get the Lorentz distribution. "
-	   "For alpha = 2, beta=0, we get the Gaussian distribution. "
+	   "\n"
+	   "* For alpha = 1, beta=0, we get the Lorentz distribution.\n"
+	   "* For alpha = 2, beta=0, we get the Gaussian distribution.\n"
            "\n"
-	   "If @alpha <= 0 or @alpha > 2, RANDLEVY returns #NUM! error. "
-	   "If @beta < -1 or @beta > 1, RANDLEVY returns #NUM! error. "
+	   "* If @alpha <= 0 or @alpha > 2, RANDLEVY returns #NUM! error.\n"
+	   "* If @beta < -1 or @beta > 1, RANDLEVY returns #NUM! error.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDLEVY(0.5,0.1,1).\n"
@@ -785,12 +927,14 @@ static const char *help_randexppow = {
            "@SYNTAX=RANDEXPPOW(a,b)\n"
 
            "@DESCRIPTION="
-           "RANDLEVY returns a random variate from the exponential power "
+           "RANDEXPPOW returns a random variate from the exponential power "
 	   "distribution with scale parameter @a and exponent @b. The "
-	   "distribution is, p(x) dx = {1 over 2 a Gamma(1+1/b)} exp(-|x/a|^b) "
-	   "dx, for x >= 0. For b = 1 this reduces to the Laplace distribution. "
-	   "For b = 2 it has the same form as a gaussian distribution, but "
-	   "with a = sqrt{2} sigma. "
+	   "distribution is,\n\n\t"
+	   "p(x) dx = {1 over 2 a Gamma(1+1/b)} exp(-|x/a|^b) dx, "
+	   "for x >= 0.\n\n"
+	   "* For b = 1 this reduces to the Laplace distribution.\n"
+	   "* For b = 2 it has the same form as a gaussian distribution, "
+	   "but with a = sqrt{2} sigma.\n"
            "\n"
            "@EXAMPLES=\n"
            "RANDEXPPOW(0.5,0.1).\n"
@@ -807,6 +951,143 @@ gnumeric_randexppow (FunctionEvalInfo *ei, Value **argv)
 	return value_new_float (random_exppow (a, b));
 }
 
+/***************************************************************************/
+
+static const char *help_randlandau = {
+        N_("@FUNCTION=RANDLANDAU\n"
+           "@SYNTAX=RANDLANDAU()\n"
+
+           "@DESCRIPTION="
+           "RANDLANDAU returns a random variate from the Landau distribution. "
+	   "The probability distribution for Landau random variates is "
+	   "defined analytically by the complex integral,\n\n\t"
+	   "p(x) = (1/(2 pi i)) int_{c-i infty}^{c+i infty} ds "
+	   "exp(s log(s) + x s).\n\n"
+	   "For numerical purposes it is more convenient to use the "
+	   "following equivalent form of the integral,\n\n\t"
+	   "p(x) = (1/pi) int_0^ infty dt exp(-t log(t) - x t) sin(pi t).\n"
+           "\n"
+           "@EXAMPLES=\n"
+           "RANDLANDAU().\n"
+           "\n"
+           "@SEEALSO=RAND")
+};
+
+static Value *
+gnumeric_randlandau (FunctionEvalInfo *ei, Value **argv)
+{
+	return value_new_float (random_landau ());
+}
+
+/***************************************************************************/
+
+static const char *help_randgaussiantail = {
+        N_("@FUNCTION=RANDGAUSSIANTAIL\n"
+           "@SYNTAX=RANDGAUSSIANTAIL(a,sigma)\n"
+
+           "@DESCRIPTION="
+           "RANDGAUSSIANTAIL returns a random variates from the upper tail "
+	   "of a Gaussian distribution with standard deviation sigma. The "
+	   "values returned are larger than the lower limit a, which must be "
+	   "positive. The method is based on Marsaglia's famous "
+	   "rectangle-wedge-tail algorithm (Ann Math Stat 32, 894-899 "
+	   "(1961)), with this aspect explained in Knuth, v2, 3rd ed, p139, "
+	   "586 (exercise 11).\n"
+	   "\n"
+	   "The probability distribution for Gaussian tail random variates "
+	   "is,\n\n\t"
+	   "p(x) dx = {1 over N(a;sigma)} exp (- x^2/(2 sigma^2)) dx,\n\n"
+	   "for x > a where N(a;sigma) is the normalization constant, "
+	   "N(a;sigma) = (1/2) erfc(a / sqrt(2 sigma^2)).\n"
+           "\n"
+           "@EXAMPLES=\n"
+           "RANDGAUSSIANTAIL(0.5,0.1).\n"
+           "\n"
+           "@SEEALSO=RAND")
+};
+
+static Value *
+gnumeric_randgaussiantail (FunctionEvalInfo *ei, Value **argv)
+{
+	gnum_float a     = value_get_as_float (argv[0]);
+	gnum_float sigma = value_get_as_float (argv[1]);
+
+	return value_new_float (random_gaussian_tail (a, sigma));
+}
+
+/***************************************************************************/
+
+static const char *help_simtable = {
+        N_("@FUNCTION=SIMTABLE\n"
+           "@SYNTAX=SIMTABLE(d1, d2, ..., dN)\n"
+
+           "@DESCRIPTION="
+           "SIMTABLE returns one of the values in the given argument list "
+	   "depending on the round number of the simulation tool. When the "
+	   "simulation tool is not activated, SIMTABLE returns @d1.\n"
+	   "\n"
+	   "With the simulation tool and the SIMTABLE function you can "
+	   "test given decision variables. Each SIMTABLE function contains "
+	   "the possible values of a simulation variable. In most of "
+	   "valid simulation models you should have the same number of "
+	   "values @dN for all decision variables.  If the simulation is run "
+	   "more rounds than there are values defined, SIMTABLE returns "
+	   "#N/A! error (e.g. if A1 contains `=SIMTABLE(1)' and A2 "
+	   "`=SIMTABLE(1,2)', A1 yields #N/A! error on the second round).\n"
+	   "\n"
+	   "The successive use of the simulation tool also requires that you "
+	   "give to the tool at least one input variable having RAND() or "
+	   "any other RAND<distribution name>() function in it. "
+	   "On each round, the simulation tool iterates given number of "
+	   "times all the input variables to revalue them. On each iteration, "
+	   "the values of the of the output variables are stored, and when "
+	   "the round is completed, descriptive statistical information is "
+	   "created according to the values.\n"
+	   "\n"
+           "@EXAMPLES=\n"
+	   "SIMTABLE(TRUE,FALSE) returns TRUE on the first simulation round "
+	   "and FALSE on the second round.\n"
+           "SIMTABLE(223,225,227,229) returns 227 on the simulation round "
+           "#3.\n"
+           "\n"
+           "@SEEALSO=")
+};
+
+typedef struct {
+	int   index;
+	Value *value;
+} simtable_t;
+
+static Value *
+callback_function_simtable (const EvalPos *ep, Value *value, void *closure)
+{
+	simtable_t *p = closure;
+
+	if (p->index == ep->sheet->simulation_round)
+		p->value = value_duplicate (value);
+	++(p->index);
+
+	return NULL;
+}
+
+static Value *
+gnumeric_simtable (FunctionEvalInfo *ei, GnmExprList *nodes)
+{
+	simtable_t p;
+
+	p.index = 0;
+	p.value = NULL;
+
+	function_iterate_argument_values
+		(ei->pos, callback_function_simtable, &p, nodes,
+		 FALSE, CELL_ITER_IGNORE_BLANK);
+
+	/* See if there was any value worth using. */
+	if (p.value == NULL)
+		return value_new_error (ei->pos, gnumeric_err_NA);
+
+	return p.value;
+}
 
 /***************************************************************************/
 
@@ -825,7 +1106,9 @@ const ModulePluginFunctionInfo random_functions[] = {
 	  gnumeric_randcauchy, NULL, NULL, NULL },
         { "randchisq", "f", N_("nu"),   &help_randchisq,
 	  gnumeric_randchisq, NULL, NULL, NULL },
-        { "randexp", "f", N_("b"),         &help_randexp,
+ 	{ "randdiscrete", "r|r", N_("value_range,prob_range"),
+	  &help_randdiscrete, gnumeric_randdiscrete, NULL, NULL, NULL },
+	{ "randexp", "f", N_("b"),         &help_randexp,
 	  gnumeric_randexp, NULL, NULL, NULL },
         { "randexppow", "ff", N_("a,b"),         &help_randexppow,
 	  gnumeric_randexppow, NULL, NULL, NULL },
@@ -833,12 +1116,16 @@ const ModulePluginFunctionInfo random_functions[] = {
 	  gnumeric_randfdist, NULL, NULL, NULL },
         { "randgamma", "ff", N_("a,b"),    &help_randgamma,
 	  gnumeric_randgamma, NULL, NULL, NULL },
+        { "randgaussiantail", "ff", N_("a,sigma"),    &help_randgaussiantail,
+	  gnumeric_randgaussiantail, NULL, NULL, NULL },
         { "randgeom", "f", N_("p"),    &help_randgeom,
 	  gnumeric_randgeom, NULL, NULL, NULL },
         { "randgumbel", "ff|f", N_("a,b[,type]"),    &help_randgumbel,
 	  gnumeric_randgumbel, NULL, NULL, NULL },
         { "randhyperg", "fff", N_("n1,n2,t"),    &help_randhyperg,
 	  gnumeric_randhyperg, NULL, NULL, NULL },
+        { "randlandau", "", "", &help_randlandau,
+	  gnumeric_randlandau, NULL, NULL, NULL },
         { "randlaplace", "f", N_("a"), &help_randlaplace,
 	  gnumeric_randlaplace, NULL, NULL, NULL },
         { "randlevy", "ff|f", N_("c,alpha[,beta]"), &help_randlevy,
@@ -867,5 +1154,7 @@ const ModulePluginFunctionInfo random_functions[] = {
 	  gnumeric_randuniform, NULL, NULL, NULL },
         { "randweibull", "ff", N_("a,b"), &help_randweibull,
 	  gnumeric_randweibull, NULL, NULL, NULL },
+	{ "simtable", 0, N_("d1[,d2,...,dN]"), &help_simtable, NULL,
+	  gnumeric_simtable, NULL, NULL },
         {NULL}
 };
