@@ -59,12 +59,6 @@ typedef struct {
 
 int gb_debug = 0;
 
-gboolean
-plugin_can_deactivate_general (void)
-{
-	return FALSE;
-}
-
 void
 plugin_cleanup_general (ErrorInfo **ret_error)
 {
@@ -112,7 +106,7 @@ generic_marshaller (FunctionEvalInfo *ei, GList *nodes)
 		 * this can be relaxed.  We do not need to require
 		 * non emptiness, or scalarness.
 		 */
-		Value *v = expr_eval (l->data, ei->pos, EVAL_STRICT);
+		Value *v = gnm_expr_eval (l->data, ei->pos, GNM_EXPR_EVAL_STRICT);
 
 		args = g_slist_prepend (args, value_to_gb (v));
 
@@ -168,7 +162,7 @@ register_vb_function (Workbook         *opt_workbook,
 
 	/* FIXME: we need per workbook names */
 	fndef = function_add_nodes (cat, name, "", NULL, NULL,
-				    generic_marshaller);
+				    generic_marshaller, NULL);
 	function_def_set_user_data (fndef, wd);
 }
 
@@ -389,4 +383,6 @@ plugin_init_general (ErrorInfo **err)
 		}
 	}
 	g_free (proj_name);
+	/* Don't try to deactivate the plugin */
+	gnm_plugin_use_ref (PLUGIN);
 }
