@@ -37,7 +37,7 @@ GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 static GdaClient* connection_pool = NULL;
 
 static Value *
-display_recordset (GdaRecordset *recset)
+display_recordset (GdaDataModel *recset, FunctionEvalInfo *ei)
 {
 	Value* array = NULL;
 	gint   col;
@@ -45,33 +45,35 @@ display_recordset (GdaRecordset *recset)
 	gint   fieldcount = 0;
 	gint   rowcount = 0;
 
-	g_return_val_if_fail (GDA_IS_RECORDSET (recset), NULL);
+	g_return_val_if_fail (GDA_IS_DATA_MODEL (recset), NULL);
 
 	fieldcount = gda_data_model_get_n_columns (GDA_DATA_MODEL (recset));
 	rowcount = gda_data_model_get_n_rows (GDA_DATA_MODEL (recset));
 
-	/* convert the GdaRecordset in an array */
-	if (rowcount > 0) {
-		array = value_new_array_empty (fieldcount, rowcount);
-		for (row = 0; row < rowcount; row++) {
-			for (col = 0; col < fieldcount; col++) {
-				gchar *str;
-				const GdaValue *value;
+	/* convert the GdaDataModel in an array */
+	if (rowcount <= 0)
+		return value_new_empty ();
 
-				value = gda_data_model_get_value_at (GDA_DATA_MODEL (recset),
-								     col, row);
-				str = gda_value_stringify ((GdaValue *) value);
-				value_array_set (array,
-						 col,
-						 row,
-						 value_new_string(str));
+	if (rowcount >= SHEET_MAX_ROWS)
+		return value_new_error (ei->pos, _("Too much data returned"));
 
-				g_free (str);
-			}
+	array = value_new_array_empty (fieldcount, rowcount);
+	for (row = 0; row < rowcount; row++) {
+		for (col = 0; col < fieldcount; col++) {
+			gchar *str;
+			const GdaValue *value;
+
+			value = gda_data_model_get_value_at (GDA_DATA_MODEL (recset),
+							     col, row);
+			str = gda_value_stringify ((GdaValue *) value);
+			value_array_set (array,
+					 col,
+					 row,
+					 value_new_string(str));
+
+			g_free (str);
 		}
 	}
-	else
-		array = value_new_array_empty (1, 1);
 
 	return array;
 }
@@ -102,7 +104,7 @@ gnumeric_execSQL (FunctionEvalInfo *ei, Value **args)
 	gchar*         password;
 	gchar*         sql;
 	GdaConnection* cnc;
-	GdaRecordset*  recset;
+	GdaDataModel*  recset;
 	GList*         recset_list;
 	GdaCommand*    cmd;
 
@@ -130,16 +132,15 @@ gnumeric_execSQL (FunctionEvalInfo *ei, Value **args)
 	recset_list = gda_connection_execute_command (cnc, cmd, NULL);
 	gda_command_free (cmd);
 	if (recset_list) {
-		recset = (GdaRecordset *) recset_list->data;
-		if (!GDA_IS_RECORDSET (recset))
+		recset = (GdaDataModel *) recset_list->data;
+		if (!GDA_IS_DATA_MODEL (recset))
 			ret = value_new_error (ei->pos, _("Error: no recordsets were returned"));
 		else
-			ret = display_recordset (recset);
+			ret = display_recordset (recset, ei);
 
 		g_list_foreach (recset_list, (GFunc) g_object_unref, NULL);
 		g_list_free (recset_list);
-	}
-	else
+	} else
 		ret = value_new_empty ();
 
 	return ret;
