@@ -112,7 +112,6 @@ gnm_guile_catcher (void *data, SCM tag, SCM throw_args)
 	char *msg;
 	char buf[256];
 	Value *v;
-	int len;
 
 	func = scm_c_eval_string ("gnm:error->string");
 	if (scm_procedure_p (func)) {
@@ -170,6 +169,12 @@ func_marshal_func (FunctionEvalInfo *ei, Value *argv[])
 	return scm_to_value (result);
 }
 
+/*
+ * FIXME: If we clean up at exit, removing the registered functions, we get
+ * rid of the 'Leaking string [Guile] with ref_count=1' warnings. The way we
+ * do this for other plugins, including Python, we deactivate the
+ * plugin. However, it is not possible to finalize Guile.
+ */
 static SCM
 scm_register_function (SCM scm_name, SCM scm_args, SCM scm_help, SCM scm_category, SCM scm_function)
 {
@@ -192,19 +197,13 @@ scm_register_function (SCM scm_name, SCM scm_args, SCM scm_help, SCM scm_categor
 	cat   = function_get_category (SCM_CHARS (scm_category));
 	fndef = function_add_args (cat, g_strdup (SCM_CHARS (scm_name)),
 				   g_strdup (SCM_CHARS (scm_args)), NULL,
-				   help, func_marshal_func);
+				   help, func_marshal_func, NULL);
 
 	function_def_set_user_data (fndef, GINT_TO_POINTER (scm_function));
 
 	return SCM_UNSPECIFIED;
 }
 
-gboolean
-plugin_can_deactivate_general (void)
-{
-	return FALSE;
-}
-
 void
 plugin_cleanup_general (ErrorInfo **ret_error)
 {
@@ -214,7 +213,6 @@ plugin_cleanup_general (ErrorInfo **ret_error)
 void
 plugin_init_general (ErrorInfo **ret_error)
 {
-	FunctionCategory *cat;
 	char *name, *dir;
 
 	*ret_error = NULL;
@@ -224,8 +222,6 @@ plugin_init_general (ErrorInfo **ret_error)
 	/* Initialize just in case. */
 	eval_pos = NULL;
 
-	cat = function_get_category ("Guile");
-
 	init_value_type ();
 
 	scm_c_define_gsubr ("gnumeric-funcall", 2, 0, 0, scm_gnumeric_funcall);
@@ -241,4 +237,6 @@ plugin_init_general (ErrorInfo **ret_error)
 		  SCM_EOL);
 	g_free (name);
 	g_free (dir);
+	/* Don't try to deactivate the plugin */
+	gnm_plugin_use_ref (PLUGIN);
 }
