@@ -4,7 +4,6 @@
  *
  * Authors:
  *   Jukka-Pekka Iivonen <jiivonen@hutcs.cs.hut.fi>
- *   File handling code copied from Dif module.
  *
  *      Reads an MPS file and stores the data in it in data structures
  *      defined in mps.h.
@@ -63,47 +62,12 @@
 static gboolean
 mps_get_line (MpsInputContext *ctxt)
 {
-        guchar *p, *p_limit;
-
- try_again:
-	p_limit = ctxt->data + ctxt->data_size;
-	if (ctxt->cur >= p_limit) {
-	        ctxt->line[0] = '\0';
-		ctxt->line_len = 0;
-		return FALSE;
-	}
-
-	for (p = ctxt->cur; p < p_limit && p[0] != '\n' && p[0] != '\r'; p++);
-
-	ctxt->line_len = p - ctxt->cur;
-	if (ctxt->line_len > ctxt->alloc_line_len) {
-	        g_free (ctxt->line);
-		ctxt->alloc_line_len = MAX (ctxt->alloc_line_len * 2,
-					    ctxt->line_len);
-		ctxt->line = g_malloc (ctxt->alloc_line_len + 1);
-	}
-	if (ctxt->line_len > 0) {
-	        memcpy (ctxt->line, ctxt->cur, ctxt->line_len);
-	}
-	ctxt->line[ctxt->line_len] = '\0';
-
-	if (p == p_limit || (p == p_limit - 1 && (p[0] == '\n' ||
-						  p[0] == '\r'))) {
-	        ctxt->cur = p_limit;
-	} else if ((p[0] == '\n' && p[1] == '\r') || (p[0] == '\r' &&
-						      p[1] == '\n')) {
-	        ctxt->cur = p + 2;
-	} else {
-	        ctxt->cur = p + 1;
-	}
-
-	if ((++ctxt->line_no % N_INPUT_LINES_BETWEEN_UPDATES) == 0) {
-	        memory_io_progress_update (ctxt->io_context, ctxt->cur);
-	}
-
-	/* Check if a comment line */
-	if (ctxt->line[0] == '*')
-	        goto try_again;
+	do {
+		ctxt->line = gsf_input_textline_ascii_gets (ctxt->input);
+		if (ctxt->line == NULL)
+			return FALSE;
+		/* Check if a comment or empty line */
+	} while (ctxt->line[0] == '*' || ctxt->line[0] == '\0');
 
 	return TRUE;
 }
@@ -112,12 +76,12 @@ static gboolean
 mps_parse_data (gchar *str, gchar *type, gchar *name1, gchar *name2,
 		gchar *value1, gchar *name3, gchar *value2)
 {
-        gint i;
+        gint  i;
 	gchar *n1 = name1;
 	gchar *n2 = name2;
 	gchar *n3 = name3;
 
-	for (i=0; i<8; i++)
+	for (i = 0; i < 8; i++)
 	        name1[i] = name2[i] = name3[i] = ' ';
 	*value2 = *name3 = '\0';
         if (!(*str) || *str++ != ' ' || !(*str))
@@ -155,7 +119,7 @@ mps_parse_data (gchar *str, gchar *type, gchar *name1, gchar *name2,
 	        goto ok_out;
 	if (*str++ != ' ')
 	        return FALSE;
-	for (i=15; i<=22; i++, str++) {
+	for (i = 15; i <= 22; i++, str++) {
 	        *name2++ = *str;
 		if (!(*str))
 		        return FALSE;
@@ -165,7 +129,7 @@ mps_parse_data (gchar *str, gchar *type, gchar *name1, gchar *name2,
 	/* Value 1 */
 	if (!(*str) || *str++ != ' ' || !(*str) || *str++ != ' ')
 	        return FALSE;
-	for (i=25; i<=36; i++, str++) {
+	for (i = 25; i <= 36; i++, str++) {
 	        *value1++ = *str;
 		if (!(*str))
 		        goto ok_out;
@@ -185,7 +149,7 @@ mps_parse_data (gchar *str, gchar *type, gchar *name1, gchar *name2,
 	        goto ok_out;
 	if (*str++ != ' ')
 	        return FALSE;
-	for (i=40; i<=47; i++, str++) {
+	for (i = 40; i <= 47; i++, str++) {
 	        *name3++ = *str;
 		if (!(*str))
 		        return FALSE;
@@ -195,7 +159,7 @@ mps_parse_data (gchar *str, gchar *type, gchar *name1, gchar *name2,
 	/* Value 2 */
 	if (!(*str) || *str++ != ' ' || !(*str) || *str++ != ' ')
 	        return FALSE;
-	for (i=50; i<=61; i++, str++) {
+	for (i = 50; i <= 61; i++, str++) {
 	        *value2++ = *str;
 		if (!(*str))
 		        goto ok_out;
@@ -203,15 +167,15 @@ mps_parse_data (gchar *str, gchar *type, gchar *name1, gchar *name2,
 	*value2 = '\0';
 
  ok_out:
-	for (i=7; i>=0; i--)
+	for (i = 7; i >= 0; i--)
 	        if (n1[i] != ' ')
 		        break;
 	n1[i+1] = '\0';
-	for (i=7; i>=0; i--)
+	for (i = 7; i >= 0; i--)
 	        if (n2[i] != ' ')
 		        break;
 	n2[i+1] = '\0';
-	for (i=7; i>=0; i--)
+	for (i = 7; i >= 0; i--)
 	        if (n3[i] != ' ')
 		        break;
 	n3[i+1] = '\0';
@@ -244,9 +208,7 @@ mps_parse_name (MpsInputContext *ctxt)
 			while (isspace ((unsigned char) *line))
 			        line++;
 
-			ctxt->name = strcpy (g_malloc (ctxt->line_len -
-						       (line-ctxt->line) + 1),
-					     line);
+			ctxt->name = g_strdup (ctxt->line);
 			break;
 		} else
 		        return FALSE;
@@ -272,15 +234,17 @@ mps_add_row (MpsInputContext *ctxt, MpsRowType type, gchar *txt)
 	if (len == 0)
 	          return FALSE;
 
-	row->name = strcpy (g_malloc (len + 1), txt);
+	row->name = g_strdup (txt);
 	row->type = type;
-	row->index = ctxt->n_rows;
-	ctxt->n_rows += 1;
-
-	ctxt->rows = g_slist_prepend (ctxt->rows, row);
 
 	if (type == ObjectiveRow)
 	          ctxt->objective_row = row;
+	else {
+		row->index = ctxt->n_rows;
+		ctxt->n_rows += 1;
+
+		ctxt->rows = g_slist_prepend (ctxt->rows, row);
+	}
 
 	return TRUE;
 }
@@ -339,10 +303,12 @@ mps_parse_rows (MpsInputContext *ctxt)
  ok_out:
 	for (tmp = ctxt->rows; tmp != NULL; tmp = tmp->next) {
 	        MpsRow *row = (MpsRow *) tmp->data;
-		g_hash_table_insert (ctxt->row_hash,
-				     row->name,
-				     (gpointer) row);
+		g_hash_table_insert (ctxt->row_hash, row->name, (gpointer) row);
 	}
+	g_hash_table_insert (ctxt->row_hash, ctxt->objective_row->name,
+			     (gpointer) ctxt->objective_row);
+	ctxt->objective_row->index = ctxt->n_rows;
+	ctxt->n_rows += 1;
 
 	return TRUE;
 }
@@ -353,16 +319,17 @@ static gboolean
 mps_add_column (MpsInputContext *ctxt, gchar *row_name, gchar *col_name,
 		gchar *value_str)
 {
-        MpsCol *col;
-	MpsRow *row;
+        MpsCol     *col;
+	MpsRow     *row;
 	MpsColInfo *i;
 
 	row = (MpsRow *) g_hash_table_lookup (ctxt->row_hash, row_name);
 	if (row == NULL)
 	          return FALSE;
-	col = g_new (MpsCol, 1);
-	col->row = row;
-	col->name = g_strdup (col_name);
+
+	col        = g_new (MpsCol, 1);
+	col->row   = row;
+	col->name  = g_strdup (col_name);
 	col->value = atof (value_str);
 	ctxt->cols = g_slist_prepend (ctxt->cols, col);
 
@@ -433,13 +400,13 @@ mps_add_rhs (MpsInputContext *ctxt, gchar *rhs_name, gchar *row_name,
 {
         MpsRhs *rhs;
 
-	rhs = g_new (MpsRhs, 1);
+	rhs       = g_new (MpsRhs, 1);
 	rhs->name = g_strdup (rhs_name);
-	rhs->row = (MpsRow *) g_hash_table_lookup (ctxt->row_hash, row_name);
+	rhs->row  = (MpsRow *) g_hash_table_lookup (ctxt->row_hash, row_name);
 	if (rhs->row == NULL)
 	          return FALSE;
 	rhs->value = atof (value_str);
-	ctxt->rhs = g_slist_prepend (ctxt->rhs, rhs);
+	ctxt->rhs  = g_slist_prepend (ctxt->rhs, rhs);
 
 	return TRUE;
 }
@@ -496,17 +463,37 @@ mps_add_bound (MpsInputContext *ctxt, MpsBoundType type, gchar *bound_name,
 	if (info == NULL)
 	        return FALSE;  /* Column is not defined */
 
-	bound = g_new (MpsBound, 1);
-	bound->name = g_new (gchar, strlen (bound_name) + 13);
+	bound            = g_new (MpsBound, 1);
+	bound->name      = g_new (gchar, strlen (bound_name) + 13);
 	sprintf(bound->name, "Bound #%d: %s", ctxt->n_bounds + 1, bound_name);
 	bound->col_index = info->index;
-	bound->value = atof (value_str);
-	ctxt->bounds = g_slist_prepend (ctxt->bounds, bound);
+	bound->value     = atof (value_str);
+	bound->type      = type;
+	ctxt->bounds     = g_slist_prepend (ctxt->bounds, bound);
 	(ctxt->n_bounds)++;
 
 	return TRUE;
 }
 
+/*
+ * RANGES section parsing.  Ranges are currently not supported.
+ *
+ * Returns FALSE on error.
+ */
+static gboolean
+mps_parse_ranges (MpsInputContext *ctxt)
+{
+	/* gchar        type[3], n1[10], n2[10], v1[20], n3[10], v2[20]; */
+
+	if (strncmp (ctxt->line, "ENDATA", 6) == 0)
+	        return TRUE;
+
+	if (strncmp (ctxt->line, "RANGES", 6) != 0 || ctxt->line[6] != '\0')
+	        return TRUE;
+
+	return FALSE;
+}
+
 /*
  * BOUNDS section parsing.  Saves the bounds into `ctxt->bounds' GSList.
  * Each list element is MpsBound, and their `name', `col_index', and `value'
@@ -517,7 +504,8 @@ mps_add_bound (MpsInputContext *ctxt, MpsBoundType type, gchar *bound_name,
 static gboolean
 mps_parse_bounds (MpsInputContext *ctxt)
 {
-	gchar type[3], n1[10], n2[10], v1[20], n3[10], v2[20];
+	gchar        type[3], n1[10], n2[10], v1[20], n3[10], v2[20];
+	MpsBoundType t;
 
 	if (strncmp (ctxt->line, "ENDATA", 6) == 0)
 	        return TRUE;
@@ -536,11 +524,17 @@ mps_parse_bounds (MpsInputContext *ctxt)
 			        return FALSE;
 		}
 
-		if (strncmp (type, "UP", 2) == 0) {
-			if (!mps_add_bound (ctxt, UpperBound, n1, n2, v1))
-			        return FALSE;
-		} else
-		        return FALSE; /* Only upper bounds are implemented */
+		if (strncmp (type, "UP", 2) == 0)
+			t = UpperBound;
+		else if (strncmp (type, "LO", 2) == 0)
+			t = LowerBound;
+		else if (strncmp (type, "FX", 2) == 0)
+			t = FixedVariable;
+		else
+		        return FALSE; /* Not all bound types are implemented */
+
+		if (!mps_add_bound (ctxt, t, n1, n2, v1))
+			return FALSE;
 	}
 }
 
@@ -570,6 +564,11 @@ mps_parse_file (MpsInputContext *ctxt)
 			(ctxt->io_context,
 			 error_info_new_printf (_("Invalid RHS section in the "
 						  "file.")));
+	} else if (!mps_parse_ranges (ctxt)) {
+	        gnumeric_io_error_info_set
+			(ctxt->io_context,
+			 error_info_new_printf (_("Invalid RANGES section in "
+						  "the file.")));
 	} else if (!mps_parse_bounds (ctxt)) {
 	        gnumeric_io_error_info_set
 			(ctxt->io_context,
