@@ -7,10 +7,13 @@
 #include <gnumeric-config.h>
 #include <gnumeric.h>
 #include <Python.h>
+#ifdef WITH_PYGTK
+#include "pygobject.h"
+#endif
 #include <glib.h>
 #include <libgnome/libgnome.h>
 #include <gal/util/e-xml-utils.h>
-#include <gal/util/e-util.h>
+#include <gsf/gsf-impl-utils.h>
 #include <libxml/parser.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
@@ -28,8 +31,6 @@
 #include "module-plugin-defs.h"
 #include "py-gnumeric.h"
 
-#define BROKEN_PY_INITIALIZE
-
 
 GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 
@@ -65,14 +66,17 @@ struct _GnumericPluginLoaderPythonClass {
 
 static GnumericPluginLoaderClass *parent_class = NULL;
 
-static void gnumeric_plugin_loader_python_set_attributes (GnumericPluginLoader *loader, GSList *attr_names, GSList *attr_values, ErrorInfo **ret_error);
-static void gnumeric_plugin_loader_python_load (GnumericPluginLoader *loader, ErrorInfo **ret_error);
-static void gnumeric_plugin_loader_python_unload (GnumericPluginLoader *loader, ErrorInfo **ret_error);
+static void gnumeric_plugin_loader_python_set_attributes (GnumericPluginLoader *loader, GHashTable *attrs, ErrorInfo **ret_error);
+static void gnumeric_plugin_loader_python_load_base (GnumericPluginLoader *loader, ErrorInfo **ret_error);
+static void gnumeric_plugin_loader_python_unload_base (GnumericPluginLoader *loader, ErrorInfo **ret_error);
 static void gnumeric_plugin_loader_python_load_service_file_opener (GnumericPluginLoader *loader, PluginService *service, ErrorInfo **ret_error);
 static void gnumeric_plugin_loader_python_load_service_file_saver (GnumericPluginLoader *loader, PluginService *service, ErrorInfo **ret_error);
 static void gnumeric_plugin_loader_python_load_service_function_group (GnumericPluginLoader *loader, PluginService *service, ErrorInfo **ret_error);
 static void gnumeric_plugin_loader_python_unload_service_function_group (GnumericPluginLoader *loader, PluginService *service, ErrorInfo **ret_error);
 
+#define SWITCH_TO_PLUGIN(plugin) \
+switch_python_interpreter_if_needed (GNUMERIC_PLUGIN_LOADER_PYTHON (g_object_get_data (G_OBJECT (plugin), "python-loader"))->py_interpreter_info)
+
 
 #ifdef BROKEN_PY_INITIALIZE
 extern char **environ;
@@ -87,42 +91,30 @@ initialize_python_if_needed (void)
 #ifdef BROKEN_PY_INITIALIZE
 		int i;
 
-		/* Python's convertenviron has gotten into its head that it can
-		   write to the strings in the environment.  We have little choice
-		but to allocate a copy of everything. */
+		/* Before Python 2.0, Python's convertenviron would write to
+		   the strings in the environment.  We had little choice but
+		   to allocate a copy of everything. */
+
 		for (i = 0; environ[i]; i++)
 			environ[i] = g_strdup (environ[i]);
 #endif
 		Py_Initialize ();
 		PyEval_InitThreads ();
+#ifdef WITH_PYGTK
+		init_pygobject ();
+#endif
 		python_initialized = TRUE;
 	}
 }
 
 static void
-gnumeric_plugin_loader_python_set_attributes (GnumericPluginLoader *loader, GSList *attr_names, GSList *attr_values, ErrorInfo **ret_error)
+gnumeric_plugin_loader_python_set_attributes (GnumericPluginLoader *loader, GHashTable *attrs, ErrorInfo **ret_error)
 {
-	GnumericPluginLoaderPython *loader_python;
+	GnumericPluginLoaderPython *loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
 	gchar *module_name = NULL;
-	GSList *ln, *lv;
-
-	g_return_if_fail (IS_GNUMERIC_PLUGIN_LOADER_PYTHON (loader));
-	g_return_if_fail (ret_error != NULL);
-
-	*ret_error = NULL;
-	loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
-	for (ln = attr_names, lv = attr_values;
-	     ln != NULL && lv != NULL;
-	     ln = ln->next, lv = lv->next) {
-		gchar *name, *value;
-
-		name = (gchar *) ln->data;
-		value = (gchar *) lv->data;
-		if (strcmp ((gchar *) ln->data, "module_name") == 0) {
-			module_name = (gchar *) lv->data;
-		}
-	}
 
+	GNM_INIT_RET_ERROR_INFO (ret_error);
+	module_name = g_hash_table_lookup (attrs, "module_name");
 	if (module_name != NULL) {
 		loader_python->module_name = g_strdup (module_name);
 	} else {
@@ -132,9 +124,9 @@ gnumeric_plugin_loader_python_set_attributes (GnumericPluginLoader *loader, GSLi
 }
 
 static void
-gnumeric_plugin_loader_python_load (GnumericPluginLoader *loader, ErrorInfo **ret_error)
+gnumeric_plugin_loader_python_load_base (GnumericPluginLoader *loader, ErrorInfo **ret_error)
 {
-	GnumericPluginLoaderPython *loader_python;
+	GnumericPluginLoaderPython *loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
 	const gchar *python_file_extensions[]
 		= {"py", "pyc", "pyo", NULL}, **file_ext;
 	InterpreterInfo *py_interpreter_info;
@@ -142,11 +134,8 @@ gnumeric_plugin_loader_python_load (GnumericPluginLoader *loader, ErrorInfo **re
 	FILE *f;
 	ErrorInfo *open_error;
 
-	g_return_if_fail (IS_GNUMERIC_PLUGIN_LOADER_PYTHON (loader));
-	g_return_if_fail (ret_error != NULL);
-
-	*ret_error = NULL;
-	loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
+	GNM_INIT_RET_ERROR_INFO (ret_error);
+	g_object_set_data (G_OBJECT (loader->plugin), "python-loader", loader);
 	initialize_python_if_needed ();
 
 	py_interpreter_info = create_python_interpreter (loader->plugin);
@@ -160,7 +149,7 @@ gnumeric_plugin_loader_python_load (GnumericPluginLoader *loader, ErrorInfo **re
 		gchar *file_name = g_strconcat (
 			loader_python->module_name, ".", *file_ext, NULL);
 		gchar *path = g_build_filename (
-			plugin_info_peek_dir_name (loader->plugin),
+			gnm_plugin_get_dir_name (loader->plugin),
 			file_name, NULL);
 		g_free (file_name);
 		if (g_file_test (path, G_FILE_TEST_EXISTS)) {
@@ -204,44 +193,15 @@ gnumeric_plugin_loader_python_load (GnumericPluginLoader *loader, ErrorInfo **re
 }
 
 static void
-gnumeric_plugin_loader_python_unload (GnumericPluginLoader *loader, ErrorInfo **ret_error)
+gnumeric_plugin_loader_python_unload_base (GnumericPluginLoader *loader, ErrorInfo **ret_error)
 {
-	GnumericPluginLoaderPython *loader_python;
+	GnumericPluginLoaderPython *loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
 
-	g_return_if_fail (IS_GNUMERIC_PLUGIN_LOADER_PYTHON (loader));
-	g_return_if_fail (ret_error != NULL);
-
-	*ret_error = NULL;
-	loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
+	GNM_INIT_RET_ERROR_INFO (ret_error);
+	g_object_steal_data (G_OBJECT (loader->plugin), "python-loader");
 	destroy_python_interpreter (loader_python->py_interpreter_info);
 }
 
-static gint
-gnumeric_plugin_loader_python_info_get_extra_info_list (GnumericPluginLoader *loader,
-                                                        GSList **ret_keys_list,
-                                                        GSList **ret_values_list)
-{
-	GnumericPluginLoaderPython *loader_python;
-	GSList *keys_list = NULL, *values_list = NULL;
-	gint n_items = 0;
-
-	g_return_val_if_fail (IS_GNUMERIC_PLUGIN_LOADER_PYTHON (loader), 0);
-	g_return_val_if_fail (ret_keys_list != NULL && ret_values_list != NULL, 0);
-
-	loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
-	keys_list = g_slist_prepend (keys_list, g_strdup (_("Loader")));
-	values_list = g_slist_prepend (values_list, g_strdup ("python"));
-	n_items++;
-	keys_list = g_slist_prepend (keys_list, g_strdup (_("Python module name")));
-	values_list = g_slist_prepend (values_list, g_strdup (loader_python->module_name));
-	n_items++;
-
-	*ret_keys_list = g_slist_reverse (keys_list);
-	*ret_values_list = g_slist_reverse (values_list);
-
-	return n_items;
-}
-
 static void
 gnumeric_plugin_loader_python_init (GnumericPluginLoaderPython *loader_python)
 {
@@ -254,11 +214,8 @@ gnumeric_plugin_loader_python_init (GnumericPluginLoaderPython *loader_python)
 static void
 gnumeric_plugin_loader_python_destroy (GtkObject *obj)
 {
-	GnumericPluginLoaderPython *loader_python;
+	GnumericPluginLoaderPython *loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (obj);
 
-	g_return_if_fail (IS_GNUMERIC_PLUGIN_LOADER_PYTHON (obj));
-
-	loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (obj);
 	g_free (loader_python->module_name);
 }
 
@@ -271,19 +228,19 @@ gnumeric_plugin_loader_python_class_init (GnumericPluginLoaderPythonClass *klass
 	parent_class = gtk_type_class (PARENT_TYPE);
 
 	gnumeric_plugin_loader_class->set_attributes = gnumeric_plugin_loader_python_set_attributes;
-	gnumeric_plugin_loader_class->load = gnumeric_plugin_loader_python_load;
-	gnumeric_plugin_loader_class->unload = gnumeric_plugin_loader_python_unload;
+	gnumeric_plugin_loader_class->load_base = gnumeric_plugin_loader_python_load_base;
+	gnumeric_plugin_loader_class->unload_base = gnumeric_plugin_loader_python_unload_base;
 	gnumeric_plugin_loader_class->load_service_file_opener = gnumeric_plugin_loader_python_load_service_file_opener;
 	gnumeric_plugin_loader_class->load_service_file_saver = gnumeric_plugin_loader_python_load_service_file_saver;
 	gnumeric_plugin_loader_class->load_service_function_group = gnumeric_plugin_loader_python_load_service_function_group;
 	gnumeric_plugin_loader_class->unload_service_function_group = gnumeric_plugin_loader_python_unload_service_function_group;
-	gnumeric_plugin_loader_class->get_extra_info_list = gnumeric_plugin_loader_python_info_get_extra_info_list;
 
 	gtk_object_class->destroy = gnumeric_plugin_loader_python_destroy;
 }
 
-E_MAKE_TYPE (gnumeric_plugin_loader_python, "GnumericPluginLoaderPython", GnumericPluginLoaderPython,
-	     &gnumeric_plugin_loader_python_class_init, gnumeric_plugin_loader_python_init, PARENT_TYPE)
+GSF_CLASS (GnumericPluginLoaderPython, gnumeric_plugin_loader_python,
+	   gnumeric_plugin_loader_python_class_init,
+	   gnumeric_plugin_loader_python_init, PARENT_TYPE)
 
 /*
  * Service - file_opener
@@ -295,20 +252,36 @@ typedef struct {
 } ServiceLoaderDataFileOpener;
 
 static gboolean
-gnumeric_plugin_loader_python_func_file_probe (GnumFileOpener const *fo, PluginService *service,
-                                               const gchar *file_name, FileProbeLevel pl)
+gnumeric_plugin_loader_python_func_file_probe (
+	GnumFileOpener const *fo, PluginService *service,
+	GsfInput *input, FileProbeLevel pl)
 {
+#ifndef WITH_PYGTK
+	g_warning ("Probing from Python plugins requires gnome-python "
+		   "and Python bindings for libgsf");
+	return FALSE;
+#else	
 	ServiceLoaderDataFileOpener *loader_data;
-	PyObject *probe_result;
+	PyObject *probe_result = NULL;
+	PyObject *input_wrapper;
 	gboolean result;
 
-	g_return_val_if_fail (service != NULL, FALSE);
-	g_return_val_if_fail (file_name != NULL, FALSE);
+	g_return_val_if_fail (GNM_IS_PLUGIN_SERVICE_FILE_OPENER (service), FALSE);
+	g_return_val_if_fail (input != NULL, FALSE);
 
-	loader_data = (ServiceLoaderDataFileOpener *) plugin_service_get_loader_data (service);
-	switch_python_interpreter_if_needed (GNUMERIC_PLUGIN_LOADER_PYTHON (plugin_info_get_loader (service->plugin))->py_interpreter_info);
-	probe_result = PyObject_CallFunction
-		(loader_data->python_func_file_probe, (char *) "s", file_name);
+	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
+	SWITCH_TO_PLUGIN (plugin_service_get_plugin (service));
+	input_wrapper = pygobject_new (G_OBJECT (input));
+	if (input_wrapper == NULL) {
+		g_warning (convert_python_exception_to_string ());
+		clear_python_error_if_needed ();
+	}
+	if (input_wrapper != NULL) {
+		probe_result = PyObject_CallFunction
+			(loader_data->python_func_file_probe, 
+			 (char *) "O", input_wrapper);
+		Py_DECREF (input_wrapper);
+	}
 	if (probe_result != NULL) {
 		result = PyObject_IsTrue (probe_result);
 		Py_DECREF (probe_result);
@@ -318,26 +291,41 @@ gnumeric_plugin_loader_python_func_file_probe (GnumFileOpener const *fo, PluginS
 	}
 
 	return result;
+#endif
 }
 
 static void
-gnumeric_plugin_loader_python_func_file_open (GnumFileOpener const *fo, PluginService *service,
-                                              IOContext *io_context, WorkbookView *wb_view,
-                                              const gchar *file_name)
+gnumeric_plugin_loader_python_func_file_open (GnumFileOpener const *fo, 
+					      PluginService *service,
+                                              IOContext *io_context, 
+					      WorkbookView *wb_view,
+                                              GsfInput *input)
 {
+#ifndef WITH_PYGTK
+	gnumeric_io_error_string
+		(io_context,
+		 "File opening from python plugins requires gnome-python "
+		 "and Python bindings for libgsf");
+#else	
 	ServiceLoaderDataFileOpener *loader_data;
 	Sheet *sheet;
-	PyObject *open_result;
+	PyObject *open_result = NULL;
+	PyObject *input_wrapper;
 
-	g_return_if_fail (service != NULL);
-	g_return_if_fail (file_name != NULL);
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FILE_OPENER (service));
+	g_return_if_fail (input != NULL);
 
-	loader_data = (ServiceLoaderDataFileOpener *) plugin_service_get_loader_data (service);
-	switch_python_interpreter_if_needed (GNUMERIC_PLUGIN_LOADER_PYTHON (plugin_info_get_loader (service->plugin))->py_interpreter_info);
+	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
+	SWITCH_TO_PLUGIN (plugin_service_get_plugin (service));
 	sheet = sheet_new (wb_view_workbook (wb_view), _("Some name"));
-	open_result = PyObject_CallFunction
-		(loader_data->python_func_file_open,
-		 (char *) "Ns", py_new_Sheet_object (sheet), file_name);
+	input_wrapper = pygobject_new (G_OBJECT (input));
+	if (input_wrapper != NULL) {
+		open_result = PyObject_CallFunction
+			(loader_data->python_func_file_open,
+			 (char *) "NO", 
+			 py_new_Sheet_object (sheet), input_wrapper);
+		Py_DECREF (input_wrapper);
+	}
 	if (open_result != NULL) {
 		Py_DECREF (open_result);
 		workbook_sheet_attach (wb_view_workbook (wb_view), sheet, NULL);
@@ -346,6 +334,7 @@ gnumeric_plugin_loader_python_func_file_open (GnumFileOpener const *fo, PluginSe
 		clear_python_error_if_needed ();
 		sheet_destroy (sheet);
 	}
+#endif
 }
 
 static void
@@ -353,63 +342,44 @@ gnumeric_plugin_loader_python_load_service_file_opener (GnumericPluginLoader *lo
                                                         PluginService *service,
                                                         ErrorInfo **ret_error)
 {
-	GnumericPluginLoaderPython *loader_python;
-	PluginServiceFileOpener *service_file_opener;
+	GnumericPluginLoaderPython *loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
 	gchar *func_name_file_probe, *func_name_file_open;
 	PyObject *python_func_file_probe, *python_func_file_open;
 
-	g_return_if_fail (IS_GNUMERIC_PLUGIN_LOADER_PYTHON (loader));
-	g_return_if_fail (service != NULL);
-	g_return_if_fail (ret_error != NULL);
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FILE_OPENER (service));
 
-	*ret_error = NULL;
-	loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
+	GNM_INIT_RET_ERROR_INFO (ret_error);
 	switch_python_interpreter_if_needed (loader_python->py_interpreter_info);
-	service_file_opener = &service->t.file_opener;
-	if (service_file_opener->has_probe) {
-		func_name_file_probe = g_strdup_printf ("%s_file_probe", service_file_opener->id);
-		python_func_file_probe = PyDict_GetItemString (loader_python->main_module_dict,
-		                                               func_name_file_probe);
-		clear_python_error_if_needed ();
-	} else {
-		func_name_file_probe = NULL;
-		python_func_file_probe = NULL;
-	}
-	func_name_file_open = g_strdup_printf ("%s_file_open", service_file_opener->id);
+	func_name_file_probe = g_strconcat (
+		plugin_service_get_id (service), "_file_probe", NULL);
+	python_func_file_probe = PyDict_GetItemString (loader_python->main_module_dict,
+	                                               func_name_file_probe);
+	clear_python_error_if_needed ();
+	func_name_file_open = g_strconcat (
+		plugin_service_get_id (service), "_file_open", NULL);
 	python_func_file_open = PyDict_GetItemString (loader_python->main_module_dict,
 	                                              func_name_file_open);
 	clear_python_error_if_needed ();
-	if ((!service_file_opener->has_probe || python_func_file_probe != NULL) &&
-	    python_func_file_open != NULL) {
+	if (python_func_file_open != NULL) {
+		PluginServiceFileOpenerCallbacks *cbs;
 		ServiceLoaderDataFileOpener *loader_data;
 
-		if (service_file_opener->has_probe) {
-			service_file_opener->plugin_func_file_probe = gnumeric_plugin_loader_python_func_file_probe;
-		} else {
-			service_file_opener->plugin_func_file_probe = NULL;
-		}
-		service_file_opener->plugin_func_file_open = gnumeric_plugin_loader_python_func_file_open;
+		cbs = plugin_service_get_cbs (service);
+		cbs->plugin_func_file_probe = gnumeric_plugin_loader_python_func_file_probe;
+		cbs->plugin_func_file_open = gnumeric_plugin_loader_python_func_file_open;
 
 		loader_data = g_new (ServiceLoaderDataFileOpener, 1);
 		loader_data->python_func_file_probe = python_func_file_probe;
 		loader_data->python_func_file_open = python_func_file_open;
-		plugin_service_set_loader_data (service, (gpointer) loader_data);
+		g_object_set_data (G_OBJECT (service), "loader_data", loader_data);
 	} else {
 		*ret_error = error_info_new_printf (
 		             _("Python file \"%s\" has invalid format."),
 		             loader_python->module_name);
-		if (service_file_opener->has_probe && python_func_file_probe == NULL) {
-			error_info_add_details (*ret_error,
-			                        error_info_new_printf (
-			                        _("File doesn't contain \"%s\" function."),
-			                        func_name_file_probe));
-		}
-		if (python_func_file_open == NULL) {
-			error_info_add_details (*ret_error,
-			                        error_info_new_printf (
-			                        _("File doesn't contain \"%s\" function."),
-			                        func_name_file_open));
-		}
+		error_info_add_details (*ret_error,
+		                        error_info_new_printf (
+		                        _("File doesn't contain \"%s\" function."),
+		                        func_name_file_open));
 	}
 	g_free (func_name_file_probe);
 	g_free (func_name_file_open);
@@ -432,11 +402,11 @@ gnumeric_plugin_loader_python_func_file_save (GnumFileSaver const *fs, PluginSer
 	PyObject *py_workbook;
 	PyObject *save_result;
 
-	g_return_if_fail (service != NULL);
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FILE_SAVER (service));
 	g_return_if_fail (file_name != NULL);
 
-	saver_data = (ServiceLoaderDataFileSaver *) plugin_service_get_loader_data (service);
-	switch_python_interpreter_if_needed (GNUMERIC_PLUGIN_LOADER_PYTHON (plugin_info_get_loader (service->plugin))->py_interpreter_info);
+	saver_data = g_object_get_data (G_OBJECT (service), "loader_data");
+	SWITCH_TO_PLUGIN (plugin_service_get_plugin (service));
 	py_workbook = py_new_Workbook_object (wb_view_workbook (wb_view));
 	save_result = PyObject_CallFunction
 		(saver_data->python_func_file_save,
@@ -454,31 +424,29 @@ gnumeric_plugin_loader_python_load_service_file_saver (GnumericPluginLoader *loa
                                                        PluginService *service,
                                                        ErrorInfo **ret_error)
 {
-	GnumericPluginLoaderPython *loader_python;
-	PluginServiceFileSaver *service_file_saver;
+	GnumericPluginLoaderPython *loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
 	gchar *func_name_file_save;
 	PyObject *python_func_file_save;
 
-	g_return_if_fail (IS_GNUMERIC_PLUGIN_LOADER_PYTHON (loader));
-	g_return_if_fail (service != NULL);
-	g_return_if_fail (ret_error != NULL);
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FILE_SAVER (service));
 
-	*ret_error = NULL;
-	loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
+	GNM_INIT_RET_ERROR_INFO (ret_error);
 	switch_python_interpreter_if_needed (loader_python->py_interpreter_info);
-	service_file_saver = &service->t.file_saver;
-	func_name_file_save = g_strdup_printf ("%s_file_save", service_file_saver->id);
+	func_name_file_save = g_strconcat (
+		plugin_service_get_id (service), "_file_save", NULL);
 	python_func_file_save = PyDict_GetItemString (loader_python->main_module_dict,
 	                                              func_name_file_save);
 	clear_python_error_if_needed ();
 	if (python_func_file_save != NULL) {
+		PluginServiceFileSaverCallbacks *cbs;
 		ServiceLoaderDataFileSaver *saver_data;
 
-		service_file_saver->plugin_func_file_save = gnumeric_plugin_loader_python_func_file_save;
+		cbs = plugin_service_get_cbs (service);
+		cbs->plugin_func_file_save = gnumeric_plugin_loader_python_func_file_save;
 
 		saver_data = g_new (ServiceLoaderDataFileSaver, 1);
 		saver_data->python_func_file_save = python_func_file_save;
-		plugin_service_set_loader_data (service, (gpointer) saver_data);
+		g_object_set_data (G_OBJECT (service), "loader_data", saver_data);
 	} else {
 		*ret_error = error_info_new_printf (
 		             _("Python file \"%s\" has invalid format."),
@@ -519,8 +487,8 @@ call_python_function_args (FunctionEvalInfo *ei, Value **args)
 
 	fndef = ei->func_call->func;
 	service = (PluginService *) function_def_get_user_data (fndef);
-	loader_data = (ServiceLoaderDataFunctionGroup *) plugin_service_get_loader_data (service);
-	switch_python_interpreter_if_needed (GNUMERIC_PLUGIN_LOADER_PYTHON (plugin_info_get_loader (service->plugin))->py_interpreter_info);
+	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
+	SWITCH_TO_PLUGIN (plugin_service_get_plugin (service));
 	fn_info_tuple = PyDict_GetItemString (loader_data->python_fn_info_dict,
 	                                      (gchar *) function_def_get_name (fndef));
 	g_assert (fn_info_tuple != NULL);
@@ -549,8 +517,8 @@ call_python_function_nodes (FunctionEvalInfo *ei, GnmExprList *expr_tree_list)
 
 	fndef = ei->func_call->func;
 	service = (PluginService *) function_def_get_user_data (fndef);
-	loader_data = (ServiceLoaderDataFunctionGroup *) plugin_service_get_loader_data (service);
-	switch_python_interpreter_if_needed (GNUMERIC_PLUGIN_LOADER_PYTHON (plugin_info_get_loader (service->plugin))->py_interpreter_info);
+	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
+	SWITCH_TO_PLUGIN (plugin_service_get_plugin (service));
 	python_fn = PyDict_GetItemString (loader_data->python_fn_info_dict,
 	                                  (gchar *) function_def_get_name (fndef));
 
@@ -612,11 +580,11 @@ gnumeric_plugin_loader_python_func_get_full_function_info (PluginService *servic
 	ServiceLoaderDataFunctionGroup *loader_data;
 	PyObject *fn_info_obj;
 
-	g_return_val_if_fail (service != NULL, FALSE);
+	g_return_val_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service), FALSE);
 	g_return_val_if_fail (fn_name != NULL, FALSE);
 
-	loader_data = (ServiceLoaderDataFunctionGroup *) plugin_service_get_loader_data (service);
-	switch_python_interpreter_if_needed (GNUMERIC_PLUGIN_LOADER_PYTHON (plugin_info_get_loader (service->plugin))->py_interpreter_info);
+	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
+	SWITCH_TO_PLUGIN (plugin_service_get_plugin (service));
 	fn_info_obj = PyDict_GetItemString (loader_data->python_fn_info_dict, (gchar *) fn_name);
 	if (fn_info_obj == NULL) {
 		clear_python_error_if_needed ();
@@ -652,6 +620,8 @@ gnumeric_plugin_loader_python_func_get_full_function_info (PluginService *servic
 		                                               fn_info_obj, fn_name);
 		*fn_args_ptr = NULL;
 		*fn_nodes_ptr = &call_python_function_nodes;
+		*link = NULL;
+		*unlink = NULL;
 		return TRUE;
 	} else {
 		clear_python_error_if_needed ();
@@ -664,33 +634,31 @@ gnumeric_plugin_loader_python_load_service_function_group (GnumericPluginLoader
                                                            PluginService *service,
                                                            ErrorInfo **ret_error)
 {
-	GnumericPluginLoaderPython *loader_python;
-	PluginServiceFunctionGroup *service_function_group;
+	GnumericPluginLoaderPython *loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
 	gchar *fn_info_dict_name;
 	PyObject *python_fn_info_dict;
 
-	g_return_if_fail (IS_GNUMERIC_PLUGIN_LOADER_PYTHON (loader));
-	g_return_if_fail (service != NULL);
-	g_return_if_fail (ret_error != NULL);
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service));
 
-	*ret_error = NULL;
-	loader_python = GNUMERIC_PLUGIN_LOADER_PYTHON (loader);
+	GNM_INIT_RET_ERROR_INFO (ret_error);
 	switch_python_interpreter_if_needed (loader_python->py_interpreter_info);
-	service_function_group = &service->t.function_group;
-	fn_info_dict_name = g_strdup_printf ("%s_functions", service_function_group->group_id);
+	fn_info_dict_name = g_strconcat (
+		plugin_service_get_id (service), "_functions", NULL);
 	python_fn_info_dict = PyDict_GetItemString (loader_python->main_module_dict,
 	                                             fn_info_dict_name);
 	clear_python_error_if_needed ();
 	if (python_fn_info_dict != NULL && PyDict_Check (python_fn_info_dict)) {
+		PluginServiceFunctionGroupCallbacks *cbs;
 		ServiceLoaderDataFunctionGroup *loader_data;
 
-		service_function_group->plugin_func_get_full_function_info =
+		cbs = plugin_service_get_cbs (service);
+		cbs->plugin_func_get_full_function_info =
 			&gnumeric_plugin_loader_python_func_get_full_function_info;
 
 		loader_data = g_new (ServiceLoaderDataFunctionGroup, 1);
 		loader_data->python_fn_info_dict = (PyObject *) python_fn_info_dict;
 		Py_INCREF (loader_data->python_fn_info_dict);
-		plugin_service_set_loader_data (service, (gpointer) loader_data);
+		g_object_set_data (G_OBJECT (service), "loader_data", loader_data);
 	} else {
 		*ret_error = error_info_new_printf (
 		             _("Python file \"%s\" has invalid format."),
@@ -718,12 +686,11 @@ gnumeric_plugin_loader_python_unload_service_function_group (GnumericPluginLoade
 	ServiceLoaderDataFunctionGroup *loader_data;
 
 	g_return_if_fail (IS_GNUMERIC_PLUGIN_LOADER_PYTHON (loader));
-	g_return_if_fail (service != NULL);
-	g_return_if_fail (ret_error != NULL);
+	g_return_if_fail (GNM_IS_PLUGIN_SERVICE_FUNCTION_GROUP (service));
 
-	*ret_error = NULL;
-	loader_data = (ServiceLoaderDataFunctionGroup *) plugin_service_get_loader_data (service);
-	switch_python_interpreter_if_needed (GNUMERIC_PLUGIN_LOADER_PYTHON (plugin_info_get_loader (service->plugin))->py_interpreter_info);
+	GNM_INIT_RET_ERROR_INFO (ret_error);
+	loader_data = g_object_get_data (G_OBJECT (service), "loader_data");
+	SWITCH_TO_PLUGIN (plugin_service_get_plugin (service));
 	Py_DECREF (loader_data->python_fn_info_dict);
 }
 
@@ -732,7 +699,6 @@ gnumeric_plugin_loader_python_unload_service_function_group (GnumericPluginLoade
 GType
 python_get_loader_type (ErrorInfo **ret_error)
 {
-	*ret_error = NULL;
-
+	GNM_INIT_RET_ERROR_INFO (ret_error);
 	return TYPE_GNUMERIC_PLUGIN_LOADER_PYTHON;
 }
