@@ -797,6 +797,16 @@ cleanup:
 	return retval;
 }
 
+static void
+function_ref_notify (FunctionDefinition *fn_def, int refcount)
+{
+	if (refcount == 0) {
+		gnm_plugin_use_unref (PLUGIN);
+	} else {
+		gnm_plugin_use_ref (PLUGIN);
+	}
+}
+
 /**
  * register_function
  * @m        Dummy
@@ -843,11 +853,13 @@ register_function (PyObject *m, PyObject *py_args)
 		fndef = function_add_args (cat, g_strdup (name),
 					   g_strdup (args),
 					   g_strdup (named_args), help,
-					   marshal_func_args);
+					   marshal_func_args,
+					   function_ref_notify);
 	else
 		fndef = function_add_nodes (cat, g_strdup (name), NULL,
 					    g_strdup (named_args), help,
-					    marshal_func_nodes);
+					    marshal_func_nodes,
+					    function_ref_notify);
 
 	fdata = g_new (FuncData, 1);
 	fdata->fndef    = fndef;
@@ -894,20 +906,6 @@ initgnumeric (void)
 		PyDict_SetItemString (d, (char *) "error", GnumericError);
 }
 
-gboolean
-plugin_can_deactivate_general (void)
-{
-	FuncData *fdata;
-	GList *l;
-
-	for (l = funclist; l != NULL; l = l->next) {
-		fdata = (FuncData *) l->data;
-		if (func_get_ref_count (fdata->fndef) != 0)
-			return FALSE;
-	}
-	return TRUE;
-}
-
 void
 plugin_cleanup_general (ErrorInfo **ret_error)
 {
