@@ -23,6 +23,7 @@
 #include <gnumeric.h>
 #include "qpro.h"
 
+#include <gutils.h>
 #include <plugin-util.h>
 #include <file.h>
 #include <workbook-view.h>
@@ -40,6 +41,7 @@
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-infile.h>
 #include <gsf/gsf-infile-msole.h>
+#include <libgnome/gnome-i18n.h>
 
 GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 
@@ -124,10 +126,9 @@ static gboolean
 qpro_validate_len (QProReadState *state, char const *id, guint16 len, int expected_len)
 {
 	if (expected_len >= 0  && len != expected_len) {
-		char *msg = g_strdup_printf ("Invalid '%s' record of length %hd instead of %d",
+		gnm_io_warning (state->io_context,
+			_("Invalid '%s' record of length %hd instead of %d"),
 			id, len, expected_len);
-		gnm_io_warning (state->io_context, msg);
-		g_free (msg);
 		return FALSE;
 	}
 
@@ -163,7 +164,7 @@ qpro_parse_formula (QProReadState *state, int col, int row,
 		switch (*fmla) {
 		case QPRO_OP_CONST_FLOAT:
 			expr = gnm_expr_new_constant (value_new_float (
-				gnumeric_get_le_double (fmla+1)));
+				gsf_le_get_double (fmla+1)));
 			len = 9;
 			break;
 
@@ -298,7 +299,7 @@ qpro_parse_formula (QProReadState *state, int col, int row,
 
 		val = value_new_string (data + 7);
 	} else
-		val = value_new_float (gnumeric_get_le_double (data));
+		val = value_new_float (gsf_le_get_double (data));
 
 	cell_set_expr_and_value (sheet_cell_fetch (state->cur_sheet, col, row),
 		expr, val, TRUE);
@@ -325,6 +326,7 @@ qpro_read_sheet (QProReadState *state)
 
 	state->cur_sheet = sheet;
 	workbook_sheet_attach (state->wb, sheet, NULL);
+	sheet_flag_recompute_spans (sheet);
 	printf ("----------> start %s\n", def_name);
 	while (NULL != (data = qpro_get_record (state, &id, &len))) {
 		switch (id) {
@@ -353,7 +355,7 @@ qpro_read_sheet (QProReadState *state)
 				sheet_style_set_pos (sheet, col, row,
 					qpro_get_style (state, data + 4));
 				cell_assign_value (sheet_cell_fetch (sheet, col, row),
-					value_new_float (gnumeric_get_le_double (data + 6)));
+					value_new_float (gsf_le_get_double (data + 6)));
 			}
 			break;
 
@@ -434,12 +436,10 @@ qpro_read_sheet (QProReadState *state)
 				guint16 high = GSF_LE_GET_GUINT16 (data + 2);
 
 				if (low == 100) {
-					if (high < 10 || high > 400) {
-						char *msg = g_strdup_printf ("Invalid zoom %hd %%",
-							high);
-						gnm_io_warning (state->io_context, msg);
-						g_free (msg);
-					} else
+					if (high < 10 || high > 400)
+						gnm_io_warning (state->io_context, 
+							_("Invalid zoom %hd %%"), high);
+					else
 						sheet_set_zoom_factor (sheet, ((double)high) / 100.,
 							FALSE, FALSE);
 				}
@@ -476,12 +476,10 @@ qpro_read_workbook (QProReadState *state, GsfInput *input)
 			break;
 
 		default :
-			if (id > QPRO_LAST_SANE_ID) {
-				char *msg = g_strdup_printf ("Invalid record %d of length %hd",
+			if (id > QPRO_LAST_SANE_ID)
+				gnm_io_warning (state->io_context,
+					_("Invalid record %d of length %hd"),
 					id, len);
-				gnm_io_warning (state->io_context, msg);
-				g_free (msg);
-			}
 		};
 		if (id == QPRO_END_OF_FILE)
 			break;
