@@ -1,12 +1,19 @@
+#ifndef GNUMERIC_PLUGIN_XBASE_XBASE_H
+#define GNUMERIC_PLUGIN_XBASE_XBASE_H
+
+#include <gnumeric.h>
+#include <gsf/gsf.h>
+
 typedef struct { /* field format */
-	guint8 name[11]; /* name, including terminating '\0' */
+	gchar name[11]; /* name, including terminating '\0' */
 	guint8 type; /* type (single ASCII char) */
 	guint8 len; /* byte length */
 	guint  pos; /* position in record */
+	StyleFormat *fmt;
 } XBfield;
 
 typedef struct { /* database instance */
-	FILE     *f; /* file handle */
+	GsfInput *input;	/* file handle */
 	guint     records; /* number of records */
 	guint     fields; /* number of fields */
 	guint     fieldlen; /* bytes per record */
@@ -23,7 +30,9 @@ typedef struct { /* record in a db */
 XBrecord *record_new  (XBfile *file);
 gboolean  record_seek (XBrecord *record, int whence, glong row);
 void      record_free (XBrecord *record);
-guint8   *record_get_field (const XBrecord *record, guint num);
+gchar	*record_get_field (const XBrecord *record, guint num);
 
-XBfile *xbase_open (const char *filename, ErrorInfo **ret_error);
+XBfile *xbase_open (GsfInput *input, ErrorInfo **ret_error);
 void    xbase_close (XBfile *file);
+
+#endif
