@@ -279,8 +279,7 @@ clipboard_paste_region (WorkbookControl *wbc,
 
 	/* If the source is a single cell */
 	/* Treat a target of a single merge specially, don't split the merge */
-	if (src_cols == 1 && src_rows == 1)
-	{
+	if (src_cols == 1 && src_rows == 1) {
 		Range const *merge = sheet_merge_is_corner (pt->sheet, &r->start);
 		if (merge != NULL && range_equal (r, merge)) {
 			dst_cols = dst_rows = 1;
@@ -379,7 +378,7 @@ clipboard_paste_region (WorkbookControl *wbc,
 			rinfo = &rwinfo.u.relocate;
 			rinfo->origin_sheet = rinfo->target_sheet = pt->sheet;
 
-			if (pt->paste_flags & PASTE_EXPR_RELOCATE) {
+			if (pt->paste_flags & PASTE_EXPR_LOCAL_RELOCATE) {
 				rinfo->origin.start = content->base;
 				rinfo->origin.end.col = content->base.col + content->cols - 1;
 				rinfo->origin.end.row = content->base.row + content->rows - 1;
@@ -435,7 +434,7 @@ clipboard_paste_region (WorkbookControl *wbc,
 				}
 
 				rinfo->pos.sheet = pt->sheet;
-				if (pt->paste_flags & PASTE_EXPR_RELOCATE) {
+				if (pt->paste_flags & PASTE_EXPR_LOCAL_RELOCATE) {
 					rinfo->pos.eval.col = content->base.col + c_copy->col_offset;
 					rinfo->pos.eval.row = content->base.row + c_copy->row_offset;
 				} else {
