@@ -935,7 +935,7 @@ dependent_unlink (Dependent *dep, CellPos const *pos)
 	g_return_if_fail (IS_SHEET (dep->sheet));
 
 	if (pos == NULL)
-		pos = &dummy;
+		pos = (dependent_is_cell (dep)) ? &DEP_TO_CELL(dep)->pos : &dummy;
 
 	unlink_expr_dep (dep, pos, dep->expression);
 	if (dep->sheet->deps != NULL) {
@@ -1608,11 +1608,21 @@ cb_dep_hash_invalidate (gpointer key, gpointer value, gpointer closure)
 #endif
 }
 
-
 static void
-cb_name_invalidate (gpointer nexpr, gpointer value, gpointer rwinfo)
+cb_name_invalidate (GnmNamedExpr *nexpr, gpointer value,
+		    GnmExprRewriteInfo const *rwinfo)
 {
-	expr_name_set_expr (nexpr, NULL, rwinfo);
+	GnmExpr const *new_expr = NULL;
+
+	if (!nexpr->builtin &&
+	    ((rwinfo->type == GNM_EXPR_REWRITE_SHEET &&
+	     rwinfo->u.sheet != nexpr->pos.sheet) ||
+	    (rwinfo->type == GNM_EXPR_REWRITE_WORKBOOK &&
+	     rwinfo->u.workbook == nexpr->pos.wb))) {
+		new_expr = gnm_expr_rewrite (nexpr->t.expr_tree, rwinfo);
+		g_return_if_fail (new_expr != NULL);
+	}
+	expr_name_set_expr (nexpr, new_expr, rwinfo);
 }
 
 /*
@@ -1671,7 +1681,7 @@ do_deps_destroy (Sheet *sheet, GnmExprRewriteInfo const *rwinfo)
 
 	if (deps->names) {
 		g_hash_table_foreach (deps->names,
-			cb_name_invalidate, (gpointer)rwinfo);
+			(GHFunc)cb_name_invalidate, (gpointer)rwinfo);
 		g_hash_table_destroy (deps->names);
 		deps->names = NULL;
 	}
@@ -1709,6 +1719,14 @@ sheet_deps_destroy (Sheet *sheet)
 	rwinfo.type = GNM_EXPR_REWRITE_SHEET;
 	rwinfo.u.sheet = sheet;
 
+	/* The GnmDepContainer contains the names that reference this, not the
+	 * names it contains.  Remove them here. NOTE : they may continue to exist
+	 * inactively for a bit.  Be careful to remove them _before_ destroying
+	 * the deps.  This is a bit wasteful in that we unlink and relink a few
+	 * things that are going to be deleted.  However, it is necessary to
+	 * catch all the different life cycles
+	 */
+	expr_name_list_destroy (&sheet->names);
 	do_deps_destroy (sheet, &rwinfo);
 }
 
@@ -1728,7 +1746,12 @@ workbook_deps_destroy (Workbook *wb)
 		wb->sheet_order_dependents = NULL;
 	}
 
-	WORKBOOK_FOREACH_SHEET (wb, sheet, do_deps_destroy (sheet, &rwinfo););
+	/* See above for explantion */
+	expr_name_list_destroy (&wb->names);
+	WORKBOOK_FOREACH_SHEET (wb, sheet, {
+		expr_name_list_destroy (&sheet->names);
+		do_deps_destroy (sheet, &rwinfo);
+	});
 }
 
 void
