@@ -254,22 +254,31 @@ cb_tool_cancel_clicked (GtkWidget *button, GenericToolState *state)
  *
  **/
 void
-dialog_tool_init_buttons (GenericToolState *state, GtkSignalFunc ok_function)
+dialog_tool_init_buttons (GenericToolState *state,
+			  GtkSignalFunc ok_function,
+			  GtkSignalFunc close_function)
 {
 	state->ok_button = glade_xml_get_widget (state->gui, "okbutton");
 	g_signal_connect (G_OBJECT (state->ok_button),
 		"clicked",
 		G_CALLBACK (ok_function), state);
 
-	state->cancel_button = glade_xml_get_widget (state->gui, "cancelbutton");
-	g_signal_connect (G_OBJECT (state->cancel_button),
-		"clicked",
-		G_CALLBACK (cb_tool_cancel_clicked), state);
+	state->cancel_button = glade_xml_get_widget (state->gui,
+						     "cancelbutton");
+	if (close_function == NULL)
+	        g_signal_connect (G_OBJECT (state->cancel_button),
+				  "clicked",
+				  G_CALLBACK (cb_tool_cancel_clicked), state);
+	else
+	        g_signal_connect (G_OBJECT (state->cancel_button),
+				  "clicked",
+				  G_CALLBACK (close_function), state);
+
 	state->apply_button = glade_xml_get_widget (state->gui, "applybutton");
 	if (state->apply_button != NULL )
 		g_signal_connect (G_OBJECT (state->apply_button),
-			"clicked",
-			G_CALLBACK (ok_function), state);
+				  "clicked",
+				  G_CALLBACK (ok_function), state);
 	state->help_button = glade_xml_get_widget (state->gui, "helpbutton");
 	if (state->help_button != NULL )
 		gnumeric_init_help_button (state->help_button,
@@ -307,19 +316,20 @@ dialog_tool_init (GenericToolState *state,
 		  char const *error_str,
 		  char const *key,
 		  GtkSignalFunc ok_function, 
+		  GtkSignalFunc close_function, 
 		  GtkSignalFunc sensitivity_cb,
 		  GnumericExprEntryFlags flags)
 {
-	GtkTable *table;
+	GtkTable  *table;
 	GtkWidget *widget;
-	gint key_stroke;
+	gint      key_stroke;
 
 	state->wbcg  = wbcg;
 	state->wb    = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
 	state->sheet = sheet;
 	state->sv    = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
 	state->warning_dialog = NULL;
-	state->help_link = help_file;
+	state->help_link      = help_file;
 	state->input_var1_str = (input_var1_str == NULL) ? 
 		_("_Input Range:") : input_var1_str;
 	state->input_var2_str = input_var2_str;
@@ -333,7 +343,7 @@ dialog_tool_init (GenericToolState *state,
 		goto dialog_tool_init_error;
 
 
-	dialog_tool_init_buttons (state, ok_function);
+	dialog_tool_init_buttons (state, ok_function, close_function);
 
 	widget = glade_xml_get_widget (state->gui, "var1-label");
 	if (widget == NULL) {
@@ -341,10 +351,14 @@ dialog_tool_init (GenericToolState *state,
 		state->accel = NULL;
 	} else {
 		state->accel = gtk_accel_group_new ();
-		table = GTK_TABLE (glade_xml_get_widget (state->gui, "input-table"));
-		state->input_entry = gnumeric_expr_entry_new (state->wbcg, TRUE);
-		gnm_expr_entry_set_flags (state->input_entry, flags, GNUM_EE_MASK);
-		gnm_expr_entry_set_scg (state->input_entry, wbcg_cur_scg (state->wbcg));
+		table = GTK_TABLE (glade_xml_get_widget (state->gui,
+							 "input-table"));
+		state->input_entry = gnumeric_expr_entry_new (state->wbcg,
+							      TRUE);
+		gnm_expr_entry_set_flags (state->input_entry, flags,
+					  GNUM_EE_MASK);
+		gnm_expr_entry_set_scg (state->input_entry,
+					wbcg_cur_scg (state->wbcg));
 		gtk_table_attach (table, GTK_WIDGET (state->input_entry),
 				  1, 2, 0, 1,
 				  GTK_EXPAND | GTK_FILL, 0,
@@ -354,12 +368,12 @@ dialog_tool_init (GenericToolState *state,
 					G_CALLBACK (sensitivity_cb), state);
 		gnumeric_editable_enters (GTK_WINDOW (state->dialog),
 					  GTK_WIDGET (state->input_entry));
-		key_stroke = gtk_label_parse_uline (GTK_LABEL (widget), state->input_var1_str);
+		key_stroke = gtk_label_parse_uline (GTK_LABEL (widget),
+						    state->input_var1_str);
 		if (key_stroke != GDK_VoidSymbol)
-			gtk_widget_add_accelerator (GTK_WIDGET (state->input_entry),
-						    "grab_focus",
-						    state->accel, key_stroke,
-						    GDK_MOD1_MASK, 0);
+			gtk_widget_add_accelerator
+			  (GTK_WIDGET (state->input_entry), "grab_focus",
+			   state->accel, key_stroke, GDK_MOD1_MASK, 0);
 		gtk_widget_show (GTK_WIDGET (state->input_entry));
 	}
 
@@ -374,14 +388,16 @@ dialog_tool_init (GenericToolState *state,
 		GList *this_label_widget;
 		GtkTableChild *tchild;
 
-		state->input_entry_2 = gnumeric_expr_entry_new (state->wbcg, TRUE);
+		state->input_entry_2 = gnumeric_expr_entry_new (state->wbcg,
+								TRUE);
 		gnm_expr_entry_set_flags (state->input_entry_2, 
 					  GNUM_EE_SINGLE_RANGE, GNUM_EE_MASK);
-		gnm_expr_entry_set_scg (state->input_entry_2, wbcg_cur_scg (state->wbcg));
+		gnm_expr_entry_set_scg (state->input_entry_2,
+					wbcg_cur_scg (state->wbcg));
 		table = GTK_TABLE (gtk_widget_get_parent (widget));
 		
-		this_label_widget = g_list_find_custom (
-			table->children, widget, (GCompareFunc) dialog_tool_cmp);
+		this_label_widget = g_list_find_custom
+		  (table->children, widget, (GCompareFunc) dialog_tool_cmp);
 		tchild =  (GtkTableChild *)(this_label_widget->data);
 
 		gtk_table_attach (table, GTK_WIDGET (state->input_entry_2),
@@ -391,25 +407,24 @@ dialog_tool_init (GenericToolState *state,
 		gnumeric_editable_enters (GTK_WINDOW (state->dialog),
 					  GTK_WIDGET (state->input_entry_2));
 		g_signal_connect_after (G_OBJECT (state->input_entry_2),
-			"changed",
-			G_CALLBACK (sensitivity_cb), state);
+					"changed",
+					G_CALLBACK (sensitivity_cb), state);
 		if (state->input_var2_str != NULL) {
-			key_stroke = gtk_label_parse_uline (GTK_LABEL (widget), 
-							    state->input_var2_str);
+			key_stroke = gtk_label_parse_uline
+			  (GTK_LABEL (widget), state->input_var2_str);
 			if (key_stroke != GDK_VoidSymbol)
-				gtk_widget_add_accelerator (GTK_WIDGET (state->input_entry_2),
-							    "grab_focus",
-							    state->accel, key_stroke,
-							    GDK_MOD1_MASK, 0);
+				gtk_widget_add_accelerator
+				  (GTK_WIDGET (state->input_entry_2),
+				   "grab_focus", state->accel, key_stroke,
+				   GDK_MOD1_MASK, 0);
 		}
 		gtk_widget_show (GTK_WIDGET (state->input_entry_2));
 	}
 
 	state->warning = glade_xml_get_widget (state->gui, "warnings");
 	wbcg_edit_attach_guru (state->wbcg, state->dialog);
-	g_signal_connect (G_OBJECT (state->dialog),
-		"destroy",
-		G_CALLBACK (tool_destroy), state);
+	g_signal_connect (G_OBJECT (state->dialog), "destroy",
+			  G_CALLBACK (tool_destroy), state);
 
 	dialog_tool_init_outputs (state, sensitivity_cb);
 
@@ -443,7 +458,8 @@ tool_load_selection (GenericToolState *state, gboolean allow_multiple)
 	if (first != NULL) {
 		if (allow_multiple) {
 			char *text = selection_to_string (state->sv, TRUE);
-			gnm_expr_entry_load_from_text  (state->input_entry, text);
+			gnm_expr_entry_load_from_text  (state->input_entry,
+							text);
 			g_free (text);
 		} else
 			gnm_expr_entry_load_from_range (state->input_entry,
@@ -453,7 +469,8 @@ tool_load_selection (GenericToolState *state, gboolean allow_multiple)
 	}
 
 	gtk_widget_show (state->dialog);
-	gnm_expr_entry_grab_focus (GNUMERIC_EXPR_ENTRY (state->input_entry), FALSE);
+	gnm_expr_entry_grab_focus (GNUMERIC_EXPR_ENTRY (state->input_entry),
+				   FALSE);
 }
 
 /**********************************************/
@@ -619,7 +636,7 @@ dialog_correlation_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 			      "correlation.glade", "Correlation", NULL, NULL,
 			      _("Could not create the Correlation Tool dialog."),
 			      CORRELATION_KEY,
-			      G_CALLBACK (corr_tool_ok_clicked_cb),
+			      G_CALLBACK (corr_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (tool_update_sensitivity_cb),
 			      0))
 		return 0;
@@ -735,7 +752,7 @@ dialog_covariance_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 			      "covariance.glade", "Covariance", NULL, NULL,
 			      _("Could not create the Covariance Tool dialog."),
 			      COVARIANCE_KEY,
-			      G_CALLBACK (cov_tool_ok_clicked_cb),
+			      G_CALLBACK (cov_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (tool_update_sensitivity_cb),
 			      0))
 		return 0;
@@ -818,11 +835,13 @@ dialog_ranking_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 
 	state = g_new (GenericToolState, 1);
 
-	if (dialog_tool_init (state, wbcg, sheet,  "rank-and-percentile-tool.html",
+	if (dialog_tool_init (state, wbcg, sheet,  
+			      "rank-and-percentile-tool.html",
 			      "rank.glade", "RankPercentile", NULL, NULL,
-			      _("Could not create the Rank and  Percentile Tools dialog."),
+			      _("Could not create the Rank and Percentile "
+				"Tools dialog."),
 			      RANK_PERCENTILE_KEY,
-			      G_CALLBACK (rank_tool_ok_clicked_cb),
+			      G_CALLBACK (rank_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (tool_update_sensitivity_cb),
 			      0))
 		return 0;
@@ -904,11 +923,14 @@ dialog_fourier_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 
 	state = g_new (GenericToolState, 1);
 
-	if (dialog_tool_init (state, wbcg, sheet,  "fourier-analysis-tool.html",
-			      "fourier-analysis.glade", "FourierAnalysis", NULL, NULL,
-			      _("Could not create the Fourier Analysis Tool dialog."),
+	if (dialog_tool_init (state, wbcg, sheet,
+			      "fourier-analysis-tool.html",
+			      "fourier-analysis.glade", "FourierAnalysis",
+			      NULL, NULL,
+			      _("Could not create the Fourier Analysis Tool "
+				"dialog."),
 			      FOURIER_KEY,
-			      G_CALLBACK (fourier_tool_ok_clicked_cb),
+			      G_CALLBACK (fourier_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (tool_update_sensitivity_cb),
 			      0))
 		return 0;
@@ -1063,18 +1085,24 @@ dialog_descriptive_stat_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 
 	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet, 
 			      "descriptive-statistics-tool.html",
-			      "descriptive-stats.glade", "DescStats", NULL, NULL,
-			      _("Could not create the Descriptive Statistics Tool dialog."),
+			      "descriptive-stats.glade", "DescStats",
+			      NULL, NULL,
+			      _("Could not create the Descriptive Statistics "
+				"Tool dialog."),
 			      DESCRIPTIVE_STATS_KEY,
-			      G_CALLBACK (cb_desc_stat_tool_ok_clicked),
+			      G_CALLBACK (cb_desc_stat_tool_ok_clicked), NULL,
 			      G_CALLBACK (desc_stat_tool_update_sensitivity_cb),
 			      0))
 		return 0;
 
-	state->summary_stats_button  = glade_xml_get_widget (state->base.gui, "summary_stats_button");
-	state->mean_stats_button  = glade_xml_get_widget (state->base.gui, "mean_stats_button");
-	state->kth_largest_button  = glade_xml_get_widget (state->base.gui, "kth_largest_button");
-	state->kth_smallest_button  = glade_xml_get_widget (state->base.gui, "kth_smallest_button");
+	state->summary_stats_button  = glade_xml_get_widget
+	        (state->base.gui, "summary_stats_button");
+	state->mean_stats_button  = glade_xml_get_widget
+	        (state->base.gui, "mean_stats_button");
+	state->kth_largest_button  = glade_xml_get_widget
+	        (state->base.gui, "kth_largest_button");
+	state->kth_smallest_button  = glade_xml_get_widget
+	        (state->base.gui, "kth_smallest_button");
 	state->c_entry  = glade_xml_get_widget (state->base.gui, "c_entry");
 	float_to_entry (GTK_ENTRY (state->c_entry), 0.95);
 	state->l_entry  = glade_xml_get_widget (state->base.gui, "l_entry");
@@ -1429,12 +1457,14 @@ dialog_ttest_tool (WorkbookControlGUI *wbcg, Sheet *sheet, ttest_type test)
 	state = g_new (TTestState, 1);
 	state->invocation = test;
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,  "t-test.html",
-			      "mean-tests.glade", "MeanTests", _("Var_iable 1 Range:"),
+	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+			      "t-test.html",
+			      "mean-tests.glade", "MeanTests",
+			      _("Var_iable 1 Range:"),
 			      _("_Variable 2 Range:"),
 			      _("Could not create the Mean Tests Tool dialog."),
 			      TTEST_KEY,
-			      G_CALLBACK (ttest_tool_ok_clicked_cb),
+			      G_CALLBACK (ttest_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (ttest_update_sensitivity_cb),
 			      GNUM_EE_SINGLE_RANGE))
 		return 0;
@@ -1630,7 +1660,7 @@ dialog_ftest_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 			      _("Var_iable 1 Range"), _("_Variable 2 Range"),
 			      _("Could not create the FTest Tool dialog."),
 			      FTEST_KEY,
-			      G_CALLBACK (ftest_tool_ok_clicked_cb),
+			      G_CALLBACK (ftest_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (ftest_update_sensitivity_cb),
 			      GNUM_EE_SINGLE_RANGE))
 		return 0;
@@ -1824,11 +1854,12 @@ dialog_sampling_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 
 	state = g_new (SamplingState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet, "sampling-tool.html",
+	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+			      "sampling-tool.html",
 			      "sampling.glade", "Sampling", NULL, NULL,
 			      _("Could not create the Sampling Tool dialog."),
 			      SAMPLING_KEY,
-			      G_CALLBACK (sampling_tool_ok_clicked_cb),
+			      G_CALLBACK (sampling_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (sampling_tool_update_sensitivity_cb),
 			      0))
 		return 0;
@@ -2038,7 +2069,7 @@ dialog_regression_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 			      _("_X Variables:"), _("_Y Variable:"),
 			      _("Could not create the Regression Tool dialog."),
 			      REGRESSION_KEY,
-			      G_CALLBACK (regression_tool_ok_clicked_cb),
+			      G_CALLBACK (regression_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (regression_tool_update_sensitivity_cb),
 			      0))
 		return 0;
@@ -2167,13 +2198,15 @@ dialog_exp_smoothing_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 
 	state = g_new (ExpSmoothToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,  "exp-smoothing-tool.html",
+	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+			      "exp-smoothing-tool.html",
 			      "exp-smoothing.glade",
 			      "ExpSmoothing", NULL, NULL,
 			      _("Could not create the Exponential Smoothing "
 				"Tool dialog."),
 			      EXP_SMOOTHING_KEY,
 			      G_CALLBACK (exp_smoothing_tool_ok_clicked_cb),
+			      NULL,
 			      G_CALLBACK (exp_smoothing_tool_update_sensitivity_cb),
 			      0)) 
 		return 0;
@@ -2304,12 +2337,14 @@ dialog_average_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 
 	state = g_new (AverageToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,  "moving-average-tool.html",
+	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet, 
+			      "moving-average-tool.html",
 			      "moving-averages.glade",
 			      "MovAverages", NULL, NULL,
-			      _("Could not create the Moving Average Tool dialog."),
+			      _("Could not create the Moving Average Tool "
+				"dialog."),
 			      AVERAGE_KEY,
-			      G_CALLBACK (average_tool_ok_clicked_cb),
+			      G_CALLBACK (average_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (average_tool_update_sensitivity_cb),
 			      0)) 
 		return 0;
@@ -2524,22 +2559,26 @@ dialog_histogram_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 
 	state = g_new (HistogramToolState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet, "histogram-tool.html",
+	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet, 
+			      "histogram-tool.html",
 			      "histogram.glade", "Histogram", 
 			      _("_Input Range:"), _("Bin _Range:"),
 			      _("Could not create the Histogram Tool dialog."),
 			      HISTOGRAM_KEY,
-			      G_CALLBACK (histogram_tool_ok_clicked_cb),
+			      G_CALLBACK (histogram_tool_ok_clicked_cb), NULL,
 			      G_CALLBACK (histogram_tool_update_sensitivity_cb),
 			      0)) 
 		return 0;
 
-	state->predetermined_button = GTK_WIDGET(glade_xml_get_widget (state->base.gui,
-								       "pre_determined_button"));
-	state->calculated_button = GTK_WIDGET(glade_xml_get_widget (state->base.gui,
-								    "calculated_button"));
-	state->bin_labels_button = GTK_WIDGET(glade_xml_get_widget (state->base.gui,
-								    "labels_2_button"));
+	state->predetermined_button = GTK_WIDGET (glade_xml_get_widget
+						  (state->base.gui,
+						   "pre_determined_button"));
+	state->calculated_button = GTK_WIDGET (glade_xml_get_widget
+					       (state->base.gui,
+						"calculated_button"));
+	state->bin_labels_button = GTK_WIDGET (glade_xml_get_widget
+					       (state->base.gui,
+						"labels_2_button"));
 	state->n_entry = GTK_ENTRY(glade_xml_get_widget (state->base.gui,
 							  "n_entry"));
 	state->max_entry = GTK_ENTRY(glade_xml_get_widget (state->base.gui,
@@ -2633,7 +2672,8 @@ anova_single_tool_ok_clicked_cb (GtkWidget *button, AnovaSingleToolState *state)
  * an alpha is given.
  **/
 static void
-anova_single_tool_update_sensitivity_cb (GtkWidget *dummy, AnovaSingleToolState *state)
+anova_single_tool_update_sensitivity_cb (GtkWidget *dummy,
+					 AnovaSingleToolState *state)
 {
 	gboolean input_1_ready  = FALSE;
 	gboolean output_ready  = FALSE;
@@ -2644,9 +2684,11 @@ anova_single_tool_update_sensitivity_cb (GtkWidget *dummy, AnovaSingleToolState
         GSList *input_range;
 
         output_range = gnm_expr_entry_parse_as_value
-		(GNUMERIC_EXPR_ENTRY (state->base.output_entry), state->base.sheet);
+		(GNUMERIC_EXPR_ENTRY (state->base.output_entry),
+		 state->base.sheet);
         input_range = gnm_expr_entry_parse_as_list (
-		GNUMERIC_EXPR_ENTRY (state->base.input_entry), state->base.sheet);
+		GNUMERIC_EXPR_ENTRY (state->base.input_entry),
+		state->base.sheet);
 
 	i = gnumeric_glade_group_value (state->base.gui, output_group);
 	err = entry_to_float (GTK_ENTRY (state->alpha_entry), &alpha, FALSE);
@@ -2696,14 +2738,17 @@ dialog_anova_single_factor_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,  
 			      "anova.html#ANOVA-SINGLE-FACTOR-TOOL",
 			      "anova-one.glade", "ANOVA", NULL, NULL,
-			      _("Could not create the ANOVA (single factor) tool dialog."),
+			      _("Could not create the ANOVA (single factor) "
+				"tool dialog."),
 			      ANOVA_SINGLE_KEY,
 			      G_CALLBACK (anova_single_tool_ok_clicked_cb),
+			      NULL,
 			      G_CALLBACK (anova_single_tool_update_sensitivity_cb),
 			      0))
 		return 0;
 
-	state->alpha_entry = glade_xml_get_widget (state->base.gui, "alpha-entry");
+	state->alpha_entry = glade_xml_get_widget (state->base.gui,
+						   "alpha-entry");
 	float_to_entry (GTK_ENTRY (state->alpha_entry), 0.05);
 	g_signal_connect_after (G_OBJECT (state->alpha_entry),
 		"changed",
@@ -2736,7 +2781,8 @@ dialog_anova_single_factor_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
  * contain sensible data.
  **/
 static void
-anova_two_factor_tool_ok_clicked_cb (GtkWidget *button, AnovaTwoFactorToolState *state)
+anova_two_factor_tool_ok_clicked_cb (GtkWidget *button,
+				     AnovaTwoFactorToolState *state)
 {
 	data_analysis_output_t  *dao;
 	GtkWidget *w;
@@ -2751,17 +2797,21 @@ anova_two_factor_tool_ok_clicked_cb (GtkWidget *button, AnovaTwoFactorToolState
 	dao  = parse_output ((GenericToolState *)state, NULL);
 
 	data->input = gnm_expr_entry_parse_as_value
-		(GNUMERIC_EXPR_ENTRY (state->base.input_entry), state->base.sheet);
+		(GNUMERIC_EXPR_ENTRY (state->base.input_entry),
+		 state->base.sheet);
 	data->err = analysis_tools_noerr;
 	data->wbcg = state->base.wbcg;
 
 	w = glade_xml_get_widget (state->base.gui, "labels_button");
         data->labels = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w));
 
-	err = entry_to_float (GTK_ENTRY (state->alpha_entry), &data->alpha, TRUE);
-	err = entry_to_int (GTK_ENTRY (state->replication_entry), &data->replication, TRUE);
+	err = entry_to_float (GTK_ENTRY (state->alpha_entry), &data->alpha,
+			      TRUE);
+	err = entry_to_int (GTK_ENTRY (state->replication_entry),
+			    &data->replication, TRUE);
 
-	if (cmd_analysis_tool (WORKBOOK_CONTROL (state->base.wbcg), state->base.sheet, 
+	if (cmd_analysis_tool (WORKBOOK_CONTROL (state->base.wbcg),
+			       state->base.sheet, 
 			       dao, data, analysis_tool_anova_two_factor_engine)) {
 		switch (data->err) {
 		case analysis_tools_missing_data:
@@ -2788,20 +2838,24 @@ anova_two_factor_tool_ok_clicked_cb (GtkWidget *button, AnovaTwoFactorToolState
 					data->labels ? _("The given input range should contain at "
 					  "least two rows of data and the "
 					  "labels.") :
-					_("The given input range should contain at "
-					  "least two rows of data."));
+					_("The given input range should "
+					  "contain at least two rows of "
+					  "data."));
 			break;
 		case analysis_tools_replication_invalid:
 			error_in_entry ((GenericToolState *) state, 
 					GTK_WIDGET (state->base.input_entry),
-					_("The number of data rows must be a multiple "
-					  "of the replication number."));
+					_("The number of data rows must be a "
+					  "multiple of the replication "
+					  "number."));
 			break;
 		default:
 			text = g_strdup_printf (
-				_("An unexpected error has occurred: %d."), data->err);
+				_("An unexpected error has occurred: %d."),
+				data->err);
 			error_in_entry ((GenericToolState *) state, 
-					GTK_WIDGET (state->base.input_entry), text);
+					GTK_WIDGET (state->base.input_entry),
+					text);
 			g_free (text);
 			break;
 		}
@@ -2825,7 +2879,8 @@ anova_two_factor_tool_ok_clicked_cb (GtkWidget *button, AnovaTwoFactorToolState
  * an alpha and a replaication is given.
  **/
 static void
-anova_two_factor_tool_update_sensitivity_cb (GtkWidget *dummy, AnovaTwoFactorToolState *state)
+anova_two_factor_tool_update_sensitivity_cb (GtkWidget *dummy,
+					     AnovaTwoFactorToolState *state)
 {
 	gboolean ready  = FALSE;
 	int i, replication, err_alpha, err_replication;
@@ -2834,16 +2889,22 @@ anova_two_factor_tool_update_sensitivity_cb (GtkWidget *dummy, AnovaTwoFactorToo
         Value *input_range;
 
         output_range = gnm_expr_entry_parse_as_value
-		(GNUMERIC_EXPR_ENTRY (state->base.output_entry), state->base.sheet);
+		(GNUMERIC_EXPR_ENTRY (state->base.output_entry),
+		 state->base.sheet);
         input_range = gnm_expr_entry_parse_as_value
-		(GNUMERIC_EXPR_ENTRY (state->base.input_entry), state->base.sheet);
+		(GNUMERIC_EXPR_ENTRY (state->base.input_entry),
+		 state->base.sheet);
 	i = gnumeric_glade_group_value (state->base.gui, output_group);
-	err_alpha = entry_to_float (GTK_ENTRY (state->alpha_entry), &alpha, FALSE);
-	err_replication = entry_to_int (GTK_ENTRY (state->replication_entry), &replication, FALSE);
+	err_alpha = entry_to_float (GTK_ENTRY (state->alpha_entry), &alpha,
+				    FALSE);
+	err_replication = entry_to_int (GTK_ENTRY (state->replication_entry),
+					&replication, FALSE);
 
-	gtk_widget_set_sensitive (state->base.clear_outputrange_button, (i == 2));
+	gtk_widget_set_sensitive (state->base.clear_outputrange_button,
+				  (i == 2));
 	gtk_widget_set_sensitive (state->base.retain_format_button, (i == 2));
-	gtk_widget_set_sensitive (state->base.retain_comments_button, (i == 2));
+	gtk_widget_set_sensitive (state->base.retain_comments_button,
+				  (i == 2));
 
 	ready = ((input_range != NULL) &&
                  (err_alpha == 0 && alpha > 0 && alpha < 1) &&
@@ -2888,24 +2949,30 @@ dialog_anova_two_factor_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
 			      "anova.html#ANOVA-TWO-FACTOR-TOOL",
 			      "anova-two.glade", "ANOVA", NULL, NULL,
-			      _("Could not create the ANOVA (two factor) tool dialog."),
+			      _("Could not create the ANOVA (two factor) "
+				"tool dialog."),
 			      ANOVA_TWO_FACTOR_KEY,
 			      G_CALLBACK (anova_two_factor_tool_ok_clicked_cb),
+			      NULL,
 			      G_CALLBACK (anova_two_factor_tool_update_sensitivity_cb),
 			      GNUM_EE_SINGLE_RANGE))
 		return 0;
 
-	state->alpha_entry = glade_xml_get_widget (state->base.gui, "alpha-entry");
+	state->alpha_entry = glade_xml_get_widget (state->base.gui,
+						   "alpha-entry");
 	float_to_entry (GTK_ENTRY(state->alpha_entry), 0.05);
-	state->replication_entry = glade_xml_get_widget (state->base.gui, "replication-entry");
+	state->replication_entry = glade_xml_get_widget (state->base.gui,
+							 "replication-entry");
 	int_to_entry (GTK_ENTRY(state->replication_entry), 1);
 
 	g_signal_connect_after (G_OBJECT (state->alpha_entry),
 		"changed",
-		G_CALLBACK (anova_two_factor_tool_update_sensitivity_cb), state);
+		G_CALLBACK (anova_two_factor_tool_update_sensitivity_cb),
+				state);
 	g_signal_connect_after (G_OBJECT (state->replication_entry),
 		"changed",
-		G_CALLBACK (anova_two_factor_tool_update_sensitivity_cb), state);
+		G_CALLBACK (anova_two_factor_tool_update_sensitivity_cb),
+				state);
  	gnumeric_editable_enters (GTK_WINDOW (state->base.dialog),
 				  GTK_WIDGET (state->alpha_entry));
  	gnumeric_editable_enters (GTK_WINDOW (state->base.dialog),
