@@ -44,7 +44,7 @@
 
 #include <libgnome/gnome-i18n.h>
 #include <glade/glade.h>
-#include <gal/util/e-util.h>
+#include <gsf/gsf-impl-utils.h>
 #include <ctype.h>
 #include <stdio.h>
 
@@ -52,12 +52,11 @@
 
 #define CELL_SORT_KEY "cell-sort-dialog"
 
-#define MAX_INITIAL_CLAUSES 32
-
 typedef struct {
-	Sheet     *sheet;
 	WorkbookControlGUI  *wbcg;
 	Workbook  *wb;
+	SheetView *sv;
+	Sheet     *sheet;
 
 	GladeXML  *gui;
 	GtkWidget *dialog;
@@ -187,6 +186,7 @@ load_model_data (SortFlowState *state)
 	int end;
 	int index;
 	int i;
+	int limit = gnm_gconf_get_sort_max_initial_clauses ();
 
 	if (state->is_cols) {
 		start = state->sel->v_range.cell.a.col;
@@ -201,8 +201,8 @@ load_model_data (SortFlowState *state)
 	gtk_list_store_clear (state->model);
 	state->sort_items = 0;
 
-	if (end >= start + MAX_INITIAL_CLAUSES)
-		end = start + MAX_INITIAL_CLAUSES - 1;
+	if (end >= start + limit)
+		end = start + limit - 1;
 
 	for (i = start; i <= end; i++)
 		append_data (state, i, index);
@@ -396,7 +396,7 @@ dialog_load_selection (SortFlowState *state)
 {
 	Range const *first;
 
-	first = selection_first_range (state->sheet, NULL, NULL);
+	first = selection_first_range (state->sv, NULL, NULL);
 
 	if (first != NULL) {
 		gtk_toggle_button_set_active (
@@ -824,20 +824,20 @@ dialog_init (SortFlowState *state)
  * Main entry point for the Cell Sort dialog box
  */
 void
-dialog_cell_sort (WorkbookControlGUI *wbcg, Sheet *sheet)
+dialog_cell_sort (WorkbookControlGUI *wbcg)
 {
 	SortFlowState* state;
 
 	g_return_if_fail (wbcg != NULL);
-	g_return_if_fail (IS_SHEET (sheet));
 
 	if (gnumeric_dialog_raise_if_exists (wbcg, CELL_SORT_KEY))
 		return;
 
 	state = g_new (SortFlowState, 1);
 	state->wbcg  = wbcg;
-	state->wb   = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
-	state->sheet = sheet;
+	state->wb    = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
+	state->sv    = wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
+	state->sheet = sv_sheet (state->sv);
 	state->warning_dialog = NULL;
 	state->sel = NULL;
 	state->sort_items = 0;
