@@ -49,12 +49,12 @@
 #include <string.h>
 #include <commands.h>
 
+
 /**********************************************/
 /*  Generic guru items */
 /**********************************************/
 
 
-
 #define RANDOM_KEY            "analysistools-random-dialog"
 
 typedef struct {
@@ -97,23 +97,75 @@ typedef struct {
 
 /* Distribution strings for Random Number Generator */
 static const DistributionStrs distribution_strs[] = {
-        { DiscreteDistribution,
-	  N_("Discrete"), N_("_Value And Probability Input Range:"), NULL, TRUE },
+        /* The most commonly used are listed first.  I think uniform, gaussian
+	 * and discrete are the most commonly used, or what do you think? */
+
+        { UniformDistribution,
+	  N_("Uniform"), N_("_Lower Bound:"), N_("_Upper Bound:"), FALSE },
+        { UniformIntDistribution,
+	  N_("Uniform Integer"), N_("_Lower Bound:"), N_("_Upper Bound:"),
+	  FALSE },
         { NormalDistribution,
 	  N_("Normal"), N_("_Mean:"), N_("_Standard Deviation:"), FALSE },
-     	{ PoissonDistribution,
-	  N_("Poisson"), N_("_Lambda:"), NULL, FALSE },
-	{ ExponentialDistribution,
-	  N_("Exponential"), N_("_b Value:"), NULL, FALSE },
+        { DiscreteDistribution,
+	  N_("Discrete"), N_("_Value And Probability Input Range:"), NULL,
+	  TRUE },
+
+	/* The others are in alphabetical order. */
+
+        { BernoulliDistribution,
+	  N_("Bernoulli"), N_("_p Value:"), NULL, FALSE },
+        { BetaDistribution,
+	  N_("Beta"), N_("_a Value:"), N_("_b Value:"), FALSE },
 	{ BinomialDistribution,
 	  N_("Binomial"), N_("_p Value:"), N_("N_umber of Trials:"), FALSE },
+	{ CauchyDistribution,
+	  N_("Cauchy"), N_("_a Value:"), NULL, FALSE },
+	{ ChisqDistribution,
+	  N_("Chisq"), N_("_nu Value:"), NULL, FALSE },
+	{ ExponentialDistribution,
+	  N_("Exponential"), N_("_b Value:"), NULL, FALSE },
+	{ ExponentialPowerDistribution,
+	  N_("Exponential Power"), N_("_a Value:"), N_("_b Value:"), FALSE },
+	{ FdistDistribution,
+	  N_("F"), N_("nu_1 Value:"), N_("nu_2 Value:"), FALSE },
+	{ GammaDistribution,
+	  N_("Gamma"), N_("_a Value:"), N_("_b Value:"), FALSE },
+	{ GaussianTailDistribution,
+	  N_("Gaussian Tail"), N_("_a Value:"), N_("_Sigma"), FALSE },
+	{ GeometricDistribution,
+	  N_("Geometric"), N_("_p Value:"), NULL, FALSE },
+	{ Gumbel1Distribution,
+	  N_("Gumbel (Type I)"), N_("_a Value:"), N_("_b Value:"), FALSE },
+	{ Gumbel2Distribution,
+	  N_("Gumbel (Type II)"), N_("_a Value:"), N_("_b Value:"), FALSE },
+	{ LandauDistribution,
+	  N_("Landau"), NULL, NULL, FALSE },
+	{ LaplaceDistribution,
+	  N_("Laplace"), N_("_a Value:"), NULL, FALSE },
+	{ LevyDistribution,
+	  N_("Levy alpha-Stable"), N_("_c Value:"), N_("_alpha:"), FALSE },
+	{ LogarithmicDistribution,
+	  N_("Logarithmic"), N_("_p Value:"), NULL, FALSE },
+	{ LogisticDistribution,
+	  N_("Logistic"), N_("_a Value:"), NULL, FALSE },
+	{ LognormalDistribution,
+	  N_("Lognormal"), N_("_Zeta Value:"), N_("_Sigma"), FALSE },
 	{ NegativeBinomialDistribution,
 	  N_("Negative Binomial"), N_("_p Value:"),
 	  N_("N_umber of Failures"), FALSE },
-        { BernoulliDistribution,
-	  N_("Bernoulli"), N_("_p Value:"), NULL, FALSE },
-        { UniformDistribution,
-	  N_("Uniform"), N_("_Lower Bound:"),  N_("_Upper Bound:"), FALSE },
+     	{ ParetoDistribution,
+	  N_("Pareto"), N_("_a Value:"), N_("_b Value:"), FALSE },
+     	{ PoissonDistribution,
+	  N_("Poisson"), N_("_Lambda:"), NULL, FALSE },
+     	{ RayleighDistribution,
+	  N_("Rayleigh"), N_("_Sigma:"), NULL, FALSE },
+     	{ RayleighTailDistribution,
+	  N_("Rayleigh Tail"), N_("_a Value:"), N_("_Sigma:"), FALSE },
+	{ TdistDistribution,
+	  N_("Student t"), N_("nu Value:"), NULL, FALSE },
+	{ WeibullDistribution,
+	  N_("Weibull"), N_("_a Value:"), N_("_b Value:"), FALSE },
         { 0, NULL, NULL, NULL, FALSE }
 };
 
@@ -168,11 +220,11 @@ combo_get_distribution (GtkWidget *combo)
 static void
 random_tool_update_sensitivity_cb (GtkWidget *dummy, RandomToolState *state)
 {
-	gboolean ready  = FALSE;
-	gint count, vars, i;
-	gnum_float a_float, from_val, to_val, p_val;
-        Value *output_range;
-	Value *disc_prob_range;
+	gboolean   ready  = FALSE;
+	gint       count, vars, i;
+	gnum_float a_float, b_float, from_val, to_val, p_val;
+        Value      *output_range;
+	Value      *disc_prob_range;
 	random_distribution_t the_dist;
 
         output_range = gnm_expr_entry_parse_as_value
@@ -201,6 +253,12 @@ random_tool_update_sensitivity_cb (GtkWidget *dummy, RandomToolState *state)
 			entry_to_float (GTK_ENTRY (state->par1_entry), &p_val, FALSE) == 0 &&
 			p_val <= 1.0 && p_val > 0.0;
 		break;
+	case BetaDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0;
+		break;
 	case PoissonDistribution:
 		ready = ready &&
 			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
@@ -211,6 +269,130 @@ random_tool_update_sensitivity_cb (GtkWidget *dummy, RandomToolState *state)
 			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
 			a_float > 0.0;
 		break;
+	case ExponentialPowerDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
+	case CauchyDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		break;
+	case ChisqDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		break;
+	case LandauDistribution:
+		ready = TRUE;
+		break;
+	case LaplaceDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		break;
+	case GaussianTailDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
+	case RayleighDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		break;
+	case RayleighTailDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
+	case ParetoDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
+	case LevyDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
+	case FdistDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
+	case LognormalDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
+	case TdistDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		break;
+	case WeibullDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
+	case GeometricDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &p_val, FALSE) == 0 &&
+			p_val >= 0.0 && p_val <= 1;
+		break;
+	case LogarithmicDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &p_val, FALSE) == 0 &&
+			p_val >= 0.0 && p_val <= 1;
+		break;
+	case LogisticDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		break;
+	case GammaDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
+	case Gumbel1Distribution:
+	case Gumbel2Distribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &a_float, FALSE) == 0 &&
+			a_float > 0.0;
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &b_float, FALSE) == 0 &&
+			b_float > 0.0;
+		break;
 	case BinomialDistribution:
 		ready = ready &&
 			entry_to_float (GTK_ENTRY (state->par1_entry), &p_val, FALSE) == 0 &&
@@ -231,6 +413,12 @@ random_tool_update_sensitivity_cb (GtkWidget *dummy, RandomToolState *state)
 		ready = ready && disc_prob_range != NULL;
 		if (disc_prob_range != NULL) value_release (disc_prob_range);
 		break;
+	case UniformIntDistribution:
+		ready = ready &&
+			entry_to_float (GTK_ENTRY (state->par1_entry), &from_val, FALSE) == 0 &&
+			entry_to_float (GTK_ENTRY (state->par2_entry), &to_val, FALSE) == 0 &&
+			from_val <= to_val;
+		break;
 	case UniformDistribution:
 	default:
 		ready = ready &&
@@ -262,8 +450,8 @@ static void
 distribution_parbox_config (RandomToolState *state,
 			    random_distribution_t dist)
 {
-	GtkWidget *par1_entry;
-	guint par1_key = 0, par2_key = 0;
+	GtkWidget              *par1_entry;
+	guint                  par1_key = 0, par2_key = 0;
 	const DistributionStrs *ds = distribution_strs_find (dist);
 
 	if (ds->par1_is_range) {
@@ -273,21 +461,28 @@ distribution_parbox_config (RandomToolState *state,
 		par1_entry = state->par1_entry;
 		gtk_widget_hide (state->par1_expr_entry);
 	}
-	gtk_widget_show (par1_entry);
+	if (ds->label1 != NULL) {
+	        gtk_widget_show (par1_entry);
+		if (state->distribution_accel != NULL) {
+		        gtk_window_remove_accel_group
+			        (GTK_WINDOW (state->base.dialog),
+				 state->distribution_accel);
+			state->distribution_accel = NULL;
+		}
+		state->distribution_accel = gtk_accel_group_new ();
 
-	if (state->distribution_accel != NULL) {
-		gtk_window_remove_accel_group (GTK_WINDOW (state->base.dialog),
-					       state->distribution_accel);
-		state->distribution_accel = NULL;
+		par1_key = gtk_label_parse_uline (GTK_LABEL (state->par1_label),
+						  _(ds->label1));
+		if (par1_key != GDK_VoidSymbol)
+		        gtk_widget_add_accelerator (par1_entry, "grab_focus",
+						    state->distribution_accel,
+						    par1_key,
+						    GDK_MOD1_MASK, 0);
+	} else {
+		gtk_label_set_text (GTK_LABEL (state->par1_label), "");
+ 	        gtk_widget_hide (par1_entry);
 	}
-	state->distribution_accel = gtk_accel_group_new ();
 
-	par1_key = gtk_label_parse_uline (GTK_LABEL (state->par1_label),
-					  _(ds->label1));
-	if (par1_key != GDK_VoidSymbol)
-		gtk_widget_add_accelerator (par1_entry, "grab_focus",
-					    state->distribution_accel, par1_key,
-					    GDK_MOD1_MASK, 0);
 	if (ds->label2 != NULL) {
 		par2_key = gtk_label_parse_uline (GTK_LABEL (state->par2_label),
 						  _(ds->label2));
@@ -301,8 +496,10 @@ distribution_parbox_config (RandomToolState *state,
 		gtk_label_set_text (GTK_LABEL (state->par2_label), "");
 	        gtk_widget_hide (state->par2_entry);
 	}
-	gtk_window_add_accel_group (GTK_WINDOW (state->base.dialog),
-				    state->distribution_accel);
+	if (ds->label1 != NULL) {
+	        gtk_window_add_accel_group (GTK_WINDOW (state->base.dialog),
+					    state->distribution_accel);
+	}
 }
 
 /*
@@ -388,6 +585,12 @@ random_tool_ok_clicked_cb (GtkWidget *button, RandomToolState *state)
 		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
 				      &data->param.bernoulli.p, TRUE);
 		break;
+	case BetaDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.beta.a, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.beta.b, TRUE);
+		break;
 	case PoissonDistribution:
 		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
 				      &data->param.poisson.lambda, TRUE);
@@ -396,6 +599,101 @@ random_tool_ok_clicked_cb (GtkWidget *button, RandomToolState *state)
 		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
 				      &data->param.exponential.b, TRUE);
 		break;
+	case ExponentialPowerDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.exppow.a, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.exppow.b, TRUE);
+		break;
+	case CauchyDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.cauchy.a, TRUE);
+		break;
+	case LandauDistribution:
+		break;
+	case LaplaceDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.laplace.a, TRUE);
+		break;
+	case GaussianTailDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.gaussian_tail.a, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.gaussian_tail.sigma, TRUE);
+		break;
+	case ChisqDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.chisq.nu, TRUE);
+		break;
+	case LogarithmicDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.logarithmic.p, TRUE);
+		break;
+	case LogisticDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.logistic.a, TRUE);
+		break;
+	case RayleighDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.rayleigh.sigma, TRUE);
+		break;
+	case RayleighTailDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.rayleigh_tail.a, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.rayleigh_tail.sigma, TRUE);
+		break;
+	case LognormalDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.lognormal.zeta, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.lognormal.sigma, TRUE);
+		break;
+	case LevyDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.levy.c, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.levy.alpha, TRUE);
+		break;
+	case FdistDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.fdist.nu1, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.fdist.nu2, TRUE);
+		break;
+	case ParetoDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.pareto.a, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.pareto.b, TRUE);
+		break;
+	case TdistDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.tdist.nu, TRUE);
+		break;
+	case WeibullDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.weibull.a, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.weibull.b, TRUE);
+		break;
+	case GeometricDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.geometric.p, TRUE);
+		break;
+	case GammaDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.gamma.a, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.gamma.b, TRUE);
+		break;
+	case Gumbel1Distribution:
+	case Gumbel2Distribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
+				      &data->param.gumbel.a, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry), 
+				      &data->param.gumbel.b, TRUE);
+		break;
 	case BinomialDistribution:
 		err = entry_to_float (GTK_ENTRY (state->par1_entry), 
 				      &data->param.binomial.p, TRUE);
@@ -410,7 +708,14 @@ random_tool_ok_clicked_cb (GtkWidget *button, RandomToolState *state)
 		break;
 	case DiscreteDistribution:
 		data->param.discrete.range = gnm_expr_entry_parse_as_value (
-			GNUMERIC_EXPR_ENTRY (state->par1_expr_entry), state->base.sheet);
+			GNUMERIC_EXPR_ENTRY (state->par1_expr_entry),
+			state->base.sheet);
+		break;
+	case UniformIntDistribution:
+		err = entry_to_float (GTK_ENTRY (state->par1_entry),
+				     &data->param.uniform.lower_limit, TRUE);
+		err = entry_to_float (GTK_ENTRY (state->par2_entry),
+				     &data->param.uniform.upper_limit, TRUE);
 		break;
 	case UniformDistribution:
 	default:
@@ -421,8 +726,9 @@ random_tool_ok_clicked_cb (GtkWidget *button, RandomToolState *state)
 		break;
 	}
 
-	if (!cmd_analysis_tool (WORKBOOK_CONTROL (state->base.wbcg), state->base.sheet, 
-			       dao, data, tool_random_engine) && 
+	if (!cmd_analysis_tool (WORKBOOK_CONTROL (state->base.wbcg),
+				state->base.sheet, 
+				dao, data, tool_random_engine) && 
 	    (button == state->base.ok_button)) {
 		if (state->distribution_accel) {
 			gtk_window_remove_accel_group (GTK_WINDOW (state->base.dialog),
@@ -443,7 +749,7 @@ random_tool_ok_clicked_cb (GtkWidget *button, RandomToolState *state)
  * Create the dialog (guru).
  *
  **/
-static gboolean
+static void
 dialog_random_tool_init (RandomToolState *state)
 {
 	int   i, dist_str_no;
@@ -452,27 +758,13 @@ dialog_random_tool_init (RandomToolState *state)
 	GtkTable *table;
 	Range const *first;
 
-	state->base.gui = gnumeric_glade_xml_new (state->base.wbcg, "random-generation.glade");
-        if (state->base.gui == NULL)
-                return TRUE;
-
-	state->base.dialog = glade_xml_get_widget (state->base.gui, "Random");
-        if (state->base.dialog == NULL)
-                return TRUE;
-
-
-	state->base.accel = NULL;
 	state->distribution_accel = NULL;
-	state->distribution = DiscreteDistribution;
+	state->distribution = UniformDistribution;
 
-	dialog_tool_init_buttons ((GenericToolState *)state,
-				  G_CALLBACK (random_tool_ok_clicked_cb) );
-
-	dialog_tool_init_outputs ((GenericToolState *)state,
-				  G_CALLBACK (random_tool_update_sensitivity_cb));
-
-	state->distribution_table = glade_xml_get_widget (state->base.gui, "distribution_table");
-	state->distribution_combo = glade_xml_get_widget (state->base.gui, "distribution_combo");
+	state->distribution_table = glade_xml_get_widget (state->base.gui,
+							  "distribution_table");
+	state->distribution_combo = glade_xml_get_widget (state->base.gui,
+							  "distribution_combo");
 	state->par1_entry = glade_xml_get_widget (state->base.gui, "par1_entry");
 	state->par1_label = glade_xml_get_widget (state->base.gui, "par1_label");
 	state->par2_label = glade_xml_get_widget (state->base.gui, "par2_label");
@@ -495,8 +787,8 @@ dialog_random_tool_init (RandomToolState *state)
 
 	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (state->distribution_combo)->entry),
 			   _(distribution_strs[dist_str_no].name));
-
-	ds = distribution_strs_find (DiscreteDistribution);
+	
+	ds = distribution_strs_find (UniformDistribution);
 	(void) gtk_label_parse_uline (GTK_LABEL (state->par1_label), _(ds->label1));
 
   	g_signal_connect (G_OBJECT (GTK_COMBO (state->distribution_combo)->entry),
@@ -530,9 +822,6 @@ dialog_random_tool_init (RandomToolState *state)
 				  GTK_WIDGET (state->count_entry));
 
 	wbcg_edit_attach_guru (state->base.wbcg, state->base.dialog);
-	g_signal_connect (G_OBJECT (state->base.dialog),
-		"destroy",
-		G_CALLBACK (tool_destroy), state);
 	g_signal_connect (G_OBJECT (state->base.dialog),
 		"realize",
 		G_CALLBACK (dialog_random_realized), state);
@@ -552,10 +841,7 @@ dialog_random_tool_init (RandomToolState *state)
 		"changed",
 		G_CALLBACK (random_tool_update_sensitivity_cb), state);
 
-	gnumeric_keyed_dialog (state->base.wbcg, GTK_WINDOW (state->base.dialog),
-			       RANDOM_KEY);
-
-	first = selection_first_range (state->base.sheet, NULL, NULL);
+	first = selection_first_range (state->base.sv, NULL, NULL);
 	if (first != NULL) {
 		gnm_expr_entry_load_from_range (state->base.output_entry,
 						state->base.sheet, first);
@@ -567,7 +853,7 @@ dialog_random_tool_init (RandomToolState *state)
 
 	random_tool_update_sensitivity_cb (NULL, state);
 
-	return FALSE;
+	return;
 }
 
 
@@ -595,21 +881,19 @@ dialog_random_tool (WorkbookControlGUI *wbcg, Sheet *sheet)
 	}
 
 	state = g_new (RandomToolState, 1);
-	state->base.wbcg  = wbcg;
-	state->base.wb   = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
-	state->base.sheet = sheet;
-	state->base.warning_dialog = NULL;
-	state->base.help_link = "random-number-generation-tool.html";
-	state->base.input_var1_str = NULL;
-	state->base.input_var2_str = NULL;
 
-	if (dialog_random_tool_init (state)) {
-		gnumeric_notice (wbcg, GTK_MESSAGE_ERROR,
-				 _("Could not create the Random Tool dialog."));
-		g_free (state);
+	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
+			      "random-number-generation-tool.html",
+			      "random-generation.glade", "Random",
+			      NULL, NULL,
+			      _("Could not create the Random Tool dialog."),
+			      RANDOM_KEY,
+			      G_CALLBACK (random_tool_ok_clicked_cb), NULL,
+			      G_CALLBACK (random_tool_update_sensitivity_cb),
+			      0))
 		return 0;
-	}
 
+	dialog_random_tool_init (state);
 	gtk_widget_show (state->base.dialog);
 
         return 0;
