@@ -1,9 +1,11 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * expr-name.c:  Workbook name table support, will deal
- *               with all the exotic special names.
+ * expr-name.c: Supported named expressions
  *
  * Author:
+ *    Jody Goldberg <jody@gnome.org>
+ *
+ * Based on work by:
  *    Michael Meeks <michael@ximian.com>
  */
 
@@ -66,8 +68,7 @@ expr_name_unlink_deps (GnmNamedExpr *nexpr)
  * in the same sheet or workbook.
  */
 static void
-expr_name_link_deps (GSList *deps,
-		     GnmExprRewriteInfo const *rwinfo)
+expr_name_link_deps (GSList *deps, GnmExprRewriteInfo const *rwinfo)
 {
 	GSList *ptr = deps;
 
@@ -144,9 +145,16 @@ expr_name_lookup_list (GList *p, char const *name)
 	return NULL;
 }
 
+/**
+ * expr_name_lookup:
+ * @pp :
+ * @name :
+ *
+ * lookup but do not reference a named expression.
+ */
 /* FIXME : Why not use hash tables ? */
 GnmNamedExpr *
-expr_name_lookup (ParsePos const *pos, char const *name)
+expr_name_lookup (ParsePos const *pp, char const *name)
 {
 	GnmNamedExpr *res = NULL;
 	Sheet const *sheet = NULL;
@@ -154,9 +162,9 @@ expr_name_lookup (ParsePos const *pos, char const *name)
 
 	g_return_val_if_fail (name != NULL, NULL);
 
-	if (pos != NULL) {
-		sheet = pos->sheet;
-		wb = (sheet != NULL) ? sheet->workbook : pos->wb;
+	if (pp != NULL) {
+		sheet = pp->sheet;
+		wb = (sheet != NULL) ? sheet->workbook : pp->wb;
 	}
 
 	if (sheet != NULL)
@@ -184,7 +192,7 @@ expr_name_new (char const *name, gboolean builtin)
 
 	nexpr->ref_count = 1;
 	nexpr->builtin = builtin;
-	nexpr->active  = TRUE;
+	nexpr->active  = FALSE;
 	nexpr->name    = string_get (name);
 	nexpr->t.expr_tree = NULL;
 	nexpr->dependents  = NULL;
@@ -295,6 +303,7 @@ expr_name_add (ParsePos const *pp, char const *name,
 	expr_name_set_expr (nexpr, expr, NULL);
 
 	*scope = g_list_append (*scope, nexpr);
+	nexpr->active = TRUE;
 
 	return nexpr;
 }
@@ -321,7 +330,7 @@ expr_name_create (ParsePos const *pp, char const *name,
 	GnmExpr const *expr = gnm_expr_parse_str (value, pp,
 		GNM_EXPR_PARSE_DEFAULT, error);
 
-	if (!expr)
+	if (expr == NULL)
 		return NULL;
 
 	/* We know there has been no parse error, but set the
@@ -329,7 +338,6 @@ expr_name_create (ParsePos const *pp, char const *name,
 	 * creation error back to the calling routine
 	 */
 	res = expr_name_add (pp, name, expr, &err);
-	gnm_expr_unref (expr);
 	if (err != NULL)
 		error->message = g_strdup (err);
 	return res;
@@ -351,6 +359,8 @@ expr_name_unref (GnmNamedExpr *nexpr)
 	if (nexpr->ref_count-- > 1)
 		return;
 
+	g_return_if_fail (!nexpr->active);
+
 	if (nexpr->name) {
 		string_unref (nexpr->name);
 		nexpr->name = NULL;
@@ -371,14 +381,17 @@ expr_name_unref (GnmNamedExpr *nexpr)
 }
 
 /**
- * expr_name_unlink :
+ * expr_name_remove :
+ * @nexpr :
  *
- * Linked names can be looked up and used.  It is possible to have a non-zero
- * ref count and be unlinked.
- */
-static void
-expr_name_unlink (GnmNamedExpr *nexpr)
+ * Remove a @nexpr from its container and deactivate it.
+ * NOTE : @nexpr may continue to exist if things still have refrences to it,
+ * but they will evaluate to #REF!
+ **/
+void
+expr_name_remove (GnmNamedExpr *nexpr)
 {
+	g_return_if_fail (nexpr != NULL);
 	g_return_if_fail (nexpr->active);
 
 	if (nexpr->pos.sheet) {
@@ -393,25 +406,14 @@ expr_name_unlink (GnmNamedExpr *nexpr)
 		g_return_if_fail (g_list_find (global_names, nexpr) != NULL);
 		global_names = g_list_remove (global_names, nexpr);
 	}
-	expr_name_unref (nexpr);
 	nexpr->active = FALSE;
-}
-
-void
-expr_name_remove (GnmNamedExpr *nexpr)
-{
-	g_return_if_fail (nexpr != NULL);
-	g_return_if_fail (nexpr->active);
-
-	/* ref so that we can safely clear the expression later */
-	expr_name_ref (nexpr);
-	expr_name_unlink (nexpr);
 	expr_name_set_expr (nexpr, NULL, NULL);
 	expr_name_unref (nexpr);
 }
 
 /**
  * expr_name_list_destroy :
+ * @names : a POINTER to the list of names
  *
  * Frees names in the local scope.
  * NOTE : THIS DOES NOT INVALIDATE NAMES THAT REFER
@@ -419,19 +421,26 @@ expr_name_remove (GnmNamedExpr *nexpr)
  *        eg
  *           in scope sheet2 we have a name that refers
  *           to sheet1.  That will remain!
- */
+ **/
 void
-expr_name_list_destroy (GList *names)
+expr_name_list_destroy (GList **names)
 {
-	GList *p;
+	GList *ptr, *list = *names;
 
-	/* Empty the name list */
-	for (p = names ; p != NULL ; p = g_list_next (p)) {
-		GnmNamedExpr *nexpr = p->data;
-		nexpr->active = FALSE;
-		expr_name_unref (nexpr);
+	*names = NULL;
+	for (ptr = list ; ptr != NULL ; ) {
+		GnmNamedExpr *nexpr = ptr->data;
+		ptr = ptr->next;
+		if (nexpr->active) {
+			nexpr->active = FALSE;
+			if (!nexpr->builtin)
+				expr_name_set_expr (nexpr, NULL, NULL);
+			expr_name_unref (nexpr);
+		} else {
+			g_warning ("problem with named expressions");
+		}
 	}
-	g_list_free (names);
+	g_list_free (list);
 }
 
 /**
@@ -487,22 +496,39 @@ expr_name_set_scope (GnmNamedExpr *nexpr, Sheet *sheet)
 {
 	Workbook *wb;
 
-	g_return_val_if_fail (IS_SHEET (nexpr->pos.sheet), FALSE);
+	g_return_val_if_fail (nexpr != NULL, FALSE);
 
-	sheet = nexpr->pos.sheet;
-	wb = sheet->workbook;
+	if (sheet == NULL) {
+		g_return_val_if_fail (nexpr->pos.sheet != NULL, FALSE);
 
-	nexpr->pos.sheet = NULL;
-	nexpr->pos.wb = wb;
+		wb = nexpr->pos.sheet->workbook;
+		nexpr->pos.wb = wb;
+		nexpr->pos.sheet = NULL;
+		wb->names    = g_list_prepend (wb->names, nexpr);
+		sheet->names = g_list_remove (sheet->names, nexpr);
+	} else {
+		g_return_val_if_fail (nexpr->pos.sheet == NULL, FALSE);
+		g_return_val_if_fail (IS_SHEET (sheet), FALSE);
 
-	wb->names    = g_list_prepend (wb->names, nexpr);
-	sheet->names = g_list_remove (sheet->names, nexpr);
-
-	sheet_set_dirty (sheet, TRUE);
+		wb = sheet->workbook;
+		nexpr->pos.wb = NULL;
+		nexpr->pos.sheet = sheet;
+		wb->names    = g_list_remove (wb->names, nexpr);
+		sheet->names = g_list_prepend (sheet->names, nexpr);
+	}
+	workbook_set_dirty (wb, TRUE);
 
 	return TRUE;
 }
 
+/**
+ * expr_name_set_expr :
+ * @nexpr : the named expression
+ * @new_expr : the new content
+ * @rwinfo : optional.
+ *
+ * Unrefs the current content of @nexpr and absorbs a ref to @new_expr.
+ **/
 void
 expr_name_set_expr (GnmNamedExpr *nexpr, GnmExpr const *new_expr,
 		    GnmExprRewriteInfo const *rwinfo)
@@ -512,8 +538,8 @@ expr_name_set_expr (GnmNamedExpr *nexpr, GnmExpr const *new_expr,
 	g_return_if_fail (nexpr != NULL);
 	g_return_if_fail (!nexpr->builtin);
 
-	if (new_expr != NULL)
-		gnm_expr_ref (new_expr);
+	if (new_expr == nexpr->t.expr_tree)
+		return;
 	if (nexpr->t.expr_tree != NULL) {
 		deps = expr_name_unlink_deps (nexpr);
 		expr_name_handle_references (nexpr, FALSE);
@@ -599,6 +625,7 @@ expr_name_init (void)
 		GnmNamedExpr *nexpr;
 		nexpr = expr_name_new (builtins[lp].name, TRUE);
 		nexpr->t.expr_func = builtins[lp].fn;
+		nexpr->active = TRUE;
 		global_names = g_list_append (global_names, nexpr);
 	}
 }
@@ -606,15 +633,7 @@ expr_name_init (void)
 void
 expr_name_shutdown (void)
 {
-	int lp = 0;
-	for (; builtins[lp].name ; lp++) {
-		GnmNamedExpr *nexpr =
-			expr_name_lookup (NULL, builtins[lp].name);
-		if (nexpr) {
-			expr_name_unref (nexpr);
-			global_names = g_list_remove (global_names, nexpr);
-		}
-	}
+	expr_name_list_destroy (&global_names);
 }
 
 /******************************************************************************/
