@@ -47,7 +47,6 @@ cell_format_currency [] = {
 	NULL, /* "$#,##0.00_);($#,##0.00)", */
 	NULL, /* "$#,##0.00_);[Red]($#,##0.00)", */
 	NULL,
-
 };
 
 /* Some are generated */
@@ -254,171 +253,181 @@ CurrencySymbol const currency_symbols[] =
 	 * for each currency.  They MUST start with '[$'
 	 * The second column has the long names of the currencies.
 	 */
-	{N_("[$ADP]"), N_("Andorran peseta") },
-	{N_("[$AED]"), N_("UAE dirham") },
-	{N_("[$AFA]"), N_("Afghanistan afghani") },
-	{N_("[$ALL]"), N_("Albanian lek") },
-	{N_("[$ANG]"), N_("Netherlands Antillian guilder") },
-	{N_("[$AON]"), N_("Angolan new kwanza") },
-	{N_("[$ARA]"), N_("Argentine peso") },
-	{N_("[$ATS]"), N_("Austrian schilling") },
-	{N_("[$AUD]"), N_("Australian dollar") },
-	{N_("[$AWG]"), N_("Aruban guilder") },
-	{N_("[$BBD]"), N_("Barbados dollar") },
-	{N_("[$BDT]"), N_("Bangladeshi taka") },
-	{N_("[$BEF]"), N_("Belgian franc") },
-	{N_("[$BGL]"), N_("Bulgarian lev") },
-	{N_("[$BHD]"), N_("Bahraini dinar") },
-	{N_("[$BIF]"), N_("Burundi franc") },
-	{N_("[$BMD]"), N_("Bermudian dollar") },
-	{N_("[$BND]"), N_("Brunei dollar") },
-	{N_("[$BOB]"), N_("Bolivian boliviano") },
-	{N_("[$BRE]"), N_("Brazilian real") },
-	{N_("[$BSD]"), N_("Bahamian dollar") },
-	{N_("[$BTN]"), N_("Bhutan ngultrum") },
-	{N_("[$BWP]"), N_("Botswanian pula") },
-	{N_("[$BYB]"), N_("Belarussian ruble") },
-	{N_("[$BZD]"), N_("Belize dollar") },
-	{N_("[$CAD]"), N_("Canadian dollar") },
-	{N_("[$CHF]"), N_("Swiss franc") },
-	{N_("[$CLP]"), N_("Chilean peso") },
-	{N_("[$CNY]"), N_("Chinese yuan renminbi") },
-	{N_("[$COP]"), N_("Colombian peso") },
-	{N_("[$CRC]"), N_("Costa Rican colon") },
-	{N_("[$CSK]"), N_("Czech Koruna") },
-	{N_("[$CUP]"), N_("Cuban peso") },
-	{N_("[$CVE]"), N_("Cape Verde escudo") },
-	{N_("[$CYP]"), N_("Cyprus pound") },
-	{N_("[$DEM]"), N_("Deutsche mark") },
-	{N_("[$DJF]"), N_("Djibouti franc") },
-	{N_("[$DKK]"), N_("Danish krone") },
-	{N_("[$DOP]"), N_("Dominican peso") },
-	{N_("[$DZD]"), N_("Algerian dinar") },
-	{N_("[$ECS]"), N_("Ecuador sucre") },
-	{N_("[$EGP]"), N_("Egyptian pound") },
-	{N_("[$ESP]"), N_("Spanish peseta") },
-	{N_("[$ETB]"), N_("Ethiopian birr") },
-	{N_("[$EUR]"), N_("Euro") },
-	{N_("[$FIM]"), N_("Finnish markka") },
-	{N_("[$FJD]"), N_("Fiji dollar") },
-	{N_("[$FKP]"), N_("Falkland Islands pound") },
-	{N_("[$FRF]"), N_("French franc") },
-	{N_("[$GBP]"), N_("UK pound sterling") },
-	{N_("[$GHC]"), N_("Ghanaian cedi") },
-	{N_("[$GIP]"), N_("Gibraltar pound") },
-	{N_("[$GMD]"), N_("Gambian dalasi") },
-	{N_("[$GNF]"), N_("Guinea franc") },
-	{N_("[$GRD]"), N_("Greek drachma") },
-	{N_("[$GTQ]"), N_("Guatemalan quetzal") },
-	{N_("[$GWP]"), N_("Guinea-Bissau peso") },
-	{N_("[$GYD]"), N_("Guyanan dollar") },
-	{N_("[$HKD]"), N_("Hong Kong dollar") },
-	{N_("[$HNL]"), N_("Honduran lempira") },
-	{N_("[$HRK]"), N_("Croatian kuna") },
-	{N_("[$HTG]"), N_("Haitian gourde") },
-	{N_("[$HUF]"), N_("Hungarian forint") },
-	{N_("[$IDR]"), N_("Indonesian rupiah") },
-	{N_("[$IEP]"), N_("Irish punt") },
-	{N_("[$IEX]"), N_("Irish pence ***") },
-	{N_("[$ILS]"), N_("Israeli shekel") },
-	{N_("[$INR]"), N_("Indian rupee") },
-	{N_("[$IQD]"), N_("Iraqi dinar") },
-	{N_("[$IRR]"), N_("Iranian rial") },
-	{N_("[$ISK]"), N_("Iceland krona") },
-	{N_("[$ITL]"), N_("Italian lira") },
-	{N_("[$JMD]"), N_("Jamaican dollar") },
-	{N_("[$JOD]"), N_("Jordanian dinar") },
-	{N_("[$JPY]"), N_("Japanese yen") },
-	{N_("[$KES]"), N_("Kenyan shilling") },
-	{N_("[$KHR]"), N_("Kampuchean riel") },
-	{N_("[$KMF]"), N_("Comoros franc") },
-	{N_("[$KPW]"), N_("North Korean won") },
-	{N_("[$KRW]"), N_("Republic of Korea won") },
-	{N_("[$KWD]"), N_("Kuwaiti dinar") },
-	{N_("[$KYD]"), N_("Cayman Islands dollar") },
-	{N_("[$LAK]"), N_("Lao kip") },
-	{N_("[$LBP]"), N_("Lebanese pound") },
-	{N_("[$LKR]"), N_("Sri Lanka rupee") },
-	{N_("[$LRD]"), N_("Liberian dollar") },
-	{N_("[$LSL]"), N_("Lesotho loti") },
-	{N_("[$LUF]"), N_("Luxembourg franc") },
-	{N_("[$LYD]"), N_("Libyan dinar") },
-	{N_("[$MAD]"), N_("Moroccan dirham") },
-	{N_("[$MDL]"), N_("Moldovan leu") },
-	{N_("[$MGF]"), N_("Malagasy franc") },
-	{N_("[$MLF]"), N_("Mali franc") },
-	{N_("[$MMK]"), N_("Myanmar kyat") },
-	{N_("[$MNT]"), N_("Mongolian tugrik") },
-	{N_("[$MOP]"), N_("Macau pataca") },
-	{N_("[$MRO]"), N_("Mauritanian ouguiya") },
-	{N_("[$MTL]"), N_("Maltese lira") },
-	{N_("[$MUR]"), N_("Mauritius rupee") },
-	{N_("[$MVR]"), N_("Maldive rupee") },
-	{N_("[$MWK]"), N_("Malawi kwacha") },
-	{N_("[$MXP]"), N_("Mexican peso") },
-	{N_("[$MYR]"), N_("Malaysian ringgit") },
-	{N_("[$MZM]"), N_("Mozambique metical") },
-	{N_("[$NGN]"), N_("Nigerian naira") },
-	{N_("[$NIO]"), N_("Nicaraguan cordoba oro") },
-	{N_("[$NLG]"), N_("Netherlands guilder") },
-	{N_("[$NOK]"), N_("Norwegian krone") },
-	{N_("[$NPR]"), N_("Nepalese rupee") },
-	{N_("[$NZD]"), N_("New Zealand dollar") },
-	{N_("[$OMR]"), N_("Rial Omani") },
-	{N_("[$PAB]"), N_("Panamanian balboa") },
-	{N_("[$PEI]"), N_("Peruvian inti") },
-	{N_("[$PGK]"), N_("Papua New Guinea kina") },
-	{N_("[$PHP]"), N_("Philippino peso") },
-	{N_("[$PKR]"), N_("Pakistan rupee") },
-	{N_("[$PLZ]"), N_("Polish zloty") },
-	{N_("[$PTE]"), N_("Portuguese escudo") },
-	{N_("[$PYG]"), N_("Paraguay guarani") },
-	{N_("[$QAR]"), N_("Qatari rial") },
-	{N_("[$ROL]"), N_("Romanian leu") },
-	{N_("[$RUR]"), N_("Russian ruble") },
-	{N_("[$RWF]"), N_("Rwanda franc") },
-	{N_("[$SAR]"), N_("Saudi Arabian riyal") },
-	{N_("[$SBD]"), N_("Solomon Islands dollar") },
-	{N_("[$SCR]"), N_("Seychelles rupee") },
-	{N_("[$SDP]"), N_("Sudanese pound") },
-	{N_("[$SEK]"), N_("Swedish krona") },
-	{N_("[$SGD]"), N_("Singapore dollar") },
-	{N_("[$SHP]"), N_("St.Helena pound") },
-	{N_("[$SIT]"), N_("Slovenia tolar") },
-	{N_("[$SLL]"), N_("Sierra Leone leone") },
-	{N_("[$SOS]"), N_("Somali shilling") },
-	{N_("[$SRG]"), N_("Suriname guilder") },
-	{N_("[$STD]"), N_("Sao Tome and Principe dobra") },
-	{N_("[$SUR]"), N_("USSR rouble") },
-	{N_("[$SVC]"), N_("El Salvador colon") },
-	{N_("[$SYP]"), N_("Syrian pound") },
-	{N_("[$SZL]"), N_("Swaziland lilangeni") },
-	{N_("[$THB]"), N_("Thai baht") },
-	{N_("[$TND]"), N_("Tunisian dinar") },
-	{N_("[$TOP]"), N_("Tongan pa'anga") },
-	{N_("[$TPE]"), N_("East Timor escudo") },
-	{N_("[$TRL]"), N_("Turkish lira") },
-	{N_("[$TTD]"), N_("Trinidad and Tobago dollar") },
-	{N_("[$TWD]"), N_("New Taiwan dollar") },
-	{N_("[$TZS]"), N_("Tanzanian shilling") },
-        {N_("[$UAH]"), N_("Ukrainian hryvnia") },
-	{N_("[$UGX]"), N_("Ugandan shilling") },
-	{N_("[$USD]"), N_("US dollar") },
-	{N_("[$UYP]"), N_("Uruguayan peso") },
-	{N_("[$VEB]"), N_("Venezuelan bolivar") },
-	{N_("[$VND]"), N_("Vietnamese dong") },
-	{N_("[$VUV]"), N_("Vanuatu vatu") },
-	{N_("[$WST]"), N_("Samoan tala") },
-	{N_("[$XCD]"), N_("East Caribbean dollar") },
-	{N_("[$XEU]"), N_("European currency unit") },
-	{N_("[$YDD]"), N_("Democratic Yemeni dinar") },
-	{N_("[$YER]"), N_("Yemeni rial") },
-	{N_("[$YUN]"), N_("New Yugoslavia dinar") },
-	{N_("[$ZAL]"), N_("South African rand funds code") },
-	{N_("[$ZAR]"), N_("South African rand") },
-	{N_("[$ZMK]"), N_("Zambian kwacha") },
-	{N_("[$ZRZ]"), N_("Zaire Zaire") },
-	{N_("[$ZWD]"), N_("Zimbabwe dollar") },
+
+	/* 2002/08/04 Updated to match iso 4217 */
+	{ "[$AED]",	N_("United Arab Emirates, Dirhams") },
+	{ "[$AFA]",	N_("Afghanistan, Afghanis") },
+	{ "[$ALL]",	N_("Albania, Leke") },
+	{ "[$AMD]",	N_("Armenia, Drams") },
+	{ "[$ANG]",	N_("Netherlands Antilles, Guilders") },
+	{ "[$AOA]",	N_("Angola, Kwanza") },
+	{ "[$ARS]",	N_("Argentina, Pesos") },
+	{ "[$AUD]",	N_("Australia, Dollars") },
+	{ "[$AWG]",	N_("Aruba, Guilders") },
+	{ "[$AZM]",	N_("Azerbaijan, Manats") },
+	{ "[$BAM]",	N_("Bosnia and Herzegovina, Convertible Marka") },
+	{ "[$BBD]",	N_("Barbados, Dollars") },
+	{ "[$BDT]",	N_("Bangladesh, Taka") },
+	{ "[$BGL]",	N_("Bulgaria, Leva") },
+	{ "[$BHD]",	N_("Bahrain, Dinars") },
+	{ "[$BIF]",	N_("Burundi, Francs") },
+	{ "[$BMD]",	N_("Bermuda, Dollars") },
+	{ "[$BND]",	N_("Brunei Darussalam, Dollars") },
+	{ "[$BOB]",	N_("Bolivia, Bolivianos") },
+	{ "[$BRL]",	N_("Brazil, Brazil Real") },
+	{ "[$BSD]",	N_("Bahamas, Dollars") },
+	{ "[$BTN]",	N_("Bhutan, Ngultrum") },
+	{ "[$BWP]",	N_("Botswana, Pulas") },
+	{ "[$BYR]",	N_("Belarus, Rubles") },
+	{ "[$BZD]",	N_("Belize, Dollars") },
+	{ "[$CAD]",	N_("Canada, Dollars") },
+	{ "[$CDF]",	N_("Congo/Kinshasa, Congolese Francs") },
+	{ "[$CHF]",	N_("Switzerland, Francs") },
+	{ "[$CLP]",	N_("Chile, Pesos") },
+	{ "[$CNY]",	N_("China, Yuan Renminbi") },
+	{ "[$COP]",	N_("Colombia, Pesos") },
+	{ "[$CRC]",	N_("Costa Rica, Colones") },
+	{ "[$CUP]",	N_("Cuba, Pesos") },
+	{ "[$CVE]",	N_("Cape Verde, Escudos") },
+	{ "[$CYP]",	N_("Cyprus, Pounds") },
+	{ "[$CZK]",	N_("Czech Republic, Koruny") },
+	{ "[$DJF]",	N_("Djibouti, Francs") },
+	{ "[$DKK]",	N_("Denmark, Kroner") },
+	{ "[$DOP]",	N_("Dominican Republic, Pesos") },
+	{ "[$DZD]",	N_("Algeria, Algeria Dinars") },
+	{ "[$EEK]",	N_("Estonia, Krooni") },
+	{ "[$EGP]",	N_("Egypt, Pounds") },
+	{ "[$ERN]",	N_("Eritrea, Nakfa") },
+	{ "[$ETB]",	N_("Ethiopia, Birr") },
+	{ "[$EUR]",	N_("Euro Member Countries, Euro") },
+	{ "[$FJD]",	N_("Fiji, Dollars") },
+	{ "[$FKP]",	N_("Falkland Islands (Malvinas), Pounds") },
+	{ "[$GBP]",	N_("United Kingdom, Pounds") },
+	{ "[$GEL]",	N_("Georgia, Lari") },
+	{ "[$GGP]",	N_("Guernsey, Pounds") },
+	{ "[$GHC]",	N_("Ghana, Cedis") },
+	{ "[$GIP]",	N_("Gibraltar, Pounds") },
+	{ "[$GMD]",	N_("Gambia, Dalasi") },
+	{ "[$GNF]",	N_("Guinea, Francs") },
+	{ "[$GTQ]",	N_("Guatemala, Quetzales") },
+	{ "[$GYD]",	N_("Guyana, Dollars") },
+	{ "[$HKD]",	N_("Hong Kong, Dollars") },
+	{ "[$HNL]",	N_("Honduras, Lempiras") },
+	{ "[$HRK]",	N_("Croatia, Kuna") },
+	{ "[$HTG]",	N_("Haiti, Gourdes") },
+	{ "[$HUF]",	N_("Hungary, Forint") },
+	{ "[$IDR]",	N_("Indonesia, Rupiahs") },
+	{ "[$ILS]",	N_("Israel, New Shekels") },
+	{ "[$IMP]",	N_("Isle of Man, Pounds") },
+	{ "[$INR]",	N_("India, Rupees") },
+	{ "[$IQD]",	N_("Iraq, Dinars") },
+	{ "[$IRR]",	N_("Iran, Rials") },
+	{ "[$ISK]",	N_("Iceland, Kronur") },
+	{ "[$JEP]",	N_("Jersey, Pounds") },
+	{ "[$JMD]",	N_("Jamaica, Dollars") },
+	{ "[$JOD]",	N_("Jordan, Dinars") },
+	{ "[$JPY]",	N_("Japan, Yen") },
+	{ "[$KES]",	N_("Kenya, Shillings") },
+	{ "[$KGS]",	N_("Kyrgyzstan, Soms") },
+	{ "[$KHR]",	N_("Cambodia, Riels") },
+	{ "[$KMF]",	N_("Comoros, Francs") },
+	{ "[$KPW]",	N_("Korea (North), Won") },
+	{ "[$KRW]",	N_("Korea (South), Won") },
+	{ "[$KWD]",	N_("Kuwait, Dinars") },
+	{ "[$KYD]",	N_("Cayman Islands, Dollars") },
+	{ "[$KZT]",	N_("Kazakstan, Tenge") },
+	{ "[$LAK]",	N_("Laos, Kips") },
+	{ "[$LBP]",	N_("Lebanon, Pounds") },
+	{ "[$LKR]",	N_("Sri Lanka, Rupees") },
+	{ "[$LRD]",	N_("Liberia, Dollars") },
+	{ "[$LSL]",	N_("Lesotho, Maloti") },
+	{ "[$LTL]",	N_("Lithuania, Litai") },
+	{ "[$LVL]",	N_("Latvia, Lati") },
+	{ "[$LYD]",	N_("Libya, Dinars") },
+	{ "[$MAD]",	N_("Morocco, Dirhams") },
+	{ "[$MDL]",	N_("Moldova, Lei") },
+	{ "[$MGF]",	N_("Madagascar, Malagasy Francs") },
+	{ "[$MKD]",	N_("Macedonia, Denars") },
+	{ "[$MMK]",	N_("Myanmar (Burma), Kyats") },
+	{ "[$MNT]",	N_("Mongolia, Tugriks") },
+	{ "[$MOP]",	N_("Macau, Patacas") },
+	{ "[$MRO]",	N_("Mauritania, Ouguiyas") },
+	{ "[$MTL]",	N_("Malta, Liri") },
+	{ "[$MUR]",	N_("Mauritius, Rupees") },
+	{ "[$MVR]",	N_("Maldives (Maldive Islands), Rufiyaa") },
+	{ "[$MWK]",	N_("Malawi, Kwachas") },
+	{ "[$MXN]",	N_("Mexico, Pesos") },
+	{ "[$MYR]",	N_("Malaysia, Ringgits") },
+	{ "[$MZM]",	N_("Mozambique, Meticais") },
+	{ "[$NAD]",	N_("Namibia, Dollars") },
+	{ "[$NGN]",	N_("Nigeria, Nairas") },
+	{ "[$NIO]",	N_("Nicaragua, Gold Cordobas") },
+	{ "[$NOK]",	N_("Norway, Krone") },
+	{ "[$NPR]",	N_("Nepal, Nepal Rupees") },
+	{ "[$NZD]",	N_("New Zealand, Dollars") },
+	{ "[$OMR]",	N_("Oman, Rials") },
+	{ "[$PAB]",	N_("Panama, Balboa") },
+	{ "[$PEN]",	N_("Peru, Nuevos Soles") },
+	{ "[$PGK]",	N_("Papua New Guinea, Kina") },
+	{ "[$PHP]",	N_("Philippines, Pesos") },
+	{ "[$PKR]",	N_("Pakistan, Rupees") },
+	{ "[$PLN]",	N_("Poland, Zlotych") },
+	{ "[$PYG]",	N_("Paraguay, Guarani") },
+	{ "[$QAR]",	N_("Qatar, Rials") },
+	{ "[$ROL]",	N_("Romania, Lei") },
+	{ "[$RUR]",	N_("Russia, Rubles") },
+	{ "[$RWF]",	N_("Rwanda, Rwanda Francs") },
+	{ "[$SAR]",	N_("Saudi Arabia, Riyals") },
+	{ "[$SBD]",	N_("Solomon Islands, Dollars") },
+	{ "[$SCR]",	N_("Seychelles, Rupees") },
+	{ "[$SDD]",	N_("Sudan, Dinars") },
+	{ "[$SEK]",	N_("Sweden, Kronor") },
+	{ "[$SGD]",	N_("Singapore, Dollars") },
+	{ "[$SHP]",	N_("Saint Helena, Pounds") },
+	{ "[$SIT]",	N_("Slovenia, Tolars") },
+	{ "[$SKK]",	N_("Slovakia, Koruny") },
+	{ "[$SLL]",	N_("Sierra Leone, Leones") },
+	{ "[$SOS]",	N_("Somalia, Shillings") },
+	{ "[$SPL]",	N_("Seborga, Luigini") },
+	{ "[$SRG]",	N_("Suriname, Guilders") },
+	{ "[$STD]",	N_("Sao Tome and Principe, Dobras") },
+	{ "[$SVC]",	N_("El Salvador, Colones") },
+	{ "[$SYP]",	N_("Syria, Pounds") },
+	{ "[$SZL]",	N_("Swaziland, Emalangeni") },
+	{ "[$THB]",	N_("Thailand, Baht") },
+	{ "[$TJR]",	N_("Tajikistan, Rubles") },
+	{ "[$TMM]",	N_("Turkmenistan, Manats") },
+	{ "[$TND]",	N_("Tunisia, Dinars") },
+	{ "[$TOP]",	N_("Tonga, Pa'anga") },
+	{ "[$TRL]",	N_("Turkey, Liras") },
+	{ "[$TTD]",	N_("Trinidad and Tobago, Dollars") },
+	{ "[$TVD]",	N_("Tuvalu, Tuvalu Dollars") },
+	{ "[$TWD]",	N_("Taiwan, New Dollars") },
+	{ "[$TZS]",	N_("Tanzania, Shillings") },
+	{ "[$UAH]",	N_("Ukraine, Hryvnia") },
+	{ "[$UGX]",	N_("Uganda, Shillings") },
+	{ "[$USD]",	N_("United States of America, Dollars") },
+	{ "[$UYU]",	N_("Uruguay, Pesos") },
+	{ "[$UZS]",	N_("Uzbekistan, Sums") },
+	{ "[$VEB]",	N_("Venezuela, Bolivares") },
+	{ "[$VND]",	N_("Viet Nam, Dong") },
+	{ "[$VUV]",	N_("Vanuatu, Vatu") },
+	{ "[$WST]",	N_("Samoa, Tala") },
+	{ "[$XAF]",	N_("Communaute Financiere Africaine BEAC, Francs") },
+	{ "[$XAG]",	N_("Silver, Ounces") },
+	{ "[$XAU]",	N_("Gold, Ounces") },
+	{ "[$XCD]",	N_("East Caribbean Dollars") },
+	{ "[$XDR]",	N_("International Monetary Fund (IMF) Special Drawing Rights") },
+	{ "[$XOF]",	N_("Communaute Financiere Africaine BCEAO, Francs") },
+	{ "[$XPD]",	N_("Palladium Ounces") },
+	{ "[$XPF]",	N_("Comptoirs Francais du Pacifique Francs") },
+	{ "[$XPT]",	N_("Platinum, Ounces") },
+	{ "[$YER]",	N_("Yemen, Rials") },
+	{ "[$YUM]",	N_("Yugoslavia, New Dinars") },
+	{ "[$ZAR]",	N_("South Africa, Rand") },
+	{ "[$ZMK]",	N_("Zambia, Kwacha") },
+	{ "[$ZWD]",	N_("Zimbabwe, Zimbabwe Dollars") },
+
 	{ NULL, NULL }
 };
 
