@@ -37,8 +37,8 @@ static const char *help_sum = {
 
 	   "@DESCRIPTION="
 	   "SUM computes the sum of all the values and cells referenced "
-	   "in the argument list.\n"
-	   "This function is Excel compatible."
+	   "in the argument list.\n\n"
+	   "* This function is Excel compatible."
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "Let us assume that the cells A1, A2, ..., A5 contain numbers "
@@ -67,9 +67,9 @@ static const char *help_product = {
 
 	   "@DESCRIPTION="
 	   "PRODUCT returns the product of all the values and cells "
-	   "referenced in the argument list.\n"
-	   "This function is Excel compatible.  In particular, this means "
-	   "that if all cells are empty, the result will be 0."
+	   "referenced in the argument list.\n\n"
+	   "* This function is Excel compatible.  In particular, this means "
+	   "that if all cells are empty, the result will be 0.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "PRODUCT(2,5,9) equals 90.\n"
@@ -137,17 +137,17 @@ func_builtin_init (void)
 
 	def = function_add_nodes (mathcat, "sum",     0,
 				  N_("number,number,"),
-				  &help_sum, gnumeric_sum);
+				  &help_sum, gnumeric_sum, NULL);
 	auto_format_function_result (def, AF_FIRST_ARG_FORMAT);
 	mathfuncs = g_slist_prepend (mathfuncs, def);
 
 	def = function_add_nodes (mathcat, "product", 0,
 				  N_("number,number,"),    
-				  &help_product, gnumeric_product);
+				  &help_product, gnumeric_product, NULL);
 	mathfuncs = g_slist_prepend (mathfuncs, def);
 
 	def = function_add_args (gnumericcat, "gnumeric_version", "",  "",
-				 &help_gnumeric_version, gnumeric_version);
+				 &help_gnumeric_version, gnumeric_version, NULL);
 	gnumericfuncs = g_slist_prepend (gnumericfuncs, def);
 }
 
