@@ -161,49 +161,37 @@ g_list_free_custom (GList *list, GFreeFunc free_func)
 }
 
 /**
- * g_string_list_copy:
- * @list: List of strings.
- *
- * Creates a copy of the given string list (strings are also copied using
- * g_strdup).
- *
- * Return value: new copy of the list which you should free after use using
- *               function e_free_string_list()
+ * g_list_map:
+ * @list        : list of some items
+ * @map_func    : mapping function
  */
 GList *
-g_string_list_copy (GList *list)
+g_list_map (GList *list, GnmMapFunc map_func)
 {
-	GList *list_copy = NULL, *l;
+	GList *list_copy = NULL;
 
-	for (l = list; l != NULL; l = l->next) {
-		list_copy = g_list_prepend (list_copy, g_strdup ((gchar *) l->data));
-	}
-	list_copy = g_list_reverse (list_copy);
+	GNM_LIST_FOREACH (list, void, value,
+		GNM_LIST_PREPEND (list_copy, map_func (value))
+	);
 
-	return list_copy;
+	return g_list_reverse (list_copy);
 }
 
 /**
- * g_string_list_copy:
- * @list: List of strings.
- *
- * Creates a copy of the given string list (strings are also copied using
- * g_strdup).
- *
- * Return value: new copy of the list which you should free after use using
- *               function e_free_string_list()
+ * g_slist_map:
+ * @list        : list of some items
+ * @map_func    : mapping function
  */
 GSList *
-g_string_slist_copy (GSList *list)
+g_slist_map (GSList *list, GnmMapFunc map_func)
 {
-	GSList *list_copy = NULL, *l;
+	GSList *list_copy = NULL;
 
-	for (l = list; l != NULL; l = l->next) {
-		list_copy = g_slist_prepend (list_copy, g_strdup ((gchar *) l->data));
-	}
-	list_copy = g_slist_reverse (list_copy);
+	GNM_SLIST_FOREACH (list, void, value,
+		GNM_SLIST_PREPEND (list_copy, map_func (value))
+	);
 
-	return list_copy;
+	return g_slist_reverse (list_copy);
 }
 
 /**
@@ -309,9 +297,15 @@ g_lang_score_in_lang_list (gchar *lang, GList *lang_list)
 }
 
 gint
-gnumeric_strcase_equal (gconstpointer v, gconstpointer v2)
+gnumeric_strcase_equal (gconstpointer v1, gconstpointer v2)
 {
-	return g_strcasecmp ((gchar const *) v, (gchar const *)v2) == 0;
+	/* FIXME: this is expensive!  */
+	char *s1 = g_utf8_casefold (v1, -1);
+	char *s2 = g_utf8_casefold (v2, -1);
+	int res = (strcmp (s1, s2) == 0);
+	g_free (s1);
+	g_free (s2);
+	return res;
 }
 
 /* a char* hash function from ASU */
@@ -385,110 +379,6 @@ gnumeric_usr_plugin_dir (void)
 	return gnumeric_usr_dir (PLUGIN_SUFFIX);
 }
 
-/* ------------------------------------------------------------------------- */
-/*
- * Note: the code below might look awful, but fixed-sized memcpy ought to
- * produce reasonable code.
- */
-
-gint16
-gnumeric_get_le_int16 (void const *p)
-{
-	gint16 data;
-	memcpy (&data, p, sizeof (data));
-	return GINT16_FROM_LE (data);
-}
-
-guint16
-gnumeric_get_le_uint16 (void const *p)
-{
-	guint16 data;
-	memcpy (&data, p, sizeof (data));
-	return GUINT16_FROM_LE (data);
-}
-
-gint32
-gnumeric_get_le_int32 (void const *p)
-{
-	gint32 data;
-	memcpy (&data, p, sizeof (data));
-	return GINT32_FROM_LE (data);
-}
-
-guint32
-gnumeric_get_le_uint32 (void const *p)
-{
-	guint32 data;
-	memcpy (&data, p, sizeof (data));
-	return GUINT32_FROM_LE (data);
-}
-
-double
-gnumeric_get_le_double (void const *p)
-{
-#if G_BYTE_ORDER == G_BIG_ENDIAN
-	if (sizeof (double) == 8) {
-		double  d;
-		int     i;
-		guint8 *t  = (guint8 *)&d;
-		guint8 *p2 = (guint8 *)p;
-		int     sd = sizeof (d);
-
-		for (i = 0; i < sd; i++)
-			t[i] = p2[sd - 1 - i];
-
-		return d;
-	} else {
-		g_error ("Big endian machine, but weird size of doubles");
-	}
-#elif G_BYTE_ORDER == G_LITTLE_ENDIAN
-	if (sizeof (double) == 8) {
-		/*
-		 * On i86, we could access directly, but Alphas require
-		 * aligned access.
-		 */
-		double data;
-		memcpy (&data, p, sizeof (data));
-		return data;
-	} else {
-		g_error ("Little endian machine, but weird size of doubles");
-	}
-#else
-#error "Byte order not recognised -- out of luck"
-#endif
-}
-
-
-void
-gnumeric_set_le_double (void *p, double d)
-{
-#if G_BYTE_ORDER == G_BIG_ENDIAN
-	if (sizeof (double) == 8) {
-		int     i;
-		guint8 *t  = (guint8 *)&d;
-		guint8 *p2 = (guint8 *)p;
-		int     sd = sizeof (d);
-
-		for (i = 0; i < sd; i++)
-			p2[sd - 1 - i] = t[i];
-	} else {
-		g_error ("Big endian machine, but weird size of doubles");
-	}
-#elif G_BYTE_ORDER == G_LITTLE_ENDIAN
-	if (sizeof (double) == 8) {
-		/*
-		 * On i86, we could access directly, but Alphas require
-		 * aligned access.
-		 */
-		memcpy (p, &d, sizeof (d));
-	} else {
-		g_error ("Little endian machine, but weird size of doubles");
-	}
-#else
-#error "Byte order not recognised -- out of luck"
-#endif
-}
-
 /* ------------------------------------------------------------------------- */
 
 /*
@@ -506,19 +396,21 @@ gnumeric_strescape (char const *string)
 
 	g_return_val_if_fail (string != NULL, NULL);
 
-	for (p = string; *p; p++)
+	for (p = string; *p; p = g_utf8_next_char (p))
 		if (*p == '\\' || *p == '\"')
 			escapechars++;
 
-	q = escaped = g_new (char, strlen (string) + escapechars + 3);
+	q = escaped = g_new (char, (p - string) + escapechars + 3);
 	*q++ = '\"';
-	for (p = string; *p; p++) {
+	for (p = string; *p; ) {
+		char *next = g_utf8_next_char (p);
 		if (*p == '\\' || *p == '\"')
 			*q++ = '\\';
-		*q++ = *p;
+		while (p < next)
+			*q++ = *p++;
 	}
 	*q++ = '\"';
-	*q = '\000';
+	*q = 0;
 
 	return escaped;
 }
