@@ -1,13 +1,13 @@
 #ifndef GNUMERIC_IO_CONTEXT_PRIV_H
 #define GNUMERIC_IO_CONTEXT_PRIV_H
 
-#include <gtk/gtkobject.h>
+#include <glib-object.h>
 #include "io-context.h"
 #include "workbook-control.h"
 #include "error-info.h"
 
-#define IO_CONTEXT_CLASS(klass)     (GTK_CHECK_CLASS_CAST ((klass), TYPE_IO_CONTEXT, IOContext))
-#define IS_IO_CONTEXT_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), TYPE_IO_CONTEXT))
+#define IO_CONTEXT_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IO_CONTEXT, IOContext))
+#define IS_IO_CONTEXT_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IO_CONTEXT))
 
 typedef enum {
 	GNUM_PROGRESS_HELPER_NONE,
@@ -50,7 +50,7 @@ typedef struct {
 } ProgressRange;
 
 struct _IOContext {
-	GtkObject parent;
+	GObject parent;
 
 	CommandContext *impl;
 	ErrorInfo *error_info;
@@ -64,7 +64,7 @@ struct _IOContext {
 };
 
 struct _IOContextClass {
-	GtkObjectClass parent_class;
+	GObjectClass parent_class;
 };
 
 #endif /* GNUMERIC_IO_CONTEXT_PRIV_H */
