@@ -46,7 +46,6 @@
 #define GNUMERIC_ITEM "GRID"
 #include "item-debug.h"
 
-#undef PAINT_DEBUG
 #if 0
 #define MERGE_DEBUG(range, str) do { range_dump (range, str); } while (0)
 #else
@@ -96,6 +95,8 @@ struct _ItemGrid {
 	GnmHLink *cur_link; /* do not derference, just a pointer */
 	GtkWidget *tip;
 	guint tip_timer;
+
+	guint32 last_click_time;
 };
 
 static void
@@ -451,7 +452,7 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 
 					if (ci->visible)
 						item_grid_draw_merged_range (drawable, ig,
-						diff_x, y, &view, r, draw_selection);
+							diff_x, y, &view, r, draw_selection);
 				}
 			} else {
 				lag = &(ptr->next);
@@ -488,10 +489,28 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 			if (merged_active != NULL) {
 				Range const *r = merged_active->data;
 				if (r->start.col <= col) {
-					gboolean clear_top, clear_bottom = TRUE;
+					gboolean clear_top, clear_bottom = FALSE;
 					int i, first = r->start.col;
 					int last  = r->end.col;
 
+					ptr = merged_active;
+					merged_active = merged_active->next;
+					if (r->end.row <= row) {
+						ptr->next = merged_used;
+						merged_used = ptr;
+						MERGE_DEBUG (r, " : active -> used\n");
+
+						/* in case something managed the bottom of a merge */
+						if (r->end.row < row)
+							continue;
+					} else {
+						ptr->next = merged_active_seen;
+						merged_active_seen = ptr;
+						MERGE_DEBUG (r, " : active -> seen\n");
+						if (next_sr.row <= r->end.row)
+							clear_bottom = TRUE;
+					}
+
 					x += scg_colrow_distance_get (
 						gcanvas->simple.scg, TRUE, col, last+1);
 					col = last;
@@ -506,19 +525,6 @@ item_grid_draw (GnomeCanvasItem *item, GdkDrawable *drawable,
 					}
 					clear_top = (r->start.row != row);
 
-					ptr = merged_active;
-					merged_active = merged_active->next;
-					if (r->end.row <= row) {
-						clear_bottom = FALSE;
-						ptr->next = merged_used;
-						merged_used = ptr;
-						MERGE_DEBUG (r, " : active -> used\n");
-					} else {
-						ptr->next = merged_active_seen;
-						merged_active_seen = ptr;
-						MERGE_DEBUG (r, " : active -> seen\n");
-					}
-
 					/* Clear the borders */
 					for (i = first ; i <= last ; i++) {
 						if (clear_top)
@@ -922,24 +928,41 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	if (!wbcg_edit_finish (scg->wbcg, TRUE))
 		return 1;
 
-	if (!(event->state & (GDK_CONTROL_MASK|GDK_SHIFT_MASK)))
-		sv_selection_reset (sc->view);
+	/* button 1 will always change the selection,  the other buttons will
+	 * only effect things if the target is not already selected.
+	 */
+	if (event->button == 1 || !sv_is_pos_selected (sc->view, pos.col, pos.row)) {
+		if (!(event->state & (GDK_CONTROL_MASK|GDK_SHIFT_MASK)))
+			sv_selection_reset (sc->view);
 
-	if (event->button != 1 || !(event->state & GDK_SHIFT_MASK) ||
-	    sc->view->selections == NULL) {
-		sv_selection_add_pos (sc->view, pos.col, pos.row);
-		sv_make_cell_visible (sc->view, pos.col, pos.row, FALSE);
-	} else if (event->button != 2)
-		sv_selection_extend_to (sc->view, pos.col, pos.row);
-	sheet_update (sheet);
+		if (event->button != 1 || !(event->state & GDK_SHIFT_MASK) ||
+		    sc->view->selections == NULL) {
+			sv_selection_add_pos (sc->view, pos.col, pos.row);
+			sv_make_cell_visible (sc->view, pos.col, pos.row, FALSE);
+		} else if (event->button != 2)
+			sv_selection_extend_to (sc->view, pos.col, pos.row);
+		sheet_update (sheet);
+	}
 
       	switch (event->button) {
-	case 1: ig->selecting = ITEM_GRID_SELECTING_CELL_RANGE;
+	case 1: {
+		guint32 double_click_time;
+		g_object_get (gtk_widget_get_settings (GTK_WIDGET (canvas)),
+			"gtk-double-click-time", &double_click_time,
+			NULL);
+
+		if ((ig->last_click_time + double_click_time) > event->time &&
+		    wbcg_edit_start (scg->wbcg, FALSE, FALSE))
+			break;
+
+		ig->last_click_time = event->time;
+		ig->selecting = ITEM_GRID_SELECTING_CELL_RANGE;
 		gnm_canvas_slide_init (gcanvas);
 		gnm_simple_canvas_grab (item,
 			GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
 			NULL, event->time);
 		break;
+	}
 
       	/* This is here just for demo purposes */
       	case 2: drag_start (GTK_WIDGET (item->canvas), event, sheet);
@@ -1013,7 +1036,6 @@ cb_cursor_come_to_rest (ItemGrid *ig)
 			ig->tip = gnumeric_create_tooltip ();
 			gtk_label_set_text (GTK_LABEL (ig->tip),
 				gnm_hlink_get_tip (link));
-			puts (gnm_hlink_get_tip (link));
 			gnumeric_position_tooltip (ig->tip, TRUE);
 			gtk_widget_show_all (gtk_widget_get_toplevel (ig->tip));
 		}
