@@ -27,6 +27,7 @@
 #include "str.h"
 
 #include <ctype.h>
+#include <string.h>
 #include <locale.h>
 
 /*
@@ -304,8 +305,7 @@ print_cell (Cell const *cell, MStyle const *mstyle, GnomePrintContext *context,
 	    double x1, double y1, double width, double height, double h_center)
 {
 	StyleFont *style_font = mstyle_get_font (mstyle, 1.0);
-#warning FIXME
-	GnomeFont *print_font = NULL; /* style_font->font; */
+	GnomeFont *print_font = style_font->gnome_print_font;
 	double const font_descent = gnome_font_get_descender (print_font);
 	double const font_ascent = gnome_font_get_ascender (print_font);
 	double rect_x, rect_width, rect_y, rect_height;
@@ -334,7 +334,7 @@ print_cell (Cell const *cell, MStyle const *mstyle, GnomePrintContext *context,
 	g_return_if_fail (cell->rendered_value->rendered_text);
 
 	if (cell->rendered_value->rendered_text->str == NULL) {
-		g_warning ("Serious cell error at '%s'\n", cell_name (cell));
+		g_warning ("Serious cell error at '%s'", cell_name (cell));
 		/* This can occur when eg. a plugin function fires up a dialog */
 		text = "Pending";
 	} else
@@ -364,7 +364,7 @@ print_cell (Cell const *cell, MStyle const *mstyle, GnomePrintContext *context,
 
 	switch (valign) {
 	default:
-		g_warning ("Unhandled cell vertical alignment\n");
+		g_warning ("Unhandled cell vertical alignment.");
 
 	case VALIGN_JUSTIFY:
 	case VALIGN_TOP:
@@ -384,9 +384,10 @@ print_cell (Cell const *cell, MStyle const *mstyle, GnomePrintContext *context,
 		/*
 		 * rect.y == first pixel past margin
 		 * add height == first pixel in lower margin
-		 * subtract font descent
+		 * subtract font descent (sign of descent seems reversed for
+		 *	 gnome-print-2.0)
 		 */
-		text_base = rect_y - height + font_descent;
+		text_base = rect_y - height - font_descent;
 		break;
 	}
 
@@ -472,7 +473,7 @@ print_cell (Cell const *cell, MStyle const *mstyle, GnomePrintContext *context,
 			break;
 
 		default:
-			g_warning ("Single-line justitfication style not supported\n");
+			g_warning ("Single-line justitfication style not supported.");
 			x = rect_x;
 			break;
 		}
@@ -526,7 +527,7 @@ print_cell (Cell const *cell, MStyle const *mstyle, GnomePrintContext *context,
 			break;
 
 		default:
-			g_warning ("Unhandled cell vertical alignment\n");
+			g_warning ("Unhandled cell vertical alignment.");
 			y_offset = 0;
 			inter_space = font_height;
 		}
@@ -540,7 +541,7 @@ print_cell (Cell const *cell, MStyle const *mstyle, GnomePrintContext *context,
 
 			switch (halign) {
 			default:
-				g_warning ("Multi-line justification style not supported\n");
+				g_warning ("Multi-line justification style not supported.");
 			case HALIGN_JUSTIFY:
 				/* fall through */
 			case HALIGN_LEFT:
