@@ -109,6 +109,7 @@ print_info_free (PrintInformation *pi)
 
 	print_hf_free (pi->header);
 	print_hf_free (pi->footer);
+	gnome_print_config_unref(pi->print_config);
 
 	g_free (pi);
 }
@@ -250,6 +251,11 @@ print_info_new (void)
 
 	pi = g_new0 (PrintInformation, 1);
 
+	pi->print_config = gnome_print_config_default ();
+
+	/* FIXME: The print_config default configuration is probably not right! */
+	/* Specifically we should load the default paper size and formats       */
+
 	gnome_config_push_prefix ("/Gnumeric/Print/");
 
 	pi->n_copies = gnome_config_get_int ("num_copies=1");
@@ -270,25 +276,11 @@ print_info_new (void)
 	s = g_strdup_printf ("%.13g", unit_convert (1.0, UNIT_CENTIMETER, UNIT_POINTS));
 	load_margin ("margin_top", &pi->margins.top,       s);
 	load_margin ("margin_bottom", &pi->margins.bottom, s);
-	load_margin ("margin_left", &pi->margins.left,     s);
-	load_margin ("margin_right", &pi->margins.right,   s);
-	g_free (s);
-	s = g_strdup_printf ("%.13g", unit_convert (0.5, UNIT_CENTIMETER, UNIT_POINTS));
-	load_margin ("margin_header", &pi->margins.header, s);
-	load_margin ("margin_footer", &pi->margins.footer, s);
 	g_free (s);
 
 	pi->header = load_hf ("header", "", _("&[TAB]"), "");
 	pi->footer = load_hf ("footer", "", _("Page &[PAGE]"), "");
 
-	s = gnome_config_get_string ("paper=none");
-	if (strcmp (s, "none") != 0)
-		pi->paper = gnome_print_paper_get_by_name (s);
-
-	if (pi->paper == NULL)
-		pi->paper = gnome_print_paper_get_default ();
-	g_free (s);
-
 	pi->center_horizontally       = gnome_config_get_bool ("center_horizontally=false");
 	pi->center_vertically         = gnome_config_get_bool ("center_vertically=false");
 	pi->print_grid_lines          = gnome_config_get_bool ("print_grid_lines=false");
@@ -314,7 +306,7 @@ print_info_new (void)
 }
 
 static void
-save_margin (char const *prefix, PrintUnit *p)
+save_margin (char const *prefix, PrintUnit const *p)
 {
 	char *x = g_strconcat (prefix, "_units", NULL);
 
@@ -324,7 +316,7 @@ save_margin (char const *prefix, PrintUnit *p)
 }
 
 static void
-save_range (char const *section, PrintRepeatRange *repeat)
+save_range (char const *section, PrintRepeatRange const *repeat)
 {
 	char const *s = (repeat->use) ? range_name (&repeat->range) : "";
 	gnome_config_set_string (section, s);
@@ -385,8 +377,11 @@ destroy_formats (void)
 }
 
 void
-print_info_save (PrintInformation *pi)
+print_info_save (PrintInformation const *pi)
 {
+	/* FIXME: The print_config  configuration should be saved               */
+	/* Specifically we should save the default paper size and formats       */
+
 	gnome_config_push_prefix ("/Gnumeric/Print/");
 
 	gnome_config_set_int ("num_copies", pi->n_copies);
@@ -395,14 +390,9 @@ print_info_save (PrintInformation *pi)
 	gnome_config_set_float ("scale_percent", pi->scaling.percentage);
 	gnome_config_set_int ("scale_width", pi->scaling.dim.cols);
 	gnome_config_set_int ("scale_height", pi->scaling.dim.rows);
-	gnome_config_set_string ("paper", pi->paper->name);
 
 	save_margin ("margin_top", &pi->margins.top);
 	save_margin ("margin_bottom", &pi->margins.bottom);
-	save_margin ("margin_left", &pi->margins.left);
-	save_margin ("margin_right", &pi->margins.right);
-	save_margin ("margin_header", &pi->margins.header);
-	save_margin ("margin_footer", &pi->margins.footer);
 
 	gnome_config_set_bool ("center_horizontally", pi->center_horizontally);
 	gnome_config_set_bool ("center_vertically", pi->center_vertically);
@@ -706,18 +696,21 @@ print_shutdown (void)
 
 
 static void
-print_info_margin_copy (PrintUnit *src_print_unit, PrintUnit *dst_print_unit)
+print_info_margin_copy (PrintUnit const *src_print_unit, PrintUnit *dst_print_unit)
 {
 	dst_print_unit->points = src_print_unit->points;
-	dst_print_unit->desired_display = dst_print_unit->desired_display;
+	dst_print_unit->desired_display = src_print_unit->desired_display;
 }
 
 PrintInformation *
-print_info_copy (PrintInformation *src_pi)
+print_info_dup (PrintInformation const *src_pi)
 {
 	PrintInformation *dst_pi;
 
-	dst_pi = print_info_new();
+	dst_pi = print_info_new ();
+	
+	gnome_print_config_unref (dst_pi->print_config);
+	dst_pi->print_config       = gnome_print_config_dup (src_pi->print_config);
 
 	dst_pi->orientation        = src_pi->orientation;
 
@@ -727,13 +720,9 @@ print_info_copy (PrintInformation *src_pi)
 	dst_pi->scaling.dim.cols   = src_pi->scaling.dim.cols;
 	dst_pi->scaling.dim.rows   = src_pi->scaling.dim.rows;
 
-	/* Margins */
+	/* Margins (note that the others are copied as part of print_config) */
 	print_info_margin_copy (&src_pi->margins.top,    &dst_pi->margins.top);
 	print_info_margin_copy (&src_pi->margins.bottom, &dst_pi->margins.bottom);
-	print_info_margin_copy (&src_pi->margins.left,   &dst_pi->margins.left);
-	print_info_margin_copy (&src_pi->margins.right,  &dst_pi->margins.right);
-	print_info_margin_copy (&src_pi->margins.header, &dst_pi->margins.header);
-	print_info_margin_copy (&src_pi->margins.footer, &dst_pi->margins.footer);
 
 	/* Booleans */
 	dst_pi->center_vertically	  = src_pi->center_vertically;
@@ -742,6 +731,7 @@ print_info_copy (PrintInformation *src_pi)
 	dst_pi->print_even_if_only_styles = src_pi->print_even_if_only_styles;
 	dst_pi->print_black_and_white	  = src_pi->print_black_and_white;
 	dst_pi->print_as_draft		  = src_pi->print_as_draft;
+	dst_pi->print_comments		  = src_pi->print_comments;
 	dst_pi->print_titles		  = src_pi->print_titles;
 	dst_pi->print_order		  = src_pi->print_order;
 
@@ -751,12 +741,85 @@ print_info_copy (PrintInformation *src_pi)
 	print_hf_free (dst_pi->footer);
 	dst_pi->footer = print_hf_copy (src_pi->footer);
 
-	/* Paper */
-	dst_pi->paper = gnome_print_paper_get_by_name (src_pi->paper->name);
-
 	/* Repeat Range */
 	dst_pi->repeat_top  = src_pi->repeat_top;
 	dst_pi->repeat_left = src_pi->repeat_left;
 
 	return dst_pi;
 }
+
+gboolean    
+print_info_get_margins (PrintInformation const *pi, 
+			double *top, double *bottom, double *left, double *right)
+{
+	gboolean res_top, res_bottom, res_left, res_right;
+
+	g_return_val_if_fail (pi->print_config != NULL, FALSE);
+
+
+	res_top = gnome_print_config_get_length (pi->print_config, 
+						 GNOME_PRINT_KEY_PAGE_MARGIN_TOP, 
+						 top, NULL);
+	res_bottom = gnome_print_config_get_length (pi->print_config, 
+						    GNOME_PRINT_KEY_PAGE_MARGIN_BOTTOM, 
+						    bottom, NULL);
+	res_left = gnome_print_config_get_length (pi->print_config, 
+						  GNOME_PRINT_KEY_PAGE_MARGIN_LEFT, 
+						  left, NULL);
+	res_right = gnome_print_config_get_length (pi->print_config, 
+						   GNOME_PRINT_KEY_PAGE_MARGIN_RIGHT, 
+						   right, NULL);
+	return res_top && res_bottom && res_left && res_right;
+}
+
+void        
+print_info_set_margin_header   (PrintInformation *pi, double top)
+{
+	g_return_if_fail (pi->print_config != NULL);
+
+	gnome_print_config_set_length (pi->print_config, 
+				       GNOME_PRINT_KEY_PAGE_MARGIN_TOP, 
+				       top, GNOME_PRINT_PS_UNIT);
+}
+
+void        
+print_info_set_margin_footer   (PrintInformation *pi, double bottom)
+{
+	g_return_if_fail (pi->print_config != NULL);
+
+	gnome_print_config_set_length (pi->print_config, 
+				       GNOME_PRINT_KEY_PAGE_MARGIN_BOTTOM, 
+				       bottom, GNOME_PRINT_PS_UNIT);
+}
+
+void        
+print_info_set_margin_left     (PrintInformation *pi, double left)
+{
+	g_return_if_fail (pi->print_config != NULL);
+
+	gnome_print_config_set_length (pi->print_config, 
+				       GNOME_PRINT_KEY_PAGE_MARGIN_LEFT, 
+				       left, GNOME_PRINT_PS_UNIT);
+}
+
+void        
+print_info_set_margin_right    (PrintInformation *pi, double right)
+{
+	g_return_if_fail (pi->print_config != NULL);
+
+	gnome_print_config_set_length (pi->print_config, 
+				       GNOME_PRINT_KEY_PAGE_MARGIN_RIGHT, 
+				       right, GNOME_PRINT_PS_UNIT);
+}
+
+void
+print_info_set_margins (PrintInformation *pi, 
+			double top, double bottom, double left, double right)
+{
+	g_return_if_fail (pi->print_config != NULL);
+
+	print_info_set_margin_header (pi, top);
+	print_info_set_margin_footer (pi, bottom);
+	print_info_set_margin_left (pi, left);
+	print_info_set_margin_right (pi, right);
+}
