@@ -29,6 +29,229 @@
 #include "sheet-control.h"
 #include <libgnome/gnome-i18n.h>
 
+/**
+ * sv_is_singleton_selected:
+ * @sv :
+ *
+ * See if the 1st selected region is a singleton.
+ *
+ * Returns A CellPos pointer if the selection is a singleton, and NULL if not.
+ **/
+CellPos const *
+sv_is_singleton_selected (SheetView const *sv)
+{
+	if (sv->cursor.move_corner.col == sv->cursor.base_corner.col &&
+	    sv->cursor.move_corner.row == sv->cursor.base_corner.row)
+		return &sv->cursor.move_corner;
+	return NULL;
+}
+
+/**
+ * sv_is_pos_selected :
+ * @sv :
+ * @col :
+ * @row :
+ *
+ * Returns TRUE if the supplied position is selected in view @sv.
+ **/
+gboolean
+sv_is_pos_selected (SheetView const *sv, int col, int row)
+{
+	GList *ptr;
+	Range const *sr;
+
+	for (ptr = sv->selections; ptr != NULL ; ptr = ptr->next) {
+		sr = ptr->data;
+		if (range_contains (sr, col, row))
+			return TRUE;
+	}
+	return FALSE;
+}
+
+/**
+ * sv_is_range_selected :
+ * @sv :
+ * @r  :
+ * 
+ * Returns TRUE If @r overlaps with any part of the selection in @sv.
+ **/
+gboolean
+sv_is_range_selected (SheetView const *sv, Range const *r)
+{
+	GList *ptr;
+	Range const *sr;
+
+	for (ptr = sv->selections; ptr != NULL ; ptr = ptr->next){
+		sr = ptr->data;
+		if (range_overlap (sr, r))
+			return TRUE;
+	}
+	return FALSE;
+}
+
+/**
+ * sv_is_full_range_selected :
+ *
+ * @sv :
+ * @r :
+ *
+ * Returns TRUE if all of @r is contained by the selection in @sv.
+ **/
+gboolean
+sv_is_full_range_selected (SheetView const *sv, Range const *r)
+{
+	GList *ptr;
+	Range const *sr;
+
+	for (ptr = sv->selections; ptr != NULL ; ptr = ptr->next) {
+		sr = ptr->data;
+		if (range_contained (r, sr))
+			return TRUE;
+	}
+	return FALSE;
+}
+
+/*
+ * sv_is_colrow_selected :
+ * @sv : containing the selection
+ * @colrow: The column or row number we are interested in.
+ * @is_col: A flag indicating whether this it is a column or a row.
+ *
+ * Searches the selection list to see whether the entire col/row specified is
+ * contained by the section regions.  Since the selection is stored as the set
+ * overlapping user specifed regions we can safely search for the range directly.
+ *
+ * Eventually to be completely correct and deal with the case of someone manually
+ * selection an entire col/row, in separate chunks,  we will need to do something
+ * more advanced.
+ */
+gboolean
+sv_is_colrow_selected (SheetView const *sv, int colrow, gboolean is_col)
+{
+	GList *l;
+	for (l = sv->selections; l != NULL; l = l->next) {
+		Range const *ss = l->data;
+
+		if (is_col) {
+			if (ss->start.row == 0 &&
+			    ss->end.row >= SHEET_MAX_ROWS-1 &&
+			    ss->start.col <= colrow && colrow <= ss->end.col)
+				return TRUE;
+		} else {
+			if (ss->start.col == 0 &&
+			    ss->end.col >= SHEET_MAX_COLS-1 &&
+			    ss->start.row <= colrow && colrow <= ss->end.row)
+				return TRUE;
+		}
+	}
+	return FALSE;
+}
+
+/**
+ * sv_is_full_colrow_selected
+ * @sv :
+ * @is_cols :
+ * @index :
+ *
+ * Returns TRUE if all of the selected cols/rows in the selection
+ * 	are fully selected and the selection contains the specified col.
+ **/
+gboolean
+sv_is_full_colrow_selected (SheetView const *sv, gboolean is_cols, int index)
+{
+	GList *l;
+	gboolean found = FALSE;
+
+	g_return_val_if_fail (IS_SHEET_VIEW (sv), FALSE);
+
+	for (l = sv->selections; l != NULL; l = l->next){
+		Range const *r = l->data;
+		if (is_cols) {
+			if (r->start.row > 0 || r->end.row < SHEET_MAX_ROWS - 1)
+				return FALSE;
+			if (r->start.col <= index && index <= r->end.col)
+				found = TRUE;
+		} else {
+			if (r->start.col > 0 || r->end.col < SHEET_MAX_COLS - 1)
+				return FALSE;
+			if (r->start.row <= index && index <= r->end.row)
+				found = TRUE;
+		}
+	}
+
+	return found;
+}
+
+/**
+ * sheet_col_selection_type :
+ * @sv :
+ * @col :
+ *
+ * Returns How much of column @col is selected in @sv.
+ **/
+ColRowSelectionType
+sheet_col_selection_type (SheetView const *sv, int col)
+{
+	GList *ptr;
+	Range const *sr;
+	int ret = COL_ROW_NO_SELECTION;
+
+	g_return_val_if_fail (IS_SHEET_VIEW (sv), COL_ROW_NO_SELECTION);
+
+	if (sv->selections == NULL)
+		return COL_ROW_NO_SELECTION;
+
+	for (ptr = sv->selections; ptr != NULL; ptr = ptr->next) {
+		sr = ptr->data;
+
+		if (sr->start.col > col || sr->end.col < col)
+			continue;
+
+		if (sr->start.row == 0 &&
+		    sr->end.row == SHEET_MAX_ROWS-1)
+			return COL_ROW_FULL_SELECTION;
+
+		ret = COL_ROW_PARTIAL_SELECTION;
+	}
+
+	return ret;
+}
+
+/**
+ * sheet_col_selection_type :
+ * @sv :
+ * @col :
+ *
+ * Returns How much of column @col is selected in @sv.
+ **/
+ColRowSelectionType
+sheet_row_selection_type (SheetView const *sv, int row)
+{
+	GList *ptr;
+	Range const *sr;
+	int ret = COL_ROW_NO_SELECTION;
+
+	g_return_val_if_fail (IS_SHEET_VIEW (sv), COL_ROW_NO_SELECTION);
+
+	if (sv->selections == NULL)
+		return COL_ROW_NO_SELECTION;
+
+	for (ptr = sv->selections; ptr != NULL; ptr = ptr->next) {
+		sr = ptr->data;
+
+		if (sr->start.row > row || sr->end.row < row)
+			continue;
+
+		if (sr->start.col == 0 &&
+		    sr->end.col == SHEET_MAX_COLS-1)
+			return COL_ROW_FULL_SELECTION;
+
+		ret = COL_ROW_PARTIAL_SELECTION;
+	}
+
+	return ret;
+}
+
 /*
  * Quick utility routine to test intersect of line segments.
  * Returns : 5 sA == sb eA == eb	a == b
@@ -58,6 +281,43 @@ segments_intersect (int const s_a, int const e_a,
 	return (e_a <= e_b) ? 2 : 1;
 }
 
+/**
+ * sv_menu_enable_insert :
+ * @sv :
+ * @col :
+ * @row :
+ *
+ * control whether or not it is ok to insert cols or rows.  An internal routine
+ * used by the selection mechanism to avoid erasing the entire sheet when
+ * inserting the wrong dimension.
+ */
+static void
+sv_menu_enable_insert (SheetView *sv, gboolean col, gboolean row)
+{
+	int flags = 0;
+
+	g_return_if_fail (IS_SHEET_VIEW (sv));
+
+	if (sv->enable_insert_cols != col) {
+		flags |= MS_INSERT_COLS;
+		sv->enable_insert_cols = col;
+	}
+	if (sv->enable_insert_rows != row) {
+		flags |= MS_INSERT_ROWS;
+		sv->enable_insert_rows = row;
+	}
+	if (sv->enable_insert_cells != (col|row)) {
+		flags |= MS_INSERT_CELLS;
+		sv->enable_insert_cells = (col|row);
+	}
+
+	/* during initialization it does not matter */
+	if (!flags || sv->sheet == NULL)
+		return;
+
+	WORKBOOK_VIEW_FOREACH_CONTROL(sv_wbv (sv), wbc,
+		wb_control_menu_state_update (wbc, flags););
+}
 /**
  * selection_first_range
  * @sheet        : The sheet whose selection we are testing.
@@ -68,15 +328,15 @@ segments_intersect (int const s_a, int const e_a,
  *    there is more than one range.
  */
 Range const *
-selection_first_range (Sheet const *sheet, 
+selection_first_range (SheetView const *sv,
 		       WorkbookControl *wbc, char const *cmd_name)
 {
 	Range const *r;
 	GList *l;
 
-	g_return_val_if_fail (IS_SHEET (sheet), NULL);
+	g_return_val_if_fail (IS_SHEET_VIEW (sv), NULL);
 
-	l = g_list_first (sheet->selections);
+	l = g_list_first (sv->selections);
 	g_return_val_if_fail (l != NULL && l->data != NULL, NULL);
 
 	r = l->data;
@@ -90,41 +350,38 @@ selection_first_range (Sheet const *sheet,
 }
 
 /**
- * sheet_selection_extend_to:
+ * sv_selection_extend_to:
  *
- * @sheet: the sheet
+ * @sv: the sheet
  * @col:   column that gets covered (negative indicates all cols)
  * @row:   row that gets covered (negative indicates all rows)
  *
  * This extends the selection to cover col, row and updates the status areas.
  */
 void
-sheet_selection_extend_to (Sheet *sheet, int col, int row)
+sv_selection_extend_to (SheetView *sv, int col, int row)
 {
 	int base_col, base_row;
 
-	g_return_if_fail (IS_SHEET (sheet));
-
 	if (col < 0) {
 		base_col = 0;
 		col = SHEET_MAX_COLS - 1;
 	} else
-		base_col = sheet->cursor.base_corner.col;
+		base_col = sv->cursor.base_corner.col;
 	if (row < 0) {
 		base_row = 0;
 		row = SHEET_MAX_ROWS - 1;
 	} else
-		base_row = sheet->cursor.base_corner.row;
+		base_row = sv->cursor.base_corner.row;
 
 	/* If nothing was going to change dont redraw */
-	if (sheet->cursor.move_corner.col == col &&
-	    sheet->cursor.move_corner.row == row &&
-	    sheet->cursor.base_corner.col == base_col &&
-	    sheet->cursor.base_corner.row == base_row)
+	if (sv->cursor.move_corner.col == col &&
+	    sv->cursor.move_corner.row == row &&
+	    sv->cursor.base_corner.col == base_col &&
+	    sv->cursor.base_corner.row == base_row)
 		return;
 
-	sheet_selection_set (sheet, sheet->edit_pos.col, sheet->edit_pos.row,
-			     base_col, base_row, col, row); 
+	sv_selection_set (sv, &sv->edit_pos, base_col, base_row, col, row);
 
 	/*
 	 * FIXME : Does this belong here ?
@@ -132,101 +389,17 @@ sheet_selection_extend_to (Sheet *sheet, int col, int row)
 	 * selection also update the status region, but this is somewhat lower
 	 * level that I want to do this.
 	 */
-	sheet_update (sheet);
-	WORKBOOK_FOREACH_VIEW (sheet->workbook, view,
+	sheet_update (sv->sheet);
+	WORKBOOK_FOREACH_VIEW (sv->sheet->workbook, view,
 	{
-		if (wb_view_cur_sheet (view) == sheet)
+		if (wb_view_cur_sheet (view) == sv->sheet)
 			wb_view_selection_desc (view, FALSE, NULL);
 	});
 }
 
-gboolean
-sheet_is_all_selected (Sheet const *sheet)
-{
-	Range *ss;
-	GList *l;
-
-	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
-
-	for (l = sheet->selections; l != NULL; l = l->next){
-		ss = l->data;
-
-		if (ss->start.col == 0 &&
-		    ss->start.row == 0 &&
-		    ss->end.col == SHEET_MAX_COLS-1 &&
-		    ss->end.row == SHEET_MAX_ROWS-1)
-			return TRUE;
-	}
-	return FALSE;
-}
-
-gboolean
-sheet_is_cell_selected (Sheet const *sheet, int col, int row)
-{
-	GList *list;
-
-	for (list = sheet->selections; list; list = list->next){
-		Range const *ss = list->data;
-
-		if (range_contains (ss, col, row))
-			return TRUE;
-	}
-	return FALSE;
-}
-
-void
-sheet_selection_redraw (Sheet const *sheet)
-{
-	GList *sel;
-
-	for (sel = sheet->selections; sel; sel = sel->next){
-		Range const *r = sel->data;
-
-		SHEET_FOREACH_CONTROL (sheet, control,
-			sc_redraw_region (control,
-				r->start.col, r->start.row,
-				r->end.col, r->end.row);
-			sc_redraw_headers (control, TRUE, TRUE, r););
-	}
-}
-
-/*
- * TRUE : If the range overlaps with any part of the selection
- */
-gboolean
-sheet_is_range_selected (Sheet const *sheet, Range const *r)
-{
-	GList *list;
-
-	for (list = sheet->selections; list; list = list->next){
-		Range const *ss = list->data;
-
-		if (range_overlap (ss, r))
-			return TRUE;
-	}
-	return FALSE;
-}
-
-/*
- * TRUE : If entire range is contained in the selection
- */
-gboolean
-sheet_is_full_range_selected (Sheet const *sheet, Range const *r)
-{
-	GList *list;
-
-	for (list = sheet->selections; list; list = list->next){
-		Range const *ss = list->data;
-
-		if (range_contained (r, ss))
-			return TRUE;
-	}
-	return FALSE;
-}
-
 static void
-sheet_selection_set_internal (Sheet *sheet,
-			      int edit_col, int edit_row,
+sheet_selection_set_internal (SheetView *sv,
+			      CellPos const *edit,
 			      int base_col, int base_row,
 			      int move_col, int move_row,
 			      gboolean just_add_it)
@@ -236,8 +409,7 @@ sheet_selection_set_internal (Sheet *sheet,
 	Range old_sel, new_sel;
 	gboolean do_cols, do_rows;
 
-	g_return_if_fail (IS_SHEET (sheet));
-	g_return_if_fail (sheet->selections != NULL);
+	g_return_if_fail (sv->selections != NULL);
 
 	new_sel.start.col = MIN(base_col, move_col);
 	new_sel.start.row = MIN(base_row, move_row);
@@ -246,8 +418,9 @@ sheet_selection_set_internal (Sheet *sheet,
 
 	g_return_if_fail (range_is_sane (&new_sel));
 
-	sheet_merge_find_container (sheet, &new_sel);
-	ss = (Range *)sheet->selections->data;
+	if (sv->sheet != NULL) /* beware initialization */
+		sheet_merge_find_container (sv->sheet, &new_sel);
+	ss = (Range *)sv->selections->data;
 	if (!just_add_it && range_equal (ss, &new_sel))
 		return;
 
@@ -255,14 +428,13 @@ sheet_selection_set_internal (Sheet *sheet,
 	*ss = new_sel;
 
 	/* Set the cursor boundary */
-	sheet_cursor_set (sheet,
-			  edit_col, edit_row,
-			  base_col, base_row,
-			  move_col, move_row, ss);
+	sv_cursor_set (sv, edit,
+		base_col, base_row,
+		move_col, move_row, ss);
 
 	if (just_add_it) {
-		sheet_redraw_range (sheet, &new_sel);
-		sheet_redraw_headers (sheet, TRUE, TRUE, &new_sel);
+		sv_redraw_range	(sv, &new_sel);
+		sv_redraw_headers (sv, TRUE, TRUE, &new_sel);
 		goto set_menu_flags;
 	}
 
@@ -274,22 +446,19 @@ sheet_selection_set_internal (Sheet *sheet,
 		 */
 		ranges = range_fragment (&old_sel, &new_sel);
 
-		for (l = ranges->next; l; l = l->next){
-			Range *range = l->data;
-
-			sheet_redraw_range (sheet, range);
-		}
+		for (l = ranges->next; l; l = l->next)
+			sv_redraw_range	(sv, l->data);
 		range_fragment_free (ranges);
 	} else {
-		sheet_redraw_range (sheet, &old_sel);
-		sheet_redraw_range (sheet, &new_sel);
+		sv_redraw_range (sv, &old_sel);
+		sv_redraw_range (sv, &new_sel);
 	}
 
 	/* Has the entire row been selected/unselected */
 	if ((new_sel.start.row == 0 && new_sel.end.row == SHEET_MAX_ROWS-1) ^
 	    (old_sel.start.row == 0 && old_sel.end.row == SHEET_MAX_ROWS-1)) {
 		Range tmp = range_union (&new_sel, &old_sel);
-		sheet_redraw_headers (sheet, TRUE, FALSE, &tmp);
+		sv_redraw_headers (sv, TRUE, FALSE, &tmp);
 	} else {
 		Range tmp = new_sel;
 		int diff;
@@ -303,7 +472,7 @@ sheet_selection_set_internal (Sheet *sheet,
 				tmp.end.col = old_sel.start.col;
 				tmp.start.col = new_sel.start.col;
 			}
-			sheet_redraw_headers (sheet, TRUE, FALSE, &tmp);
+			sv_redraw_headers (sv, TRUE, FALSE, &tmp);
 		}
 		diff = new_sel.end.col - old_sel.end.col;
 		if (diff != 0) {
@@ -314,7 +483,7 @@ sheet_selection_set_internal (Sheet *sheet,
 				tmp.end.col = old_sel.end.col;
 				tmp.start.col = new_sel.end.col;
 			}
-			sheet_redraw_headers (sheet, TRUE, FALSE, &tmp);
+			sv_redraw_headers (sv, TRUE, FALSE, &tmp);
 		}
 	}
 
@@ -322,7 +491,7 @@ sheet_selection_set_internal (Sheet *sheet,
 	if ((new_sel.start.col == 0 && new_sel.end.col == SHEET_MAX_COLS-1) ^
 	    (old_sel.start.col == 0 && old_sel.end.col == SHEET_MAX_COLS-1)) {
 		Range tmp = range_union (&new_sel, &old_sel);
-		sheet_redraw_headers (sheet, FALSE, TRUE, &tmp);
+		sv_redraw_headers (sv, FALSE, TRUE, &tmp);
 	} else {
 		Range tmp = new_sel;
 		int diff;
@@ -336,7 +505,7 @@ sheet_selection_set_internal (Sheet *sheet,
 				tmp.end.row = old_sel.start.row;
 				tmp.start.row = new_sel.start.row;
 			}
-			sheet_redraw_headers (sheet, FALSE, TRUE, &tmp);
+			sv_redraw_headers (sv, FALSE, TRUE, &tmp);
 		}
 
 		diff = new_sel.end.row - old_sel.end.row;
@@ -348,12 +517,12 @@ sheet_selection_set_internal (Sheet *sheet,
 				tmp.end.row = old_sel.end.row;
 				tmp.start.row = new_sel.end.row;
 			}
-			sheet_redraw_headers (sheet, FALSE, TRUE, &tmp);
+			sv_redraw_headers (sv, FALSE, TRUE, &tmp);
 		}
 	}
-	
+
 set_menu_flags:
-	sheet_flag_selection_change (sheet);
+	sv_flag_selection_change (sv);
 
 	/*
 	 * Now see if there is some selection which selects a
@@ -361,7 +530,7 @@ set_menu_flags:
 	 * insert row/cols and the flags accordingly.
 	 */
 	do_rows = do_cols = TRUE;
-	for (list = sheet->selections; list && (do_cols || do_rows); list = list->next) {
+	for (list = sv->selections; list && (do_cols || do_rows); list = list->next) {
 		Range const *r = list->data;
 
 		if (do_cols && range_is_full (r, TRUE))
@@ -369,7 +538,7 @@ set_menu_flags:
 		if (do_rows && range_is_full (r, FALSE))
 			do_rows = FALSE;
 	}
-	sheet_menu_state_enable_insert (sheet, do_cols, do_rows);
+	sv_menu_enable_insert (sv, do_cols, do_rows);
 
 	/*
 	 * FIXME: Enable/disable the show/hide detail menu items here.
@@ -389,19 +558,17 @@ set_menu_flags:
 }
 
 void
-sheet_selection_set (Sheet *sheet,
-		     int edit_col, int edit_row,
-		     int base_col, int base_row,
-		     int move_col, int move_row)
+sv_selection_set (SheetView *sv, CellPos const *edit,
+		  int base_col, int base_row,
+		  int move_col, int move_row)
 {
-	sheet_selection_set_internal (sheet,
-				      edit_col, edit_row,
-				      base_col, base_row,
-				      move_col, move_row, FALSE);
+	sheet_selection_set_internal (sv, edit,
+		base_col, base_row,
+		move_col, move_row, FALSE);
 }
 
 /**
- * sheet_selection_add_range : prepends a new range to the selection list.
+ * sv_selection_add_range : prepends a new range to the selection list.
  *
  * @sheet          : sheet whose selection to append to.
  * @edit_{col,row} : cell to mark as the new edit cursor.
@@ -411,124 +578,81 @@ sheet_selection_set (Sheet *sheet,
  * Prepends a range to the selection list and set the edit cursor.
  */
 void
-sheet_selection_add_range (Sheet *sheet,
-			   int edit_col, int edit_row,
-			   int base_col, int base_row,
-			   int move_col, int move_row)
+sv_selection_add_range (SheetView *sv,
+			 int edit_col, int edit_row,
+			 int base_col, int base_row,
+			 int move_col, int move_row)
 {
 	Range *ss;
+	CellPos edit;
 
-	g_return_if_fail (IS_SHEET (sheet));
+	g_return_if_fail (IS_SHEET_VIEW (sv));
 
 	/* Create and prepend new selection */
 	ss = g_new0 (Range, 1);
-	sheet->selections = g_list_prepend (sheet->selections, ss);
-	sheet_selection_set_internal (sheet,
-				      edit_col, edit_row,
-				      base_col, base_row,
-				      move_col, move_row, TRUE);
+	sv->selections = g_list_prepend (sv->selections, ss);
+	edit.col = edit_col;
+	edit.row = edit_row;
+	sheet_selection_set_internal (sv, &edit,
+		base_col, base_row,
+		move_col, move_row, TRUE);
 }
 
 void
-sheet_selection_add (Sheet *sheet, int col, int row)
+sv_selection_add_pos (SheetView *sv, int col, int row)
 {
-	sheet_selection_add_range (sheet, col, row, col, row, col, row);
+	sv_selection_add_range (sv, col, row, col, row, col, row);
 }
 
 /**
- * sheet_selection_free
- * @sheet: the sheet
+ * sv_selection_free
+ * @sv: the sheet
  *
  * Releases the selection associated with this sheet
  */
 void
-sheet_selection_free (Sheet *sheet)
+sv_selection_free (SheetView *sv)
 {
 	GList *list;
 
-	for (list = sheet->selections; list; list = list->next){
-		Range *ss = list->data;
-		g_free (ss);
-	}
-
-	g_list_free (sheet->selections);
-	sheet->selections = NULL;
+	for (list = sv->selections; list; list = list->next)
+		g_free (list->data);
+	g_list_free (sv->selections);
+	sv->selections = NULL;
 }
 
 /*
- * sheet_selection_reset
- * sheet:  The sheet
+ * sv_selection_reset :
+ * @sv:  The sheet view
  *
  * Clears all of the selection ranges.
- * WARNING: This does not set a new selection this should
- * be taken care on the calling routine.
+ *
+ * WARNING: This does not set a new selection and leaves the view in an
+ * 		INVALID STATE.
  */
 void
-sheet_selection_reset (Sheet *sheet)
+sv_selection_reset (SheetView *sv)
 {
 	GList *list, *tmp;
 
-	g_return_if_fail (IS_SHEET (sheet));
+	g_return_if_fail (IS_SHEET_VIEW (sv));
 
 	/* Empty the sheets selection */
-	list = sheet->selections;
-	sheet->selections = NULL;
+	list = sv->selections;
+	sv->selections = NULL;
 
 	/* Redraw the grid, & headers for each region */
 	for (tmp = list; tmp; tmp = tmp->next){
 		Range *ss = tmp->data;
-
-		sheet_redraw_range (sheet, ss);
-		sheet_redraw_headers (sheet, TRUE, TRUE, ss);
+		sv_redraw_range (sv, ss);
+		sv_redraw_headers (sv, TRUE, TRUE, ss);
 		g_free (ss);
 	}
 
 	g_list_free (list);
 
 	/* Make sure we re-enable the insert col/row and cell menu items */
-	sheet_menu_state_enable_insert (sheet, TRUE, TRUE);
-}
-
-gboolean
-sheet_selection_copy (WorkbookControl *wbc, Sheet *sheet)
-{
-	Range const *sel;
-
-	if (!(sel = selection_first_range (sheet, wbc, _("Copy"))))
-		return FALSE;
-
-	application_clipboard_cut_copy (wbc, FALSE, sheet, sel, TRUE);
-
-	return TRUE;
-}
-
-gboolean
-sheet_selection_cut (WorkbookControl *wbc, Sheet *sheet)
-{
-	Range const *sel;
-
-	/*
-	 * 'cut' is a poor description of what we're
-	 * doing here.  'move' would be a better
-	 * approximation.  The key portion of this process is that
-	 * the range being moved has all
-	 * 	- references to it adjusted to the new site.
-	 * 	- relative references from it adjusted.
-	 *
-	 * NOTE : This command DOES NOT MOVE ANYTHING !
-	 *        We only store the src, paste does the move.
-	 */
-	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
-
-	if (!(sel = selection_first_range (sheet, wbc, _("Cut"))))
-		return FALSE;
-
-	if (sheet_range_splits_region (sheet, sel, NULL, wbc, _("Cut")))
-		return FALSE;
-
-	application_clipboard_cut_copy (wbc, TRUE, sheet, sel, TRUE);
-
-	return TRUE;
+	sv_menu_enable_insert (sv, TRUE, TRUE);
 }
 
 /**
@@ -537,7 +661,7 @@ sheet_selection_cut (WorkbookControl *wbc, Sheet *sheet)
  * @allow_intersection : Divide the selection into nonoverlapping subranges.
  */
 GSList *
-selection_get_ranges (Sheet const *sheet, gboolean allow_intersection)
+selection_get_ranges (SheetView const *sv, gboolean allow_intersection)
 {
 	GList  *l;
 	GSList *proposed = NULL;
@@ -552,7 +676,7 @@ selection_get_ranges (Sheet const *sheet, gboolean allow_intersection)
 	 * the proposed regions overlap.  Start the search with the
 	 * single user proposed segment and accumulate distict regions.
 	 */
-	for (l = sheet->selections; l != NULL; l = l->next) {
+	for (l = sv->selections; l != NULL; l = l->next) {
 		Range const *r = l->data;
 
 		/* The set of regions that do not interset with b or
@@ -820,7 +944,7 @@ selection_get_ranges (Sheet const *sheet, gboolean allow_intersection)
 
 /**
  * selection_apply:
- * @sheet: the sheet.
+ * @sv: the sheet.
  * @func:  The function to apply.
  * @allow_intersection : Call the routine for the non-intersecting subregions.
  * @closure : A parameter to pass to each invocation of @func.
@@ -830,23 +954,23 @@ selection_get_ranges (Sheet const *sheet, gboolean allow_intersection)
  * than the smaller system created non-intersection regions.
  */
 void
-selection_apply (Sheet *sheet, SelectionApplyFunc const func,
+selection_apply (SheetView *sv, SelectionApplyFunc const func,
 		 gboolean allow_intersection,
 		 void * closure)
 {
 	GList *l;
 	GSList *proposed = NULL;
 
-	g_return_if_fail (IS_SHEET (sheet));
+	g_return_if_fail (IS_SHEET_VIEW (sv));
 
 	if (allow_intersection) {
-		for (l = sheet->selections; l != NULL; l = l->next) {
+		for (l = sv->selections; l != NULL; l = l->next) {
 			Range const *ss = l->data;
 
-			(*func) (sheet, ss, closure);
+			(*func) (sv, ss, closure);
 		}
 	} else {
-		proposed = selection_get_ranges (sheet, allow_intersection);
+		proposed = selection_get_ranges (sv, allow_intersection);
 		while (proposed != NULL) {
 			/* pop the 1st element off the list */
 			Range *r = proposed->data;
@@ -856,7 +980,7 @@ selection_apply (Sheet *sheet, SelectionApplyFunc const func,
 			range_dump (r, "\n");
 #endif
 
-			(*func) (sheet, r, closure);
+			(*func) (sv, r, closure);
 			g_free (r);
 		}
 	}
@@ -869,7 +993,7 @@ typedef struct
 } selection_to_string_closure;
 
 static void
-cb_range_to_string (Sheet *sheet, Range const *r, void *closure)
+cb_range_to_string (SheetView *sv, Range const *r, void *closure)
 {
 	selection_to_string_closure * res = closure;
 
@@ -877,7 +1001,7 @@ cb_range_to_string (Sheet *sheet, Range const *r, void *closure)
 		g_string_append_c (res->str, ',');
 
 	if (res->include_sheet_name_prefix)
-		g_string_sprintfa (res->str, "%s!", sheet->name_quoted);
+		g_string_sprintfa (res->str, "%s!", sv->sheet->name_quoted);
 
 	g_string_sprintfa (res->str, "$%s$%s",
 			   col_name (r->start.col), row_name (r->start.row));
@@ -887,7 +1011,7 @@ cb_range_to_string (Sheet *sheet, Range const *r, void *closure)
 }
 
 char *
-selection_to_string (Sheet *sheet, gboolean include_sheet_name_prefix)
+selection_to_string (SheetView *sv, gboolean include_sheet_name_prefix)
 {
 	char    *output;
 	selection_to_string_closure res;
@@ -896,54 +1020,18 @@ selection_to_string (Sheet *sheet, gboolean include_sheet_name_prefix)
 	res.include_sheet_name_prefix = include_sheet_name_prefix;
 
 	/* selection_apply will check all necessary invariants. */
-	selection_apply (sheet, &cb_range_to_string, TRUE, &res);
+	selection_apply (sv, &cb_range_to_string, TRUE, &res);
 
 	output = res.str->str;
 	g_string_free (res.str, FALSE);
 	return output;
 }
 
-/*
- * selection_contains_colrow :
- * @sheet : containing the selection
- * @colrow: The column or row number we are interested in.
- * @is_col: A flag indicating whether this it is a column or a row.
- *
- * Searches the selection list to see whether the entire col/row specified is
- * contained by the section regions.  Since the selection is stored as the set
- * overlapping user specifed regions we can safely search for the range directly.
- *
- * Eventually to be completely correct and deal with the case of someone manually
- * selection an entire col/row, in separate chunks,  we will need to do something
- * more advanced.
- */
-gboolean
-selection_contains_colrow (Sheet const *sheet, int colrow, gboolean is_col)
-{
-	GList *l;
-	for (l = sheet->selections; l != NULL; l = l->next) {
-		Range const *ss = l->data;
-
-		if (is_col) {
-			if (ss->start.row == 0 &&
-			    ss->end.row >= SHEET_MAX_ROWS-1 &&
-			    ss->start.col <= colrow && colrow <= ss->end.col)
-				return TRUE;
-		} else {
-			if (ss->start.col == 0 &&
-			    ss->end.col >= SHEET_MAX_COLS-1 &&
-			    ss->start.row <= colrow && colrow <= ss->end.row)
-				return TRUE;
-		}
-	}
-	return FALSE;
-}
-
 /**
  * selection_foreach_range :
- * @sheet : The whose selection is being iterated.
+ * @sv : The whose selection is being iterated.
  * @from_start : Iterate from start to end or end to start.
- * @range_cb : A function to call for each sheet.
+ * @range_cb : A function to call for each selected range.
  * @user_data :
  *
  * Iterate through the ranges in a selection.
@@ -951,26 +1039,26 @@ selection_contains_colrow (Sheet const *sheet, int colrow, gboolean is_col)
  * selection list.  This can be changed in the future if it is a requirement.
  */
 gboolean
-selection_foreach_range (Sheet *sheet, gboolean from_start,
-			 gboolean (*range_cb) (Sheet *sheet,
+selection_foreach_range (SheetView *sv, gboolean from_start,
+			 gboolean (*range_cb) (SheetView *sv,
 					       Range const *range,
 					       gpointer user_data),
 			 gpointer user_data)
 {
 	GList *l;
 
-	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
+	g_return_val_if_fail (IS_SHEET_VIEW (sv), FALSE);
 
 	if (from_start)
-		for (l = sheet->selections; l != NULL; l = l->next) {
+		for (l = sv->selections; l != NULL; l = l->next) {
 			Range *ss = l->data;
-			if (!range_cb (sheet, ss, user_data))
+			if (!range_cb (sv, ss, user_data))
 				return FALSE;
 		}
 	else
-		for (l = g_list_last (sheet->selections); l != NULL; l = l->prev) {
+		for (l = g_list_last (sv->selections); l != NULL; l = l->prev) {
 			Range *ss = l->data;
-			if (!range_cb (sheet, ss, user_data))
+			if (!range_cb (sv, ss, user_data))
 				return FALSE;
 		}
 	return TRUE;
@@ -979,7 +1067,7 @@ selection_foreach_range (Sheet *sheet, gboolean from_start,
 /*
  * walk_boundaries : Iterates through a region by row then column.
  *
- * @sheet : The sheet being iterated in
+ * @sv : The sheet being iterated in
  * @bound : The bounding range
  * @forward : iterate forward or backwards
  * @horizontal : across then down
@@ -989,18 +1077,18 @@ selection_foreach_range (Sheet *sheet, gboolean from_start,
  * returns TRUE if the cursor leaves the boundary region.
  */
 static gboolean
-walk_boundaries (Sheet const *sheet, Range const * const bound,
+walk_boundaries (SheetView const *sv, Range const * const bound,
 		 gboolean const forward, gboolean const horizontal,
 		 gboolean const smart_merge, CellPos * const res)
 {
 	ColRowInfo const *cri;
 	int const step = forward ? 1 : -1;
-	CellPos pos = sheet->edit_pos_real;
+	CellPos pos = sv->edit_pos_real;
 	Range const *merge;
 
 	*res = pos;
 loop :
-	merge = sheet_merge_contains_pos (sheet, &pos);
+	merge = sheet_merge_contains_pos (sv->sheet, &pos);
 	if (horizontal) {
 		if (merge != NULL)
 			pos.col = (forward) ? merge->end.col : merge->start.col;
@@ -1033,15 +1121,15 @@ loop :
 			pos.row += step;
 	}
 
-	cri = sheet_col_get (sheet, pos.col);
+	cri = sheet_col_get (sv->sheet, pos.col);
 	if (cri != NULL && !cri->visible)
 		goto loop;
-	cri = sheet_row_get (sheet, pos.row);
+	cri = sheet_row_get (sv->sheet, pos.row);
 	if (cri != NULL && !cri->visible)
 		goto loop;
 
 	if (smart_merge) {
-		merge = sheet_merge_contains_pos (sheet, &pos);
+		merge = sheet_merge_contains_pos (sv->sheet, &pos);
 		if (merge != NULL) {
 			if (forward) {
 				if (pos.col != merge->start.col ||
@@ -1064,20 +1152,20 @@ loop :
 }
 
 void
-sheet_selection_walk_step (Sheet *sheet,
-			   gboolean forward,
-			   gboolean horizontal)
+sv_selection_walk_step (SheetView *sv,
+			gboolean forward,
+			gboolean horizontal)
 {
 	int selections_count;
 	CellPos destination;
 	Range const *ss;
 	gboolean is_singleton = FALSE;
 
-	g_return_if_fail (IS_SHEET (sheet));
-	g_return_if_fail (sheet->selections != NULL);
+	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (sv->selections != NULL);
 
-	ss = sheet->selections->data;
-	selections_count = g_list_length (sheet->selections);
+	ss = sv->selections->data;
+	selections_count = g_list_length (sv->selections);
 
 	/* If there is no selection besides the cursor
 	 * iterate through the entire sheet.  Move the
@@ -1088,15 +1176,15 @@ sheet_selection_walk_step (Sheet *sheet,
 		if (ss->start.col == ss->end.col &&
 		    ss->start.row == ss->end.row)
 			is_singleton = TRUE;
-		else if (ss->start.col == sheet->edit_pos.col &&
-			 ss->start.row == sheet->edit_pos.row) {
-			Range const *merge = sheet_merge_is_corner (sheet,
-				&sheet->edit_pos);
+		else if (ss->start.col == sv->edit_pos.col &&
+			 ss->start.row == sv->edit_pos.row) {
+			Range const *merge = sheet_merge_is_corner (sv->sheet,
+				&sv->edit_pos);
 			if (merge != NULL && range_equal (merge, ss))
 				is_singleton = TRUE;
 		}
 	}
-			
+
 	if (is_singleton) {
 		Range full_sheet;
 		if (horizontal) {
@@ -1112,135 +1200,42 @@ sheet_selection_walk_step (Sheet *sheet,
 		}
 
 		/* Ignore attempts to move outside the boundary region */
-		if (!walk_boundaries (sheet, &full_sheet, forward, horizontal,
+		if (!walk_boundaries (sv, &full_sheet, forward, horizontal,
 				      FALSE, &destination)) {
-			sheet_selection_set (sheet,
-					     destination.col, destination.row,
-					     destination.col, destination.row,
-					     destination.col, destination.row);
-			sheet_make_cell_visible (sheet, sheet->edit_pos.col,
-						 sheet->edit_pos.row, TRUE);
+			sv_selection_set (sv, &destination,
+					  destination.col, destination.row,
+					  destination.col, destination.row);
+			sv_make_cell_visible (sv, sv->edit_pos.col,
+					      sv->edit_pos.row, TRUE);
 		}
 		return;
 	}
 
-	if (walk_boundaries (sheet, ss, forward, horizontal,
+	if (walk_boundaries (sv, ss, forward, horizontal,
 			     TRUE, &destination)) {
 		if (forward) {
-			GList *tmp = g_list_last (sheet->selections);
-			sheet->selections =
+			GList *tmp = g_list_last (sv->selections);
+			sv->selections =
 			    g_list_concat (tmp,
-					   g_list_remove_link (sheet->selections,
+					   g_list_remove_link (sv->selections,
 							       tmp));
-			ss = sheet->selections->data;
+			ss = sv->selections->data;
 			destination = ss->start;
 		} else {
-			GList *tmp = sheet->selections;
-			sheet->selections =
-			    g_list_concat (g_list_remove_link (sheet->selections,
+			GList *tmp = sv->selections;
+			sv->selections =
+			    g_list_concat (g_list_remove_link (sv->selections,
 							       tmp),
 					   tmp);
-			ss = sheet->selections->data;
+			ss = sv->selections->data;
 			destination = ss->end;
 		}
 		if (selections_count != 1)
-			sheet_cursor_set (sheet,
-					  destination.col, destination.row,
-					  ss->start.col, ss->start.row,
-					  ss->end.col, ss->end.row, NULL);
+			sv_cursor_set (sv, &destination,
+				       ss->start.col, ss->start.row,
+				       ss->end.col, ss->end.row, NULL);
 	}
 
-	sheet_set_edit_pos (sheet, destination.col, destination.row);
-	sheet_make_cell_visible (sheet, destination.col, destination.row, TRUE);
-}
-
-ColRowSelectionType
-sheet_col_selection_type (Sheet const *sheet, int col)
-{
-	GList *l;
-	int ret = COL_ROW_NO_SELECTION;
-
-	g_return_val_if_fail (IS_SHEET (sheet), COL_ROW_NO_SELECTION);
-
-	if (sheet->selections == NULL)
-		return COL_ROW_NO_SELECTION;
-
-	for (l = sheet->selections; l != NULL; l = l->next){
-		Range *ss = l->data;
-
-		if (ss->start.col > col ||
-		    ss->end.col < col)
-			continue;
-
-		if (ss->start.row == 0 &&
-		    ss->end.row == SHEET_MAX_ROWS-1)
-			return COL_ROW_FULL_SELECTION;
-
-		ret = COL_ROW_PARTIAL_SELECTION;
-	}
-
-	return ret;
-}
-
-ColRowSelectionType
-sheet_row_selection_type (Sheet const *sheet, int row)
-{
-	GList *l;
-	int ret = COL_ROW_NO_SELECTION;
-
-	g_return_val_if_fail (IS_SHEET (sheet), COL_ROW_NO_SELECTION);
-
-	if (sheet->selections == NULL)
-		return COL_ROW_NO_SELECTION;
-
-	for (l = sheet->selections; l != NULL; l = l->next) {
-		Range *ss = l->data;
-
-		if (ss->start.row > row ||
-		    ss->end.row < row)
-			continue;
-
-		if (ss->start.col == 0 &&
-		    ss->end.col == SHEET_MAX_COLS-1)
-			return COL_ROW_FULL_SELECTION;
-
-		ret = COL_ROW_PARTIAL_SELECTION;
-	}
-
-	return ret;
-}
-
-/**
- * sheet_selection_full_cols :
- * @sheet :
- * @is_cols :
- * @index :
- *
- * returns TRUE if all of the selected cols/rows in the selection
- * 	are fully selected and the selection contains the specified col.
- */
-gboolean
-sheet_selection_full_cols_rows (Sheet const *sheet, gboolean is_cols, int index)
-{
-	GList *l;
-	gboolean found = FALSE;
-
-	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
-
-	for (l = sheet->selections; l != NULL; l = l->next){
-		Range const *r = l->data;
-		if (is_cols) {
-			if (r->start.row > 0 || r->end.row < SHEET_MAX_ROWS - 1)
-				return FALSE;
-			if (r->start.col <= index && index <= r->end.col)
-				found = TRUE;
-		} else {
-			if (r->start.col > 0 || r->end.col < SHEET_MAX_COLS - 1)
-				return FALSE;
-			if (r->start.row <= index && index <= r->end.row)
-				found = TRUE;
-		}
-	}
-
-	return found;
+	sv_set_edit_pos (sv, &destination);
+	sv_make_cell_visible (sv, destination.col, destination.row, TRUE);
 }
