@@ -24,9 +24,9 @@
 #include "gnumeric.h"
 #include "sheet-control-priv.h"
 
-#include <gal/util/e-util.h>
+#include <gsf/gsf-impl-utils.h>
 
-#define SC_CLASS(o) SHEET_CONTROL_CLASS ((o)->object.klass)
+#define SC_CLASS(o) SHEET_CONTROL_CLASS (G_OBJECT_GET_CLASS (o))
 #define SC_VIRTUAL_FULL(func, handle, arglist, call)		\
 void sc_ ## func arglist				        \
 {								\
@@ -42,25 +42,25 @@ void sc_ ## func arglist				        \
 
 /*****************************************************************************/
 
-static GtkObjectClass *parent_class;
+static GObjectClass *parent_class;
 
 static void
-sc_destroy (GtkObject *obj)
+sc_finalize (GObject *obj)
 {
 	/* Commented out until needed */
-	/* SheetControl *sc = SHEET_CONTROL (obj); */ 
-	GTK_OBJECT_CLASS (parent_class)->destroy (obj);
+	/* SheetControl *sc = SHEET_CONTROL (obj); */
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
-sc_class_init (GtkObjectClass *object_class)
+sc_class_init (GObjectClass *object_class)
 {
-	parent_class = gtk_type_class (gtk_object_get_type ());
-	object_class->destroy = sc_destroy;
+	parent_class = g_type_class_peek (G_TYPE_OBJECT);
+	object_class->finalize = sc_finalize;
 }
 
-E_MAKE_TYPE (sheet_control, "SheetControl", SheetControl,
-	     sc_class_init, NULL, GTK_TYPE_OBJECT);
+GSF_CLASS (SheetControl, sheet_control,
+	   sc_class_init, NULL, G_TYPE_OBJECT);
 
 WorkbookControl *
 sc_wbc (SheetControl const *sc)
@@ -76,11 +76,11 @@ sc_sheet (SheetControl const *sc)
 	return sc->sheet;
 }
 
-void
-sc_sheet_set (SheetControl *sc, Sheet *sheet)
+SheetView *
+sc_view (SheetControl const *sc)
 {
-	g_return_if_fail (IS_SHEET_CONTROL (sc));
-	sc->sheet = sheet;
+	g_return_val_if_fail (IS_SHEET_CONTROL (sc), NULL);
+	return sc->view;
 }
 
 SC_VIRTUAL (resize, (SheetControl *sc, gboolean force_scroll), (sc, force_scroll))
@@ -88,10 +88,9 @@ SC_VIRTUAL (resize, (SheetControl *sc, gboolean force_scroll), (sc, force_scroll
 SC_VIRTUAL (set_zoom_factor, (SheetControl *sc), (sc))
 
 SC_VIRTUAL (redraw_all, (SheetControl *sc, gboolean headers), (sc, headers))
-SC_VIRTUAL (redraw_region,
-	    (SheetControl *sc,
-	     int start_col, int start_row, int end_col, int end_row),
-	    (sc, start_col, start_row, end_col, end_row))
+SC_VIRTUAL (redraw_range,
+	    (SheetControl *sc, Range const *r),
+	    (sc, r))
 SC_VIRTUAL (redraw_headers,
 	    (SheetControl *sc,
 	     gboolean const col, gboolean const row, Range const * r),
@@ -119,6 +118,9 @@ SC_VIRTUAL (make_cell_visible,
 SC_VIRTUAL (cursor_bound, (SheetControl *sc, Range const *r), (sc, r))
 SC_VIRTUAL (set_panes, (SheetControl *sc), (sc))
 
+SC_VIRTUAL (object_create_view,	(SheetControl *sc, SheetObject *so), (sc, so));
+SC_VIRTUAL (object_destroy_view, (SheetControl *sc, SheetObject *so), (sc, so));
+
 float
 sc_colrow_distance_get (SheetControl const *sc, gboolean is_col,
 			int start, int end)
