@@ -30,7 +30,9 @@
 #include <libgnome/gnome-i18n.h>
 #include <gtk/gtkimagemenuitem.h>
 #include <gtk/gtkstock.h>
-#include <gal/util/e-util.h>
+#include <gsf/gsf-impl-utils.h>
+
+#include <string.h>
 
 /* Returns the class for a SheetObject */
 #define SO_CLASS(so) SHEET_OBJECT_CLASS(G_OBJECT_GET_CLASS(so))
@@ -281,9 +283,9 @@ sheet_object_class_init (GObjectClass *object_class)
 	sheet_object_class->default_height_pts = 36.;	/* 1/2 inch */
 }
 
-E_MAKE_TYPE (sheet_object, "SheetObject", SheetObject,
-	     sheet_object_class_init, sheet_object_init,
-	     G_TYPE_OBJECT);
+GSF_CLASS (SheetObject, sheet_object,
+	   sheet_object_class_init, sheet_object_init,
+	   G_TYPE_OBJECT);
 
 SheetObject *
 sheet_object_view_obj (GObject *view)
@@ -396,7 +398,7 @@ sheet_object_set_sheet (SheetObject *so, Sheet *sheet)
 
 	g_object_ref (G_OBJECT (so));
 	sheet->sheet_objects = g_list_prepend (sheet->sheet_objects, so);
-	SHEET_FOREACH_CONTROL (so->sheet, control,
+	SHEET_FOREACH_CONTROL (so->sheet, view, control,
 		sc_object_create_view (control, so););
 	sheet_object_update_bounds (so, NULL);
 
