@@ -299,6 +299,14 @@ w_lp_solve_get_dual (SolverProgram program, int row)
         return lp->p->duals [row + 1];
 }
 
+static int
+w_lp_solve_get_iterations (SolverProgram program)
+{
+	lp_solve_t *lp = (lp_solve_t *) program;
+
+        return lp->p->total_iter;
+}
+
 static gboolean
 w_lp_solve_set_option (SolverProgram program, SolverOptionType option,
 		       const gboolean *b_value,
@@ -546,6 +554,12 @@ w_glpk_get_dual (SolverProgram program, int row)
 	return x;
 }
 
+static int
+w_glpk_get_iterations (SolverProgram program)
+{
+        return -1;
+}
+
 gboolean
 w_glpk_set_option (SolverProgram program, SolverOptionType option,
 		   const gboolean *b_value,
@@ -617,20 +631,20 @@ w_qp_dummy_set_minim (SolverProgram program)
 static void
 w_qp_dummy_set_obj_fn (SolverProgram program, int col, gnum_float value)
 {
-        printf ("w_qp_dummy_set_obj_fn %d, %g\n", col, value);
+        printf ("w_qp_dummy_set_obj_fn %d, %" GNUM_FORMAT_g "\n", col, value);
 }
 
 static void
 w_qp_dummy_set_constr_mat (SolverProgram program, int col, int row, gnum_float value)
 {
-        printf ("w_qp_dummy_set_constr_mat %d, %d, %g\n", col, row, value);
+        printf ("w_qp_dummy_set_constr_mat %d, %d, %" GNUM_FORMAT_g "\n", col, row, value);
 }
 
 static void
 w_qp_dummy_set_constr (SolverProgram program, int row, SolverConstraintType type,
 		   gnum_float value)
 {
-        printf ("w_qp_dummy_set_constr %d, %d, %g\n", row, type, value);
+        printf ("w_qp_dummy_set_constr %d, %d, %" GNUM_FORMAT_g "\n", row, type, value);
 }
 
 static void
@@ -673,6 +687,12 @@ w_qp_dummy_get_dual (SolverProgram program, int row)
 	return 0;
 }
 
+static int
+w_qp_dummy_solver_lp_get_iterations (SolverProgram p)
+{
+	return 0;
+}
+
 static gboolean
 w_qp_dummy_set_option (SolverProgram program, SolverOptionType option,
 		   const gboolean *b_value,
@@ -712,6 +732,7 @@ const SolverLPAlgorithm lp_algorithm [] = {
 		(solver_lp_get_obj_fn_value_fn*) w_lp_solve_get_value_of_obj_fn,
 		(solver_lp_get_obj_fn_var_fn*)   w_lp_solve_get_solution,
 		(solver_lp_get_shadow_prize_fn*) w_lp_solve_get_dual,
+		(solver_lp_get_iterations_fn*)   w_lp_solve_get_iterations,
 		(solver_lp_set_option_fn*)       w_lp_solve_set_option,
 		(solver_lp_print_fn*)            w_lp_solve_print_lp
 	},
@@ -732,6 +753,7 @@ const SolverLPAlgorithm lp_algorithm [] = {
 		(solver_lp_get_obj_fn_value_fn*) w_glpk_get_value_of_obj_fn,
 		(solver_lp_get_obj_fn_var_fn*)   w_glpk_get_solution,
 		(solver_lp_get_shadow_prize_fn*) w_glpk_get_dual,
+		(solver_lp_get_iterations_fn*)   w_glpk_iterations,
 		(solver_lp_set_option_fn*)       w_glpk_set_option,
 		(solver_lp_print_fn*)            w_glpk_print_lp
 	},
@@ -756,6 +778,7 @@ const SolverLPAlgorithm qp_algorithm [] = {
 		(solver_lp_get_obj_fn_value_fn*) w_qp_dummy_get_value_of_obj_fn,
 		(solver_lp_get_obj_fn_var_fn*)   w_qp_dummy_get_solution,
 		(solver_lp_get_shadow_prize_fn*) w_qp_dummy_get_dual,
+		(solver_lp_get_iterations_fn *)  w_qp_dummy_solver_lp_get_iterations,
 		(solver_lp_set_option_fn*)       w_qp_dummy_set_option,
 		(solver_lp_print_fn*)            w_qp_dummy_print
 	},
