@@ -23,6 +23,7 @@
 #include "gnumeric.h"
 #include "workbook-control-priv.h"
 
+#include "application.h"
 #include "workbook-view.h"
 #include "workbook.h"
 #include "sheet.h"
@@ -32,7 +33,7 @@
 #include "ranges.h"
 #include "expr-name.h"
 
-#include <gal/util/e-util.h>
+#include <gsf/gsf-impl-utils.h>
 #include <libgnome/gnome-i18n.h>
 
 #define WBC_CLASS(o) WORKBOOK_CONTROL_CLASS (G_OBJECT_GET_CLASS (o))
@@ -73,9 +74,6 @@ WBC_VIRTUAL (edit_line_set,
 	(WorkbookControl *wbc, char const *text), (wbc, text))
 WBC_VIRTUAL (selection_descr_set,
 	(WorkbookControl *wbc, char const *text), (wbc, text))
-WBC_VIRTUAL_FULL (set_sensitive, set_sensitive,
-        (WorkbookControl *wbc, gboolean sensitive),
-	(wbc, sensitive))
 WBC_VIRTUAL (edit_set_sensitive,
 	(WorkbookControl *wbc,
 	 gboolean ok_cancel_flag, gboolean func_guru_flag),
@@ -110,8 +108,8 @@ WBC_VIRTUAL_FULL (undo_redo_labels, undo_redo.labels,
 WBC_VIRTUAL_FULL (menu_state_sheet_prefs, menu_state.sheet_prefs,
 	(WorkbookControl *wbc, Sheet const *sheet), (wbc, sheet))
 WBC_VIRTUAL_FULL (menu_state_update, menu_state.update,
-        (WorkbookControl *wbc, Sheet const *sheet, int flags),
-	(wbc, sheet, flags))
+        (WorkbookControl *wbc, int flags),
+	(wbc, flags))
 WBC_VIRTUAL_FULL (menu_state_sheet_count, menu_state.sheet_count,
 	(WorkbookControl *wbc), (wbc))
 
@@ -119,7 +117,7 @@ WBC_VIRTUAL (paste_from_selection,
 	(WorkbookControl *wbc, PasteTarget const *pt), (wbc, pt))
 
 void
-wb_control_sheet_add (WorkbookControl *wbc, Sheet *new_sheet)
+wb_control_sheet_add (WorkbookControl *wbc, SheetView *sv)
 {
 	WorkbookControlClass *wbc_class;
 
@@ -127,8 +125,9 @@ wb_control_sheet_add (WorkbookControl *wbc, Sheet *new_sheet)
 
 	wbc_class = WBC_CLASS (wbc);
 	if (wbc_class != NULL && wbc_class->sheet.add != NULL) {
+		Sheet *new_sheet = sv_sheet (sv);
 
-		wbc_class->sheet.add (wbc, new_sheet);
+		wbc_class->sheet.add (wbc, sv);
 
 		/* If this is the current sheet init the display */
 		if (new_sheet == wb_control_cur_sheet (wbc)) {
@@ -139,7 +138,7 @@ wb_control_sheet_add (WorkbookControl *wbc, Sheet *new_sheet)
 			wb_control_auto_expr_value (wbc);
 			wb_control_format_feedback (wbc);
 			wb_control_menu_state_sheet_prefs (wbc, new_sheet);
-			wb_control_menu_state_update (wbc, new_sheet, MS_ALL);
+			wb_control_menu_state_update (wbc, MS_ALL);
 		}
 	}
 }
@@ -178,36 +177,40 @@ wb_control_validation_msg (WorkbookControl *wbc, ValidationStyle v,
 }
 
 WorkbookView *
-wb_control_view (WorkbookControl *wbc)
+wb_control_view (WorkbookControl const *wbc)
 {
 	g_return_val_if_fail (IS_WORKBOOK_CONTROL (wbc), NULL);
-
 	return wbc->wb_view;
 }
 
 Workbook *
-wb_control_workbook (WorkbookControl *wbc)
+wb_control_workbook (WorkbookControl const *wbc)
 {
 	g_return_val_if_fail (IS_WORKBOOK_CONTROL (wbc), NULL);
-	g_return_val_if_fail (wbc->wb_view != NULL, NULL);
-
 	return wb_view_workbook (wbc->wb_view);
 }
 
 Sheet *
-wb_control_cur_sheet (WorkbookControl *wbc)
+wb_control_cur_sheet (WorkbookControl const *wbc)
 {
 	g_return_val_if_fail (IS_WORKBOOK_CONTROL (wbc), NULL);
-	g_return_val_if_fail (wbc->wb_view != NULL, NULL);
-
 	return wb_view_cur_sheet (wbc->wb_view);
 }
 
+SheetView *
+wb_control_cur_sheet_view (WorkbookControl const *wbc)
+{
+	g_return_val_if_fail (IS_WORKBOOK_CONTROL (wbc), NULL);
+	return wb_view_cur_sheet_view (wbc->wb_view);
+}
+
 gboolean
 wb_control_parse_and_jump (WorkbookControl *wbc, const char *text)
 {
 	RangeRef const *r;
+	CellPos tmp;
 	Sheet *sheet  = wb_control_cur_sheet (wbc);
+	SheetView *sv;
 	Value *target = global_range_parse (sheet, text);
 
 	/* not an address, is it a name ? */
@@ -218,7 +221,8 @@ wb_control_parse_and_jump (WorkbookControl *wbc, const char *text)
 
 		/* Not a name, create one */
 		if (nexpr == NULL) {
-			Range const *r = selection_first_range (sheet,  wbc,
+			Range const *r = selection_first_range (
+				wb_control_cur_sheet_view (wbc),  wbc,
 				_("Define Name"));
 			if (r != NULL) {
 				char const *err;
@@ -250,15 +254,23 @@ wb_control_parse_and_jump (WorkbookControl *wbc, const char *text)
 
 	r = &target->v_range.cell;
 	sheet = r->a.sheet;
-	sheet_selection_set (r->a.sheet, r->a.col, r->a.row,
-			     r->a.col, r->a.row, r->b.col, r->b.row);
-	sheet_make_cell_visible (sheet, r->a.col, r->a.row, FALSE);
+	sv = sheet_get_view (sheet, wb_control_view (wbc)),
+	tmp.col = r->a.col;
+	tmp.row = r->a.row;
+	sv_selection_set (sv, &tmp, r->a.col, r->a.row, r->b.col, r->b.row);
+	sv_make_cell_visible (sv, r->a.col, r->a.row, FALSE);
 	if (wb_control_cur_sheet (wbc) != sheet)
 		wb_view_sheet_focus (wbc->wb_view, sheet);
 	value_release (target);
 	return TRUE;
 }
 
+static void
+cb_wbc_clipboard_modified (GnumericApplication *app, WorkbookControl *wbc)
+{
+	wb_control_menu_state_update (wbc, MS_PASTE_SPECIAL);
+}
+
 /*****************************************************************************/
 
 static void
@@ -266,6 +278,10 @@ wbc_finalize (GObject *obj)
 {
 	GObjectClass *parent_class;
 	WorkbookControl *wbc = WORKBOOK_CONTROL (obj);
+	if (wbc->clipboard_changed_signal)
+		g_signal_handler_disconnect (gnumeric_application_get_app (), 
+					     wbc->clipboard_changed_signal);
+	wbc->clipboard_changed_signal = 0;
 	if (wbc->wb_view != NULL)
 		wb_view_detach_control (wbc);
 	parent_class = g_type_class_peek (COMMAND_CONTEXT_TYPE);
@@ -279,8 +295,20 @@ workbook_control_class_init (GObjectClass *object_class)
 	object_class->finalize = wbc_finalize;
 }
 
-E_MAKE_TYPE (workbook_control, "WorkbookControl", WorkbookControl,
-	     workbook_control_class_init, NULL, COMMAND_CONTEXT_TYPE);
+static void
+workbook_control_init (GObject *obj)
+{
+	WorkbookControl *wbc = WORKBOOK_CONTROL (obj);
+
+	wbc->clipboard_changed_signal = g_signal_connect (
+		gnumeric_application_get_app (),
+		"clipboard_modified",
+		G_CALLBACK (cb_wbc_clipboard_modified), wbc);
+}
+
+GSF_CLASS (WorkbookControl, workbook_control,
+	   workbook_control_class_init, workbook_control_init,
+	   COMMAND_CONTEXT_TYPE);
 
 void
 workbook_control_set_view (WorkbookControl *wbc,
@@ -299,6 +327,8 @@ void
 workbook_control_init_state (WorkbookControl *wbc)
 {
 	GList *sheets, *ptr;
+	Sheet *sheet;
+	WorkbookView *wbv;
 	WorkbookControlClass *wbc_class;
 
 	g_return_if_fail (IS_WORKBOOK_CONTROL (wbc));
@@ -307,9 +337,15 @@ workbook_control_init_state (WorkbookControl *wbc)
 	command_setup_combos (wbc);
 
 	/* Add views all all existing sheets */
+	wbv = wb_control_view (wbc);
 	sheets = workbook_sheets (wb_control_workbook (wbc));
-	for (ptr = sheets; ptr != NULL ; ptr = ptr->next)
-		wb_control_sheet_add (wbc, ptr->data);
+	for (ptr = sheets; ptr != NULL ; ptr = ptr->next) {
+		sheet = ptr->data;
+		SHEET_FOREACH_VIEW (sheet, view, {
+			if (sv_wbv (view) == wbv)
+				wb_control_sheet_add (wbc, view);
+		});
+	}
 	g_list_free (sheets);
 
 	wbc_class = WBC_CLASS (wbc);
