@@ -84,7 +84,7 @@ wb_view_sheet_focus (WorkbookView *wbv, Sheet *sheet)
 {
 	if (wbv->current_sheet != sheet) {
 		/* Make sure the sheet has been attached */
-		g_return_if_fail (sheet->index_in_wb >= 0);
+		g_return_if_fail (sheet == NULL || sheet->index_in_wb >= 0);
 
 		WORKBOOK_VIEW_FOREACH_CONTROL (wbv, control,
 			wb_control_sheet_focus (control, sheet););
@@ -360,12 +360,16 @@ wb_view_auto_expr_recalc (WorkbookView *wbv, gboolean display)
 	EvalPos		 ep;
 	GnmExprList	*selection = NULL;
 	Value		*v;
+	SheetView	*sv;
 
 	g_return_if_fail (IS_WORKBOOK_VIEW (wbv));
 	g_return_if_fail (wbv->auto_expr != NULL);
 
-	selection_apply (wb_view_cur_sheet_view (wbv), &accumulate_regions,
-		FALSE, &selection);
+	sv = wb_view_cur_sheet_view (wbv);
+	if (sv == NULL)
+		return;
+
+	selection_apply (sv, &accumulate_regions, FALSE, &selection);
 
 	ei.pos = eval_pos_init_sheet (&ep, wbv->current_sheet);
 	ei.func_call = (GnmExprFunction const *)wbv->auto_expr;
@@ -543,7 +547,11 @@ wb_view_save_as (WorkbookView *wbv, GnumFileSaver *fs, gchar const *file_name,
 
 	wb = wb_view_workbook (wbv);
 	io_context = gnumeric_io_context_new (context);
+
+	cmd_context_set_sensitive (context, FALSE);
 	gnum_file_saver_save (fs, io_context, wbv, file_name);
+	cmd_context_set_sensitive (context, TRUE);
+
 	error = gnumeric_io_error_occurred (io_context);
 	if (!error) {
 		workbook_set_saveinfo (wb, file_name, gnum_file_saver_get_format_level (fs), fs);
@@ -644,10 +652,6 @@ wb_view_new_from_input  (GsfInput *input,
 		gnum_file_opener_open (optional_fmt, io_context, new_wbv, input);
 		workbook_enable_recursive_dirty (new_wb, old);
 
-		if (!gnumeric_io_error_occurred (io_context) &&
-		    workbook_sheet_count (new_wb) == 0)
-			gnumeric_io_error_read (io_context, _("No sheets in workbook."));
-
 		if (gnumeric_io_error_occurred (io_context)) {
 			g_object_unref (G_OBJECT (new_wb));
 			new_wbv = NULL;
@@ -656,9 +660,6 @@ wb_view_new_from_input  (GsfInput *input,
 	} else
 		gnumeric_io_error_read (io_context, _("Unsupported file format."));
 
-	if (gnumeric_io_error_occurred (io_context))
-		gnumeric_io_error_display (io_context);
-
 	return new_wbv;
 }
 
@@ -687,6 +688,7 @@ wb_view_new_from_file (char const *file_name,
 	if (input == NULL)
 		input = gsf_input_stdio_new (file_name, &err);
 
+	puts (file_name);
 	if (input != NULL) {
 		WorkbookView *res = wb_view_new_from_input  (input,
 			optional_fmt, io_context);
