@@ -11,7 +11,8 @@ struct _WorkbookView {
 	Workbook *wb;
 	GPtrArray *wb_controls;
 
-	Sheet	  *current_sheet;
+	Sheet	  *current_sheet;	/* convenience */
+	SheetView *current_sheet_view;
 
 	/* preferences */
 	gboolean   show_horizontal_scrollbar;
@@ -48,14 +49,13 @@ typedef struct {
 /* Lifecycle */
 GType		 workbook_view_get_type	  (void);
 WorkbookView	*workbook_view_new	  (Workbook *optional_workbook);
-void             workbook_view_init       (WorkbookView *wbv,
-					   Workbook *optional_workbook);
 void		 wb_view_attach_control	  (WorkbookView *wbv, WorkbookControl *wbc);
 void		 wb_view_detach_control	  (WorkbookControl *wbc);
 
 /* Information */
-Workbook	*wb_view_workbook	  (WorkbookView *wbv);
-Sheet		*wb_view_cur_sheet	  (WorkbookView *wbv);
+Workbook	*wb_view_workbook	  (WorkbookView const *wbv);
+Sheet		*wb_view_cur_sheet	  (WorkbookView const *wbv);
+SheetView	*wb_view_cur_sheet_view	  (WorkbookView const *wbv);
 void		 wb_view_sheet_focus	  (WorkbookView *wbv, Sheet *sheet);
 void		 wb_view_sheet_add	  (WorkbookView *wbv, Sheet *new_sheet);
 gboolean	 wb_view_is_protected	  (WorkbookView *wbv, gboolean check_sheet);
@@ -74,16 +74,20 @@ void		 wb_view_edit_line_set	  (WorkbookView *wbv,
 					   WorkbookControl *optional_wbc);
 void		 wb_view_auto_expr_recalc (WorkbookView *wbv, gboolean display);
 void		 wb_view_auto_expr	  (WorkbookView *wbv,
-					   char const *name, char const *expr);
+					   char const *name,
+					   char const *func_name);
 
 /* I/O routines */
 gboolean wb_view_save_as     (WorkbookView *wbv, GnumFileSaver *fs,
 			      char const *file_name, CommandContext *context);
 gboolean wb_view_save        (WorkbookView *wbv, CommandContext *context);
-gboolean wb_view_open        (char const *file_name,
-			      WorkbookControl *wbc,
-			      gboolean display_errors,
-                              GnumFileOpener const *fo);
+
+WorkbookView *wb_view_new_from_input  (GsfInput *input,
+				       GnumFileOpener const *optional_format,
+				       IOContext *io_context);
+WorkbookView *wb_view_new_from_file  (char const *file_name,
+				      GnumFileOpener const *optional_format,
+				      IOContext *io_context);
 
 #define WORKBOOK_VIEW_FOREACH_CONTROL(wbv, control, code)			\
 do {										\
